function sgnDeclicked = classificator(sgn)
% -------------------------------------------------------
% Main Function for Clifford Classificator Routine  
%
% --------------------------------------------------------
% Author: Mijail Guillemard - 2010
% Copyright 2010 Mijail Guillemard
% This program is distributed under the terms of the GNU General Public License.
% --------------------------------------------------------

clear all; close all;
fname = 'classificator'; 
addpath('isomap'); addpath('cliffordProduct');
global parms; setGlobalParms;

%% =====================================================================
%% Loading Audio Signals

fnam = 'femaleGermanMonoA11Khz'; % fnam = 'beat1'; fnam = 'BassDrumS';
fnam = 'FemaleSpeechEnglish11Khz';
[sgn Fs] = wavread(['audio/' fnam '.wav']);
lsg1 = length(sgn); 
lsg1 = 24352; % for 44Khz
sgn = sgn(1:lsg1); 

%% =====================================================================
%% STFT and Consonants vs Vocals (manual) selection 

pt=1; fftSize = 128; winSize = 128; hopSize = 4; fftSize2 = fftSize/2;
[wxn wsg] = stft(sgn',fftSize,winSize,hopSize);
awxn = abs(wxn);
% nawxn = sum(awxn.*awxn); clcs = find(nawxn > 1); awxn = awxn(:,clcs);
dawxn = diff(awxn); lawxn = log10(awxn); dlawxn = diff(lawxn);
plotSpectro(sgn,'spectOrg');

% position of consonants in speech signal
posCodeCol = [1:100,1300:1600,2570:3100,3350:4000,5120:5350,5600:5990];
% position of consonants in speech signal in decimated matrix 
posCodeCol2 = round(posCodeCol/2);

%% =====================================================================
%% Cluster Analysis

%pcaAnalysis2CodeColors(awxn',   posCodeCol); title('awx PCA');
%pcaAnalysis2CodeColors(dawxn',  posCodeCol); title('dawx PCA');
pcaAnalysis2CodeColors(lawxn',  posCodeCol); title('lawx: PCA of spectrogram data ');
screen2jpeg('PCAClassification');
%pcaAnalysis2CodeColors(dlawxn', posCodeCol); title('dlawx PCA');

sed = isomapPlotting2(lawxn(:,1:2:end)',posCodeCol2); 
title('Isomap of spectrogram data');

%% =====================================================================
%% Moebius Transform for concentrating consonants

codeCol = posCodeCol2;
sed1 = sed(:,codeCol);
posCd = setdiff(1:size(sed,2),codeCol); hold on;
sed2 = sed(:,posCd);

e1 = centerCluster(sed1);
z1 = centerCluster(sed2);

% PCD centering and Moebius Transform design
ze12 = (e1+z1)/2; zz1 = z1 - ze12; ee1 = e1 - ze12;

[mbt imbt] = moebiusTransform2(zz1,-1,0.45);
tic; sedm = mtransformPCD(sed,mbt); toc;
pcaAnalysis2CodeColors(sedm', codeCol); 
title('Moebius-Isomap of spectrogram data');

%%== % removing outliners for better visualization of main Clouds
%%== keepCodes3 = find((sedm(3,:)>-8) & (sedm(3,:)<4));
%%== keepCodes1 = find((sedm(1,:)>-16) & (sedm(1,:)<0));
%%== keepCodes = intersect(keepCodes1,keepCodes3);
%%== sedmm = sedm(:,keepCodes);
%%== pcaAnalysis3CodeColors(sedm', codeCol,keepCodes); 
%%== screen2jpeg('IsomapMoebiusClassification');
%%== pcaAnalysis2CodeColors(sed', codeCol);
%%== screen2jpeg('IsomapClassification');

% disp('function completed'); keyboard; 
