/*=========================================================
% -------------------------------------------------------
% Clifford productK  
%
% --------------------------------------------------------
% Author: M.Guillemard - 2010
% Copyright 2010 Mijail Guillemard
% This program is distributed under the terms of the GNU General Public License.
% --------------------------------------------------------

mex -O convmg.cpp
a = convmg([1,1,7;2,3,7],[1,2;4,5]);

mex -O cliffordProduct.cpp
aa = [1,3;2,4]; bb = [4:-1:1]'; bb = repmat(bb,1,10);
%aa = [1,3;2,0]; bb = [4:-1:2,0]'; bb = repmat(bb,1,10);
%aa = [1,4,7;2,5,8;3,6,9]; bb = [4:-1:1]'; bb = repmat(bb,1,10);
aa = [1,3,2,4,7,6,5,2]; bb = [4:-1:2]'; bb = repmat(bb,1,3);
cc = cliffordProduct(aa,bb);

% code for checking correctness - using previously prepared cliffprodN function
aa = [1,3,2,4,7,6,5,2]; bb = [4:-1:2]'; bb = repmat(bb,1,3);
bb1 = [bb(:,1); zeros(5,1)];
cliffprodN([aa' bb1]);
cc = cliffordProduct(aa,bb);

in mguillem/aa you can compile the program with: 
g++ geomaNT.cc -o geomaNT.exe


 *=======================================================*/

#include "mex.h"
#include "stdio.h"

#include <iostream>
#include <stdexcept>
#include <complex>
#include "geoma.h"
// #include "geomaData.h"

void cliffordPr(double y[], double x0[], double x1[], 
					 int mrows, int ncols)
{
  // computes y = x0*x1 with x0 a clifford number and x1 a matrix of vectors
  // compute the power of 2 factor for initializing the clifford 
  unsigned int Nn = 1; 
  for (unsigned int nk = 0; nk < 16; ++nk)
	 {
		if ((1U<<nk)==mrows){ Nn = nk; break; }
	 }


  nklein::GeometricAlgebra<double> clif0(true,0,Nn);
  nklein::GeometricAlgebra<double> clif1(true,0,Nn);
  nklein::GeometricAlgebra<double> clifY(true,0,Nn);

  for (int aa = 0; aa < ncols; ++aa)
	 {
		clif1.SetCoefs(&(x1[aa*mrows]));
		clif0.SetCoefs(&(x0[aa*mrows]));
		clifY = clif0 * clif1; 
		clifY.GetCoefs(&(y[aa*mrows]));
	 }
}



/* The gateway routine. */
void mexFunction( int nlhs, mxArray *plhs[],
                  int nrhs, const mxArray *prhs[] )
{
  /* Check for proper number of arguments. */
  if(nrhs!=2) {
	 mexErrMsgTxt("cliffProductK: Two inputs required for this clifford product.");
  } 
  // else if(nlhs!=1) {
  //	 mexErrMsgTxt("cliffProductK: One single output is required for the clifford product");
  // }

  int ab1 = mxGetNumberOfElements(prhs[1]);
  mwSize ncols0 = mxGetN(prhs[0]);
  mwSize mrows0 = mxGetM(prhs[0]);
  // mexPrintf("N0=%i,%M0=%i,numElem=%i,nlhs=%i,nrhs=%i\n",ncols0,mrows0,ab1,nlhs,nrhs);
  
  mwSize ncols1 = mxGetN(prhs[1]);
  mwSize mrows1= mxGetM(prhs[1]);
  // mexPrintf("N1=%i,%M1=%i,\n",ncols1,mrows1);

  // unsigned int cliffordSpaceSize = 1U << mrows1;
  if(ncols0 != ncols1 | mrows0 != mrows1) {
	 mexErrMsgTxt("input matrices must have the same size");
  }

  // if(cliffordSpaceSize > 4096) {
  //	  mexErrMsgTxt("cliffordSpaceSize is too big");
  // }

  /* Create matrix for the return argument. */
  plhs[0] = mxCreateDoubleMatrix(mrows1,ncols1, mxREAL);
	 	 
  /* Assign pointers to each input and output. */
  double *x0,*x1, *y;
  x0 = mxGetPr(prhs[0]);
  x1 = mxGetPr(prhs[1]);
  y  = mxGetPr(plhs[0]);
  
  /* Call the main clifford product routine. */
  // y = x0*x1 with x0 a clifford number and x1 a matrix of vectors
  cliffordPr( y,x0,x1,mrows0,ncols0);  
  // cliffordPrA(y,x0,x1,mrows0,ncols0,mrows1,ncols1);

    return;
}

