/*=========================================================
% -------------------------------------------------------
% Clifford Conjugation N  
%
% --------------------------------------------------------
% Author: M.Guillemard - 2010
% Copyright 2010 Mijail Guillemard
% This program is distributed under the terms of the GNU General Public License.
% --------------------------------------------------------

mex -O convmg.cpp
a = convmg([1,1,7;2,3,7],[1,2;4,5]);

mex -O clifprod.cpp
aa = clifprod([1,4;2,3]);

in mguillem/aa you can compile the program with: 
g++ geomaNT.cc -o geomaNT.exe

 *=======================================================*/

#include "mex.h"
#include "stdio.h"

#include <iostream>
#include <stdexcept>
#include <complex>
#include "geoma.h"

void cliffordPr(double y[], double x0[], 
					 int mrows, int ncols)
{
  // compute the power of 2 factor for initializing the clifford 
  unsigned int Nn = 1; 
  for (unsigned int nk = 0; nk < 16; ++nk)
	 {
		if ((1U<<nk)==mrows){ Nn = nk; break; }
	 }
  //  mexPrintf("Nn=%i\n",Nn);

  nklein::GeometricAlgebra<double> clif0(true,0,Nn);
  nklein::GeometricAlgebra<double> clifY(true,0,Nn);

  for (int aa = 0; aa < ncols; ++aa)
	 {
		clif0.SetCoefs(&(x0[aa*mrows]));
		clifY = clif0.Conjugation(); 
		clifY.GetCoefs(&(y[aa*mrows]));
	 }
}

/* The gateway routine. */
void mexFunction( int nlhs, mxArray *plhs[],
                  int nrhs, const mxArray *prhs[] )
{
  /* Check for proper number of arguments. */
  if(nrhs!=1) {
	 mexErrMsgTxt("Only one input is required for this clifford product function.");
  }

  int ab1 = mxGetNumberOfElements(prhs[0]);
  mwSize ncols = mxGetN(prhs[0]);
  mwSize mrows = mxGetM(prhs[0]);
  // mexPrintf("ncols=%i,mrows=%i,numElem=%i,nlhs=%i,nrhs=%i\n",ncols,mrows,ab1,nlhs,nrhs);
  
  unsigned int power2 = mrows & (mrows -1);
  if(power2 != 0) {
	 mexErrMsgTxt("cliffconjN.cpp: mrows must be a power of 2");
  }

  /* Create matrix for the return argument. */
  plhs[0] = mxCreateDoubleMatrix(mrows,ncols, mxREAL);
	 	 
  /* Assign pointers to each input and output. */
  double *xx,*yy;
  xx = mxGetPr(prhs[0]);
  yy = mxGetPr(plhs[0]);
  
  /* Call the main clifford product routine. */
  cliffordPr(yy,xx,mrows,ncols);  

  return;
}
