/*=========================================================
% -------------------------------------------------------
% Clifford Product  
%
% --------------------------------------------------------
% Author: M.Guillemard - 2010
% Copyright 2010 Mijail Guillemard
% This program is distributed under the terms of the GNU General Public License.
% --------------------------------------------------------

mex -O convmg.cpp
a = convmg([1,1,7;2,3,7],[1,2;4,5]);

mex -O clifprod.cpp
aa = clifprod([1,4;2,3]);

in mguillem/aa you can compile the program with: 
g++ geomaNT.cc -o geomaNT.exe

 *=======================================================*/

#include "mex.h"
#include "stdio.h"

#include <iostream>
#include <stdexcept>
#include <complex>
#include "geoma.h"
// #include "geomaData.h"

void cliffordPr(double yy[], double xx[], 
					 int mrows, int ncols)
{
  // computes y = x0*x1 with x0 a clifford number and x1 a matrix of vectors
  unsigned int Nn = mrows; 
  nklein::GeometricAlgebra<double> clif0(true,0,Nn);
  nklein::GeometricAlgebra<double> clifY(true,0,Nn);

  clifY.SetCoefsVector(xx);

  //  mexPrintf("\n");
  // for (int ks = 0; ks < 1U<<Nn; ++ks)
  //	 mexPrintf("clifY[%i] = %f ",ks,clifY[ks]);
  // mexPrintf("\n");

  unsigned int cliffordSpaceSize = 1U<<Nn;
  for (int aa = 1; aa < ncols; aa++)
	 {
		clif0.SetCoefsVector(&(xx[aa*mrows]));
		clifY = clifY * clif0; 
	 }
		clifY.GetCoefs(yy);
}

void cliffordPrA()
{
  const unsigned int Nn = 2;
  int M = 1U<<Nn;
  double calc1[M], calc2[M], calc3[M];
  mwSize ip;
  mexPrintf("\n the M value equals: %i\n",M);
  
  calc1[0] = 7; calc1[1] = 3;
  calc1[2] = 0; calc1[3] = 0;	 
  nklein::GeometricAlgebra< double> clif(true,0,2);
  clif.SetCoefs(&calc1[0]);
  mexPrintf("\n clif: %f,%f,%f,%f\n",clif[0],clif[1],clif[2],clif[3]);
  
  calc2[0] = 4; calc2[1] = 3;
  calc2[2] = 0; calc2[3] = 0;
  nklein::GeometricAlgebra< double> clif2(true,0,2);
  clif2.SetCoefs(&calc2[0]);
  mexPrintf("\n clif2: %f,%f,%f,%f\n",clif2[0],clif2[1],clif2[2],clif2[3]);
  
  nklein::GeometricAlgebra< double> clifn(true,0,2);
  clifn = clif * clif2; 
  mexPrintf("\n cliff  auto : %f,%f,%f,%f\n",clifn[0],clifn[1],clifn[2],clifn[3]);
  
  double dx[M], *aa, *bb;
  aa = &calc1[0]; bb = &calc2[0];
  dx[0] = aa[0]*bb[0] - aa[1]*bb[1] - aa[2]*bb[2] - aa[3]*bb[3];
  dx[1] = aa[0]*bb[1] + aa[1]*bb[0] + aa[2]*bb[3] - aa[3]*bb[2];
  dx[2] = aa[0]*bb[2] - aa[1]*bb[3] + aa[2]*bb[0] + aa[3]*bb[1];
  dx[3] = aa[0]*bb[3] + aa[1]*bb[2] + aa[3]*bb[0] - aa[2]*bb[1];
  
  mexPrintf("\n cliff manual: %f,%f,%f,%f\n",dx[0],dx[1],dx[2],dx[3]);
}


/* The gateway routine. */
void mexFunction( int nlhs, mxArray *plhs[],
                  int nrhs, const mxArray *prhs[] )
{
  /* Check for proper number of arguments. */
  if(nrhs!=1) {
	 mexErrMsgTxt("Only one input is required for this clifford product function.");
  } 

  int ab1 = mxGetNumberOfElements(prhs[0]);
  mwSize ncols = mxGetN(prhs[0]);
  mwSize mrows = mxGetM(prhs[0]);
  // mexPrintf("ncols=%i,mrows=%i,numElem=%i,nlhs=%i,nrhs=%i\n",ncols,mrows,ab1,nlhs,nrhs);
  
  unsigned int cliffordSpaceSize = 1U << mrows;
  if(cliffordSpaceSize > 65536) {
	 mexErrMsgTxt("cliffordSpaceSize is too big");
  }

  /* Create matrix for the return argument. */
  plhs[0] = mxCreateDoubleMatrix(cliffordSpaceSize,1, mxREAL);
	 	 
  /* Assign pointers to each input and output. */
  double *xx,*yy;
  xx = mxGetPr(prhs[0]);
  yy = mxGetPr(plhs[0]);
  
  /* Call the main clifford product routine. */
  // y = x0*x1 with x0 a clifford number and x1 a matrix of vectors
  cliffordPr(yy,xx,mrows,ncols);  
  // cliffordPrA();  

    return;
}
