/*=========================================================
% -------------------------------------------------------
% Clifford Reverse  
%
% --------------------------------------------------------
% Author: M.Guillemard - 2010
% Copyright 2010 Mijail Guillemard
% This program is distributed under the terms of the GNU General Public License.
% --------------------------------------------------------

mex -O convmg.cpp
a = convmg([1,1,7;2,3,7],[1,2;4,5]);

mex -O clifprod.cpp
aa = clifprod([1,4;2,3]);

in mguillem/aa you can compile the program with: 
g++ geomaNT.cc -o geomaNT.exe

 *=======================================================*/

#include "mex.h"
#include "stdio.h"

#include <iostream>
#include <stdexcept>
#include <complex>
#include "geoma.h"

void cliffordPr(double y[], double x0[], 
					 int mrows, int ncols)
{
  // computes y = x0*x1 with x0 a clifford number and x1 a matrix of vectors
  unsigned int Nn = mrows; 
  nklein::GeometricAlgebra<double> clif0(true,0,Nn);
  nklein::GeometricAlgebra<double> clifY(true,0,Nn);

  unsigned int cliffordSpaceSize = 1U<<Nn;
  for (int aa = 0; aa < ncols; ++aa)
	 {
		clif0.SetCoefsVector(&(x0[aa*mrows]));
		clifY = clif0.Reversion(); 
		clifY.GetCoefs(&(y[aa*cliffordSpaceSize]));
	 }
}

/* The gateway routine. */
void mexFunction( int nlhs, mxArray *plhs[],
                  int nrhs, const mxArray *prhs[] )
{
  /* Check for proper number of arguments. */
  if(nrhs!=1) {
	 mexErrMsgTxt("Only one input is required for this clifford product function.");
  }

  int ab1 = mxGetNumberOfElements(prhs[0]);
  mwSize ncols = mxGetN(prhs[0]);
  mwSize mrows = mxGetM(prhs[0]);
  // mexPrintf("ncols=%i,mrows=%i,numElem=%i,nlhs=%i,nrhs=%i\n",ncols,mrows,ab1,nlhs,nrhs);
  
  unsigned int cliffordSpaceSize = 1U << mrows;
  if(cliffordSpaceSize > 65536) {
	 mexErrMsgTxt("cliffconj.cpp: cliffordSpaceSize is too big");
  }

  /* Create matrix for the return argument. */
  plhs[0] = mxCreateDoubleMatrix(cliffordSpaceSize,ncols, mxREAL);
	 	 
  /* Assign pointers to each input and output. */
  double *xx,*yy;
  xx = mxGetPr(prhs[0]);
  yy = mxGetPr(plhs[0]);
  
  /* Call the main clifford product routine. */
  cliffordPr(yy,xx,mrows,ncols);  

    return;
}
