function [mbt imbt] = moebiusTransform2(z1,fact,deviation)
% -------------------------------------------------------
% Moebius Transform Design  
%
% --------------------------------------------------------
% Author: M.Guillemard - 2010
% Copyright 2010 Mijail Guillemard
% This program is distributed under the terms of the GNU General Public License.
% --------------------------------------------------------
disp('starting moebius design');  
global parms; 
moedev = parms.MoebiusDeviation;
moedev = deviation;

e1 = z1;

ssize = length(z1);
ke = fact; e3 = ke*e1;  % e3(1) = 8*rand(1,1);
aici = e1(2:end)-e3(2:end); aici = aici.^2;
a0c0 =  sqrt(sum(aici)/3);
% e1(1) = e1(1)+3;
e3(1) = a0c0 + e1(1); 
fe2 = 0.5; e2 = e1*fe2 + e3*(1-fe2);
deltae = 8/3*a0c0*sum(aici)*(fe2-1)*fe2;
if deltae < 0; deltae = -deltae; end;

onec = zeros(ssize,1); onec(1) = 1;

kz = fact; z3 = kz*z1;  % z3(1) = 5*rand(1,1);
aici = z1(2:end)-z3(2:end); aici = aici.^2;
a0c0 =  sqrt(sum(aici)/3);
z3(1) = a0c0 + z1(1); 
fz2 = moedev; z2 = z1*fz2 + z3*(1-fz2);
deltaz = 8/3*a0c0*sum(aici)*(fz2-1)*fz2;
if deltaz < 0; deltaz = -deltaz; end;

pw2 = 2.^[0:ssize-2]+1;  pw2 = [1, pw2];

Aae = e2-e3; Bbef = cliffprod([e1,-Aae]); Bbe = Bbef(pw2);
Cce = e2-e1; Ddef = cliffprod([e3,-Cce]); Dde = Ddef(pw2);
Aaz = z2-z3; Bbzf = cliffprod([z1,-Aaz]); Bbz = Bbzf(pw2);
Ccz = z2-z1; Ddzf = cliffprod([z3,-Ccz]); Ddz = Ddzf(pw2);

Aae = Aae/sqrt(deltae); Bbe = Bbe/sqrt(deltae);
Cce = Cce/sqrt(deltae); Dde = Dde/sqrt(deltae);
Aaz = Aaz/sqrt(deltaz); Bbz = Bbz/sqrt(deltaz);
Ccz = Ccz/sqrt(deltaz); Ddz = Ddz/sqrt(deltaz);

Aa = cliffprod([Dde Aaz])  - cliffprod([Bbe Ccz]);  Aao = Aa;
Bb = cliffprod([Dde Bbz])  - cliffprod([Bbe Ddz]);  Bbo = Bb;
Cc = -cliffprod([Cce Aaz]) + cliffprod([Aae Ccz]);  Cco = Cc;
Dd = -cliffprod([Cce Bbz]) + cliffprod([Aae Ddz]);  Ddo = Dd;

% mbt  = [Aa'; Bb'; Cc'; Dd'];
% imbt = [Dd'; -Bb'; -Cc'; Aa'];

mbt  = [Aa Bb Cc Dd];
imbt = [cliffreverseN(Dd) -cliffreverseN(Bb) -cliffreverseN(Cc) cliffreverseN(Aa)];


Bbs = cliffreverseN(Bb); % Bbs = Bbsf(pw2);
Dds = cliffreverseN(Dd); % Dds = Ddsf(pw2);
Ccs = cliffreverseN(Cc); % Ccs = Ccsf(pw2);

ABf = cliffprodN([Aa Bbs]); % AB = ABf(pw2); % must be in \R^ssize
CDf = cliffprodN([Cc Dds]); % CD = CDf(pw2); % must be in \R^ssize
Delta1 = cliffprodN([Aa Dds]); Delta2 = cliffprodN([Bb Ccs]);
Deltax = Delta1 - Delta2; % must be 1

% check that the inverse is indeed correct - be careful with the
% reverse operation when defining the inverse moebius transform
Ax = imbt(:,1); Bx = imbt(:,2); Cx = imbt(:,3); Dx = imbt(:,4);
Bxs = cliffreverseN(Bx); % Bbs = Bbsf(pw2);
Dxs = cliffreverseN(Dx); % Dds = Ddsf(pw2);
Cxs = cliffreverseN(Cx); % Ccs = Ccsf(pw2);
Deltax1 = cliffprodN([Ax Dxs]); Deltax2 = cliffprodN([Bx Cxs]);
Deltaxx = Deltax1 - Deltax2; % must be 1
st1 = [[0:2^ssize-1]' Deltaxx]; Deltastxx=[dec2bin([0:2^ssize-1],ssize+1) num2str(st1)];


%% % checking that the coefficients Aa, Bb, Cc, Dd are in the clifford group
%% % nCc1 = cliffprodN([Cc,cliffconjN(Cc)]);
%% % norm(Cc).^2

%% st1 = [[0:2^ssize-1]' ABf]; ABfst=[dec2bin([0:2^ssize-1],ssize+1) num2str(st1)]
%% st1 = [[0:2^ssize-1]' CDf]; CDfst=[dec2bin([0:2^ssize-1],ssize+1) num2str(st1)]
% st1 = [[0:2^ssize-1]' Deltax]; Deltastx=[dec2bin([0:2^ssize-1],ssize+1) num2str(st1)];


%% ssize = 7;
%% pw2 = 2.^[0:ssize-2]+1;  pw2 = [1, pw2]; 
%% st1 = [[0:2^ssize-1]']; stk=[dec2bin([0:2^ssize-1],ssize+1) num2str(st1)];
%% pw2d = setdiff([1:2^ssize],pw2);

% disp('ii83ff'); keyboard; 