/* BasicColumnIterator.cc
 * ----------------------
 * Implements BasicColumnIterator.h
 *
 * Written by Patrick Perry
 * Original Version on December 1, 2003
 *
 * $Id: BasicColumnIterator.cc,v 1.3 2005/11/02 01:59:52 patperry Exp $
 * $Log: BasicColumnIterator.cc,v $
 * Revision 1.3  2005/11/02 01:59:52  patperry
 * The last (?) gcc4.0 fixes\!\!\!
 *
 * Revision 1.2  2005/10/24 16:20:08  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:36:05  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.3  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.2  2003/12/02 12:39:11  patperry
 * added code to combine the four blocks
 *
 * Revision 1.1  2003/12/02 11:05:00  patperry
 * Added BasicColumnIterator
 *
 */

#include <algorithm>


// static member instantiation
template <class Element_t, class Alloc>
typename Alloc::template rebind<Element_t>::other 
BasicColumnIterator<Element_t, Alloc>::ElementAlloc;


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>::
BasicColumnIterator ()
  : numRows(0), columnData(NULL)
{
}
  

template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>::
BasicColumnIterator (const BasicColumnIterator& other)
  : RowColumnIterator<Element_t, Alloc>(other.logicalPosition),
    numRows(other.numRows),
    columnData(ElementAlloc.allocate(numRows))
{
  std::copy(other.columnData, other.columnData + numRows, columnData);
}


template <class Element_t, class Alloc>
template <class ColumnIterator_t, class Alloc1>
BasicColumnIterator<Element_t, Alloc>::
BasicColumnIterator (const Matrix<Element_t, ColumnIterator_t, Alloc1>& matrix,
				 int column, int position)
  : RowColumnIterator<Element_t, Alloc>(position),
    numRows(matrix.getNumRows()),
    columnData(ElementAlloc.allocate(numRows))
{
  for (int row = 0; row < numRows; ++row) {
    columnData[row] = matrix.getElement(row, column);
  }
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>::
~BasicColumnIterator ()
{
  ElementAlloc.deallocate(columnData, numRows);
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>& 
BasicColumnIterator<Element_t, Alloc>::
operator= (const BasicColumnIterator& other)
{
  if (this != &other) {
    ElementAlloc.deallocate(columnData, numRows);
    
    logicalPosition = other.logicalPosition;
    numRows = other.numRows;
    columnData = ElementAlloc.allocate(numRows);
    std::copy(other.columnData, other.columnData + numRows, columnData);
  }

  return *this;
}


template <class Element_t, class Alloc>
Element_t
BasicColumnIterator<Element_t, Alloc>::
operator* ()
{
  return columnData[logicalPosition];
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>&
BasicColumnIterator<Element_t, Alloc>::
operator++ ()
{
  ++logicalPosition;
  return *this;
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>
BasicColumnIterator<Element_t, Alloc>::
operator++ (int post)
{
  BasicColumnIterator result = *this;
  ++(*this);
  return result;
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>&
BasicColumnIterator<Element_t, Alloc>::
operator-- ()
{
  --logicalPosition;
  return *this;
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>
BasicColumnIterator<Element_t, Alloc>::
operator-- (int post)
{
  BasicColumnIterator result = *this;
  ++(*this);
  return result;
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>&
BasicColumnIterator<Element_t, Alloc>::
operator+= (int n)
{
  logicalPosition += n;
  return *this;
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>&
BasicColumnIterator<Element_t, Alloc>::
operator-= (int n)
{
  logicalPosition -= n;
  return *this;
}


template <class Element_t, class Alloc>
int
BasicColumnIterator<Element_t, Alloc>::
operator- (const BasicColumnIterator& x) const
{
  return (logicalPosition - x.logicalPosition);
}

template <class Element_t, class Alloc>
Element_t
BasicColumnIterator<Element_t, Alloc>::
operator[] (int n) const
{
  return columnData[logicalPosition + n];
}


template <class Element_t, class Alloc>
bool
BasicColumnIterator<Element_t, Alloc>::
operator== (const BasicColumnIterator& x) const
{
  return (logicalPosition == x.logicalPosition);
}


template <class Element_t, class Alloc>
bool
BasicColumnIterator<Element_t, Alloc>::
operator!= (const BasicColumnIterator& x) const
{
  return (logicalPosition != x.logicalPosition);
}


template <class Element_t, class Alloc>
bool
BasicColumnIterator<Element_t, Alloc>::
operator< (const BasicColumnIterator& x) const
{
  return (logicalPosition < x.logicalPosition);
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>
operator+ (int n, const BasicColumnIterator<Element_t, Alloc>& i)
{
  BasicColumnIterator<Element_t, Alloc> result = i;
  result += n;
  return result;
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>
operator+ (const BasicColumnIterator<Element_t, Alloc>& i, int n)
{
  BasicColumnIterator<Element_t, Alloc> result = i;
  result += n;
  return result;
}


template <class Element_t, class Alloc>
BasicColumnIterator<Element_t, Alloc>
operator- (const BasicColumnIterator<Element_t, Alloc>& i, int n)
{
  BasicColumnIterator<Element_t, Alloc> result = i;
  result -= n;
  return result;
}

