/* CRCovering.cc
 * -------------
 * Implements CRCovering.h
 *
 * Written by Patrick Perry
 * Original Version on July 2, 2003
 *
 * $Id: CRCovering.cc,v 1.1.1.1 2005/03/18 23:36:07 silva Exp $
 * $Log: CRCovering.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:07  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.3  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.2  2003/10/17 09:51:10  patperry
 * Updated CRCovering and CSCSparseMatrix, (probably) breaking GeomSparse
 * in the process.
 *
 *
 */

#ifndef _CRCOVERING_CC
#define _CRCOVERING_CC

#include <memory>
#include <set>
#include <functional>
#include <algorithm>
#include <iterator>
#include "CRCovering.h"


  
CRCovering::
~CRCovering ()
{
  delete[] columnSets;
  delete[] rowSets;
}


int
CRCovering::
getNumSets () const
{
  return numSets;
}


int 
CRCovering::
getNumRows () const
{
  return numRows;
}


int 
CRCovering::
getNumColumns () const
{
  return numColumns;
}


const std::set<int>&
CRCovering::
getColumnSet (int i) const
{
  return columnSets[i];
}


const std::set<int>&
CRCovering::
getRowSet (int i) const
{
  return rowSets[i];
}


CRCovering::const_iterator 
CRCovering:: 
getColumnSetsBegin () const
{
  return columnSets;
}


CRCovering::const_iterator 
CRCovering:: 
getColumnSetsEnd () const
{
  return columnSets + numSets;
}


CRCovering::const_iterator 
CRCovering:: 
getRowSetsBegin () const
{
  return rowSets;
}


CRCovering::const_iterator 
CRCovering:: 
getRowSetsEnd () const
{
  return rowSets + numSets;
}


std::ostream& 
CRCovering::
put (std::ostream& s) const
{
  for (int index = 0; index < getNumSets(); ++index) {
    s << "C_" << index << ": { ";
    std::copy(getColumnSet(index).begin(), getColumnSet(index).end(),
		    std::ostream_iterator<int>(s, " "));
    s << "}\nR_" << index << ": { ";
    std::copy(getRowSet(index).begin(), getRowSet(index).end(),
		    std::ostream_iterator<int>(s, " "));
    s << "}\n";
  }

  return s;
}


std::ostream& operator<< (std::ostream& s, 
					 const CRCovering& covering)
{
  return covering.put(s);
}


#endif // _CRCOVERING_CC
