/* DiagonalBlock.cc
 * ----------------
 * Implements DiagonalBlock.h
 *
 * Written by Patrick Perry
 * Original Version on October 24, 2003
 *
 * $Id: DiagonalBlock.cc,v 1.1.1.1 2005/03/18 23:36:11 silva Exp $
 * $Log: DiagonalBlock.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:11  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.5  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.4  2003/12/12 20:13:46  patperry
 * bugfixes and debug code galore
 *
 * Revision 1.3  2003/11/22 06:54:14  patperry
 * lotsa fixes.
 *
 * Revision 1.2  2003/10/28 04:43:51  patperry
 * Preliminary version of SelectionMaskColumnIterator.
 * Copy constructors for all full matrix types.
 *
 * Revision 1.1  2003/10/24 09:30:26  patperry
 * Adding some files I forgot.
 *
 *
 */

template <class Element_t, class Alloc>
DiagonalBlock<Element_t, Alloc>::
DiagonalBlock (int id, int numRows, int numColumns)
  : LUFullMatrix<Element_t, Alloc>(numRows, numColumns),
    id(id)
{
}


template <class Element_t, class Alloc>
template <class ColumnIterator_t, class Alloc1>
DiagonalBlock<Element_t, Alloc>::
DiagonalBlock (int id, 
			const Matrix<Element_t, ColumnIterator_t, Alloc1>& matrix)
  : LUFullMatrix<Element_t, Alloc>(matrix), id(id)
{
}


template <class Element_t, class Alloc>
DiagonalBlock<Element_t, Alloc>::
~DiagonalBlock ()
{
}


template <class Element_t, class Alloc>
int
DiagonalBlock<Element_t, Alloc>::
getID () const
{
  return id;
}


template <class Element_t, class Alloc>
void
DiagonalBlock<Element_t, Alloc>::
addCoface (OffDiagonalBlock * coface)
{
  if (coface != NULL) {
    cofaces.push_back(coface);
  }
}


template <class Element_t, class Alloc>
template <class InputIterator>
void
DiagonalBlock<Element_t, Alloc>::
addCofaces (InputIterator begin, InputIterator end)
{
  for (InputIterator it = begin; it != end; ++it) {
    addCoface(*it);
  }
}


template <class Element_t, class Alloc>
void
DiagonalBlock<Element_t, Alloc>::
addFace (OffDiagonalBlock * face)
{
  faces.push_back(face);
}


template <class Element_t, class Alloc>
template <class InputIterator>
void
DiagonalBlock<Element_t, Alloc>::
addFaces (InputIterator begin, InputIterator end)
{
  faces.insert(faces.end(), begin, end);
}


template <class Element_t, class Alloc>
void
DiagonalBlock<Element_t, Alloc>::
permuteRows (const int * permutation)
{
  LUFullMatrix<Element_t, Alloc>::permuteRows(permutation);

  for (typename std::vector<OffDiagonalBlock *>::iterator it = faces.begin(); 
	  it != faces.end(); ++it) {
    (*it)->permuteRows(permutation);
  }
}


template <class Element_t, class Alloc>
void
DiagonalBlock<Element_t, Alloc>::
swapRows (int i, int j)
{
  LUFullMatrix<Element_t, Alloc>::swapRows(i, j);

  for (typename std::vector<OffDiagonalBlock *>::iterator it = faces.begin();
	  it != faces.end(); ++it) {
    (*it)->swapRows(i, j);
  }
}


template <class Element_t, class Alloc>
void
DiagonalBlock<Element_t, Alloc>::
permuteColumns (const int * permutation)
{
  LUFullMatrix<Element_t, Alloc>::permuteColumns(permutation);

  for (typename std::vector<OffDiagonalBlock *>::iterator it = cofaces.begin();
	  it != cofaces.end(); ++it) {
    (*it)->permuteColumns(permutation);
  }
}


template <class Element_t, class Alloc>
void
DiagonalBlock<Element_t, Alloc>::
swapColumns (int i, int j)
{
  LUFullMatrix<Element_t, Alloc>::swapColumns(i, j);

  for (typename std::vector<OffDiagonalBlock *>::iterator it = cofaces.begin();
	  it != cofaces.end(); ++it) {
    (*it)->swapColumns(i, j);
  }
}


template <class Element_t, class Alloc>
void
DiagonalBlock<Element_t, Alloc>::
addScalarTimesPivotToRow (Element_t scalar, int pivot, int row)
					 
{
  LUFullMatrix<Element_t, Alloc>::addScalarTimesPivotToRow(scalar, pivot, row);

  for (typename std::vector<OffDiagonalBlock *>::iterator it = faces.begin();
	  it != faces.end(); ++it) {
    (*it)->addScalarTimesRowToRow(scalar, pivot, row);
  }
}

