/* FullColumnIterator.cc
 * ---------------------
 * Implements FullColumnIterator.h
 *
 * Written by Patrick Perry
 * Original Version on October 23, 2003
 *
 * $Id: FullColumnIterator.cc,v 1.1.1.1 2005/03/18 23:36:12 silva Exp $
 * $Log: FullColumnIterator.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:12  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.4  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.3  2003/10/25 00:49:32  patperry
 * Added RowIterators.  Make RowColumnIterator have virtual functions.
 *
 * Revision 1.2  2003/10/24 08:16:05  patperry
 * LUFullMatrix works better now.
 *
 * Revision 1.1  2003/10/24 02:16:48  patperry
 * Add FullMatrix and FullColumnIterator.
 *
 *
 */


template <class Element_t, class Alloc>
FullColumnIterator<Element_t, Alloc>::
FullColumnIterator ()
  : RowColumnIterator<Element_t, Alloc>(),
    data(NULL), rowPermutationInverse(0)
{
}


template <class Element_t, class Alloc>
FullColumnIterator<Element_t, Alloc>::
FullColumnIterator (const Element_t * data,
				const int * rowPermutationInverse,
				int logicalPosition)
  : RowColumnIterator<Element_t, Alloc>(logicalPosition),
    data(data), rowPermutationInverse(rowPermutationInverse)
{
}


template <class Element_t, class Alloc>
FullColumnIterator<Element_t, Alloc>::
~FullColumnIterator ()
{
}


template <class Element_t, class Alloc>
Element_t 
FullColumnIterator<Element_t, Alloc>::
operator* ()
{
  if (!rowPermutationInverse) {
    return data[logicalPosition];
  } else {
    return data[rowPermutationInverse[logicalPosition]];
  }
}


template <class Element_t, class Alloc>
FullColumnIterator<Element_t, Alloc>&
FullColumnIterator<Element_t, Alloc>::
operator++ ()
{
  ++logicalPosition;

  return *this;
}


template <class Element_t, class Alloc>
FullColumnIterator<Element_t, Alloc>
FullColumnIterator<Element_t, Alloc>::
operator++ (int post)
{
  FullColumnIterator result = *this;
  ++logicalPosition;

  return result;
}


template <class Element_t, class Alloc>
FullColumnIterator<Element_t, Alloc>&
FullColumnIterator<Element_t, Alloc>::
operator-- ()
{
  --logicalPosition;

  return *this;
}


template <class Element_t, class Alloc>
FullColumnIterator<Element_t, Alloc>
FullColumnIterator<Element_t, Alloc>::
operator-- (int post)
{
  FullColumnIterator result = *this;
  --logicalPosition;

  return result;
}


template <class Element_t, class Alloc>
FullColumnIterator<Element_t, Alloc>&
FullColumnIterator<Element_t, Alloc>::
operator+= (int n)
{
  logicalPosition += n;

  return *this;
}


template <class Element_t, class Alloc>
FullColumnIterator<Element_t, Alloc>&
FullColumnIterator<Element_t, Alloc>::
operator-= (int n)
{
  logicalPosition -= n;

  return *this;
}


template <class Element_t, class Alloc>
int 
FullColumnIterator<Element_t, Alloc>::
operator- (const FullColumnIterator& x) const
{
  return (logicalPosition - x.logicalPosition);
}


template <class Element_t, class Alloc>
Element_t 
FullColumnIterator<Element_t, Alloc>::
operator[] (int n) const
{
  if (!rowPermutationInverse) {
    return data[logicalPosition + n];
  } else {
    return data[rowPermutationInverse[logicalPosition + n]];
  }
}


template <class Element_t, class Alloc>
bool 
FullColumnIterator<Element_t, Alloc>::
operator== (const FullColumnIterator& x) const
{
  return (logicalPosition == x.logicalPosition);
}


template <class Element_t, class Alloc>
bool 
FullColumnIterator<Element_t, Alloc>::
operator!= (const FullColumnIterator& x) const
{
  return (logicalPosition != x.logicalPosition);
}


template <class Element_t, class Alloc>
bool 
FullColumnIterator<Element_t, Alloc>::
operator< (const FullColumnIterator& x) const
{
  return (logicalPosition < x.logicalPosition);
}

