/* FullRowIterator.cc
 * ------------------
 * Implements FullRowIterator.h
 *
 * Written by Patrick Perry
 * Original Version on October 24, 2003
 *
 * $Id: FullRowIterator.cc,v 1.1.1.1 2005/03/18 23:36:14 silva Exp $
 * $Log: FullRowIterator.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:14  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.2  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.1  2003/10/25 00:49:32  patperry
 * Added RowIterators.  Make RowColumnIterator have virtual functions.
 *
 *
 */


template <class Element_t, class Alloc>
FullRowIterator<Element_t, Alloc>::
FullRowIterator ()
  : RowColumnIterator<Element_t, Alloc>(),
    data(NULL), row(row), numRows(0), columnPermutationInverse(0)
{
}


template <class Element_t, class Alloc>
FullRowIterator<Element_t, Alloc>::
FullRowIterator (const Element_t * data, int row, int numRows,
			  const int * columnPermutationInverse,
			  int logicalPosition)
  : RowColumnIterator<Element_t, Alloc>(logicalPosition),
    data(data), row(row), numRows(numRows),
    columnPermutationInverse(columnPermutationInverse)
{
  if (!columnPermutationInverse) {
    actualPosition = row + logicalPosition * numRows;
  } else {
    actualPosition = row + columnPermutationInverse[logicalPosition] * numRows;
  }
}


template <class Element_t, class Alloc>
FullRowIterator<Element_t, Alloc>::
~FullRowIterator ()
{
}


template <class Element_t, class Alloc>
Element_t 
FullRowIterator<Element_t, Alloc>::
operator* ()
{
  return data[actualPosition];
}


template <class Element_t, class Alloc>
FullRowIterator<Element_t, Alloc>&
FullRowIterator<Element_t, Alloc>::
operator++ ()
{
  ++logicalPosition;

  if (!columnPermutationInverse) {
    actualPosition += numRows;
  } else {
    actualPosition = row + columnPermutationInverse[logicalPosition] * numRows;
  }

  return *this;
}


template <class Element_t, class Alloc>
FullRowIterator<Element_t, Alloc>
FullRowIterator<Element_t, Alloc>::
operator++ (int post)
{
  FullRowIterator result = *this;
  ++(*this);

  return result;
}


template <class Element_t, class Alloc>
FullRowIterator<Element_t, Alloc>&
FullRowIterator<Element_t, Alloc>::
operator-- ()
{
  --logicalPosition;

  if (!columnPermutationInverse) {
    actualPosition -= numRows;
  } else {
    actualPosition = row + columnPermutationInverse[logicalPosition] * numRows;
  }

  return *this;
}


template <class Element_t, class Alloc>
FullRowIterator<Element_t, Alloc>
FullRowIterator<Element_t, Alloc>::
operator-- (int post)
{
  FullRowIterator result = *this;
  --(*this);

  return result;
}


template <class Element_t, class Alloc>
FullRowIterator<Element_t, Alloc>&
FullRowIterator<Element_t, Alloc>::
operator+= (int n)
{
  logicalPosition += n;

  if (!columnPermutationInverse) {
    actualPosition += n * numRows;
  } else {
    actualPosition = row + columnPermutationInverse[logicalPosition] * numRows;
  }

  return *this;
}


template <class Element_t, class Alloc>
FullRowIterator<Element_t, Alloc>&
FullRowIterator<Element_t, Alloc>::
operator-= (int n)
{
  logicalPosition -= n;

  if (!columnPermutationInverse) {
    actualPosition -= n * numRows;
  } else {
    actualPosition = row + columnPermutationInverse[logicalPosition] * numRows;
  }

  return *this;
}


template <class Element_t, class Alloc>
int 
FullRowIterator<Element_t, Alloc>::
operator- (const FullRowIterator& x) const
{
  return (logicalPosition - x.logicalPosition);
}


template <class Element_t, class Alloc>
Element_t 
FullRowIterator<Element_t, Alloc>::
operator[] (int n) const
{
  if (!columnPermutationInverse) {
    return data[actualPosition + n * numRows];
  } else {
    return data[row + numRows * columnPermutationInverse[logicalPosition + n]];
  }
}


template <class Element_t, class Alloc>
bool 
FullRowIterator<Element_t, Alloc>::
operator== (const FullRowIterator& x) const
{
  return (logicalPosition == x.logicalPosition);
}


template <class Element_t, class Alloc>
bool 
FullRowIterator<Element_t, Alloc>::
operator!= (const FullRowIterator& x) const
{
  return (logicalPosition != x.logicalPosition);
}


template <class Element_t, class Alloc>
bool 
FullRowIterator<Element_t, Alloc>::
operator< (const FullRowIterator& x) const
{
  return (logicalPosition < x.logicalPosition);
}

