// IndexList.cc
// ------------
// Implements IndexList.h
//
// Author: Erik Carlsson 
// Date:   August 27, 2003
//
// Slight Modification by Patrick Perry on August 27, 2003
//


#include <algorithm>
#include <memory>
#include <iostream>
#include "IndexList.h"


IndexList::
IndexList () 
  : length(0), list(0)
{
}


IndexList::
IndexList (int length) 
  : length(length),
    list(new int[length])
{
}


IndexList::
IndexList (int* list, int length) 
  : length(length),
    list(new int[length])
{
  std::copy(list, list + length, this->list);
}


IndexList::
IndexList (const IndexList &indexList) 
  : length(indexList.length),
    list(new int[length])
{
  std::copy(indexList.list, indexList.list + length, this->list);
}


IndexList::
~IndexList () 
{
  delete[] list;
}


void 
IndexList::
setVals (const IndexList& indexList) {
  setVals(indexList.list, indexList.length);
}


void 
IndexList::
setVals (int* list, int length) 
{
  delete[] this->list;
  setValsWithoutDeleting(list, length);
}


void 
IndexList::
makeZeros (int length) 
{
  this->length = length;
  delete[] list; list = new int[length];
  std::uninitialized_fill(list, list + length, 0);
}


void 
IndexList::
makeFull (int length) 
{
  this->length = length;
  delete[] list; list = new int[length];
  for(int i = 0; i < length; i++) list[i] = i;
}


void 
IndexList::
setValsWithoutDeleting (int* list, int length) 
{
  if(length > 0) {
    this->list = new int[length];
    std::copy(list, list + length, this->list);
  } else {
    this->list = 0;
  }
  
  this->length = length;
}


void 
IndexList::
makeNewList(int length) 
{
  delete[] this->list;
  makeNewListWithoutDeleting(length);
}


void 
IndexList::
makeNewListWithoutDeleting (int length) 
{
  list = new int[length];
  this->length = length;
}


void 
IndexList::
display () const 
{
  std::cout << "displaying list, length = " << length << "\n";
  for(int i = 0; i < length; i++) {
    std::cout << list[i] << " ";
  }
  std::cout << "\n";
}


void 
IndexList::
adjoin (const IndexList& indexList) 
{
  int* oldlist = list;
  int oldlength = length;
  length += indexList.length;
  list = new int[oldlength + indexList.length];
  std::copy(oldlist, oldlist + oldlength, list);
  std::copy(indexList.list, indexList.list + indexList.length, 
		  list + oldlength);
  delete[] oldlist;
}


//preconditions: B is a subset of A, A and B are sorted
void 
IndexList::
setDiff (const IndexList& A, const IndexList &B) 
{
  delete[] list;
  length = A.length - B.length;
  list = new int[length];
  int k = 0, l = 0;
  for(int i = 0; i < A.length; i++) {
    if(l >= B.length || A.list[i] != B.list[l]) {
      list[k] = A.list[i];
	 if(k >= length) {
	   std::cout << "setDiff error!\n"; 
	   A.display(); 
	   B.display(); 
	   return;
	 }
      k++;
    } else l++;
  }
}


void 
IndexList::
sortList () 
{
  std::sort(list, list + length);
}


void 
IndexList::
subListOf (const IndexList& A) 
{
  for(int i = 0; i < length; i++) {
    list[i] = A.list[list[i]];
  }
}


void 
IndexList::
sortAccordingTo (const IndexList& A) 
{
  IndexList temp1(A), temp2;
  for(int i = 0; i < temp1.length; i++) {
    for(int j = 0; j < temp1.length-1; j++) {
      if(temp1.list[i] < temp1.list[j]) {
	int a = temp1.list[i];
	temp1.list[i] = temp1.list[j];
	temp1.list[j] = a;
	a = list[i];
	list[i] = list[j];
	list[j] = a;
      }
    }
  }
}
