/* LUCancelFullMatrix.cc
 * ---------------------
 * Implements LUCancelFullMatrix.h
 *
 * Written by Patrick Perry
 * Original Version on August 14, 2003
 *
 * $Id: LUCancelFullMatrix.cc,v 1.2 2005/11/02 01:59:52 patperry Exp $
 * $Log: LUCancelFullMatrix.cc,v $
 * Revision 1.2  2005/11/02 01:59:52  patperry
 * The last (?) gcc4.0 fixes\!\!\!
 *
 * Revision 1.1.1.1  2005/03/18 23:36:18  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.12  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.11  2003/12/13 00:09:18  patperry
 * bugfixes
 *
 * Revision 1.10  2003/12/12 20:13:46  patperry
 * bugfixes and debug code galore
 *
 * Revision 1.9  2003/12/02 08:55:57  patperry
 * Added Destructor
 *
 * Revision 1.8  2003/11/30 05:36:29  patperry
 * more bugfixes
 *
 * Revision 1.7  2003/11/30 00:24:43  patperry
 * fixed reduction bugs.  inserted printfs
 *
 * Revision 1.6  2003/11/22 10:23:47  patperry
 * Finished data rearrange.
 *
 * Revision 1.5  2003/11/22 06:54:14  patperry
 * lotsa fixes.
 *
 * Revision 1.4  2003/10/28 04:43:51  patperry
 * Preliminary version of SelectionMaskColumnIterator.
 * Copy constructors for all full matrix types.
 *
 * Revision 1.3  2003/10/26 00:24:51  patperry
 * Preliminary Version of OffDiagonalBlock.  Deleted unnecessary files.
 *
 * Revision 1.2  2003/10/25 00:49:32  patperry
 * Added RowIterators.  Make RowColumnIterator have virtual functions.
 *
 * Revision 1.1  2003/10/24 23:05:35  patperry
 * Revamped LUFullCancelMatrix (and changed name to LUCancelFullMatrix).
 *
 *
 */

#include <cassert>


template <class Element_t, class Alloc>
LUCancelFullMatrix<Element_t, Alloc>::
LUCancelFullMatrix (const LUFullMatrix<Element_t, Alloc> * pivotMatrix,
				const LUFullMatrix<Element_t, Alloc> * cancelor)
  : FullMatrix<Element_t, Alloc>(pivotMatrix.getNumRows(), 
						   cancelor.getNumColumns()),
    pivotMatrix(pivotMatrix),
    cancelor(cancelor),
    hasBeenCanceled(false)
{
}


template <class Element_t, class Alloc>
template <class ColumnIterator_t, class Alloc1>
LUCancelFullMatrix<Element_t, Alloc>::
LUCancelFullMatrix (const Matrix<Element_t, ColumnIterator_t, Alloc1>& matrix,
				const LUFullMatrix<Element_t, Alloc> * pivotMatrix,
				const LUFullMatrix<Element_t, Alloc> * cancelor)
  : FullMatrix<Element_t, Alloc>(matrix),
    pivotMatrix(pivotMatrix),
    cancelor(cancelor),
    hasBeenCanceled(false)
{
}


template <class Element_t, class Alloc>
LUCancelFullMatrix<Element_t, Alloc>::
~LUCancelFullMatrix ()
{
}


template <class Element_t, class Alloc>
bool 
LUCancelFullMatrix<Element_t, Alloc>::
isCanceled () const
{
  return hasBeenCanceled;
}


template <class Element_t, class Alloc>
void
LUCancelFullMatrix<Element_t, Alloc>::
cancel () 
{
  if (!hasBeenCanceled) {
    this->reducePermutations();

    const int startRow = pivotMatrix->getNumPivots();
    
    if (startRow < numRows) {
	 for (int pivot = 0; pivot < cancelor->getNumPivots(); ++pivot) {
	   int row = startRow;
	   Element_t pivotValueInverse 
		= - (1 / cancelor->getElement(pivot, pivot));

	   for (ColumnIterator column = FullMatrix<Element_t, Alloc>::
			getColumnBegin(pivot) + startRow;
		   column != FullMatrix<Element_t, Alloc>::getColumnEnd(pivot);
		   ++column) {
		Element_t columnValue = *column;
		
		if (columnValue != 0) {
		  cancelRow(row, pivot, columnValue * pivotValueInverse);
		}
		++row;
	   }
	 }
    }

    hasBeenCanceled = true;
  }
}


template <class Element_t, class Alloc>
int 
LUCancelFullMatrix<Element_t, Alloc>::
getNumRowPivots () const
{
  return pivotMatrix->getNumPivots();
}


template <class Element_t, class Alloc>
int 
LUCancelFullMatrix<Element_t, Alloc>::
getNumColumnPivots () const
{
  return cancelor->getNumPivots();
}


template <class Element_t, class Alloc>
Element_t 
LUCancelFullMatrix<Element_t, Alloc>::
getElement (int i, int j) const
{
  if (!hasBeenCanceled) {
    const_cast<LUCancelFullMatrix<Element_t, Alloc> *>(this)->cancel();
  }

  return FullMatrix<Element_t, Alloc>::getElement(i, j);
}


template <class Element_t, class Alloc>
void
LUCancelFullMatrix<Element_t, Alloc>::
setElement (int i, int j, Element_t value)
{
  assert(!hasBeenCanceled);
  FullMatrix<Element_t, Alloc>::setElement(i, j, value);
}


template <class Element_t, class Alloc>
typename LUCancelFullMatrix<Element_t, Alloc>::RowIterator 
LUCancelFullMatrix<Element_t, Alloc>::
getRowBegin (int row) const
{
  if (!hasBeenCanceled) {
    const_cast<LUCancelFullMatrix<Element_t, Alloc> *>(this)->cancel();
  }

  return FullMatrix<Element_t, Alloc>::getRowBegin(row);
}


template <class Element_t, class Alloc>
typename LUCancelFullMatrix<Element_t, Alloc>::RowIterator 
LUCancelFullMatrix<Element_t, Alloc>::
getRowEnd (int row) const
{
  if (!hasBeenCanceled) {
    const_cast<LUCancelFullMatrix<Element_t, Alloc> *>(this)->cancel();
  }

  return FullMatrix<Element_t, Alloc>::getRowEnd(row);
}


template <class Element_t, class Alloc>
typename LUCancelFullMatrix<Element_t, Alloc>::ColumnIterator 
LUCancelFullMatrix<Element_t, Alloc>::
getColumnBegin (int column) const
{
  if (!hasBeenCanceled) {
    const_cast<LUCancelFullMatrix<Element_t, Alloc> *>(this)->cancel();
  }

  return FullMatrix<Element_t, Alloc>::getColumnBegin(column);
}


template <class Element_t, class Alloc>
typename LUCancelFullMatrix<Element_t, Alloc>::ColumnIterator 
LUCancelFullMatrix<Element_t, Alloc>::
getColumnEnd (int column) const
{
  if (!hasBeenCanceled) {
    const_cast<LUCancelFullMatrix<Element_t, Alloc> *>(this)->cancel();
  }

  return FullMatrix<Element_t, Alloc>::getColumnEnd(column);
}


template <class Element_t, class Alloc>
template <class InputIterator>
void 
LUCancelFullMatrix<Element_t, Alloc>::
fillColumn (int column, InputIterator values)
{
  assert(!hasBeenReduced);
    //assert(!hasBeenCanceled);
  FullMatrix<Element_t, Alloc>::fillColumn(column, values);
}


template <class Element_t, class Alloc>
std::ostream& 
LUCancelFullMatrix<Element_t, Alloc>::
put (std::ostream& s) const
{
  if (!hasBeenCanceled) {
    const_cast<LUCancelFullMatrix<Element_t, Alloc> *>(this)->cancel();
  }

  return FullMatrix<Element_t, Alloc>::put(s);
}


template <class Element_t, class Alloc>
void 
LUCancelFullMatrix<Element_t, Alloc>::
permuteRows (const int * permutation)
{
  assert(!hasBeenCanceled);
  FullMatrix<Element_t, Alloc>::permuteRows(permutation);
}


template <class Element_t, class Alloc>
void 
LUCancelFullMatrix<Element_t, Alloc>::
swapRows (int i, int j)
{
  assert(!hasBeenCanceled);
  FullMatrix<Element_t, Alloc>::swapRows(i, j);
}


template <class Element_t, class Alloc>
void 
LUCancelFullMatrix<Element_t, Alloc>::
permuteColumns (const int * permutation)
{
  assert(!hasBeenCanceled);
  FullMatrix<Element_t, Alloc>::permuteColumns(permutation);
}


template <class Element_t, class Alloc>
void 
LUCancelFullMatrix<Element_t, Alloc>::
swapColumns (int i, int j)
{
  assert(!hasBeenCanceled);
  FullMatrix<Element_t, Alloc>::swapColumns(i, j);
}


template <class Element_t, class Alloc>
template <class InputIterator>
void 
LUCancelFullMatrix<Element_t, Alloc>::
addScalarTimesVectorToRow (Element_t scalar, InputIterator vectorBegin, 
					  int row)
{
  assert(!hasBeenCanceled);
  this->reducePermutations();

  Element_t * currentRowElement = data + row;
  for (int column = 0; column < numColumns; ++column) {
    *currentRowElement += scalar * (*vectorBegin);
    ++vectorBegin;
    currentRowElement += numRows;
  }
}
					  

template <class Element_t, class Alloc>
void 
LUCancelFullMatrix<Element_t, Alloc>::
addScalarTimesRowToRow (Element_t scalar, int row1, int row2)
{
  assert(!hasBeenCanceled);

  Element_t * currentRow1Element = data + row1;
  Element_t * currentRow2Element = data + row2;

  for (int column = 0; column < numColumns; ++column) {
    *currentRow2Element += scalar * (*currentRow1Element);
    currentRow1Element += numRows;
    currentRow2Element += numRows;
  }
}


template <class Element_t, class Alloc>
void
LUCancelFullMatrix<Element_t, Alloc>::
cancelRow (int row, int pivotRow, Element_t scalar)
{
  Element_t * currentRowElement = data + row + pivotRow * numRows;
  Element_t * currentPivotRowElement = cancelor->data + pivotRow 
    + pivotRow * cancelor->numRows;

  for (int column = pivotRow; column < numColumns; ++column) {
    *currentRowElement += scalar * (*currentPivotRowElement);
    currentRowElement += numRows;
    currentPivotRowElement += cancelor->numRows;
  }

  setElement(row, pivotRow, -scalar);
}

