/* MatrixSelectionMask.cc
 * ----------------------
 * Implements MatrixSelectionMask.h
 *
 * Written by Patrick Perry
 * Original Version on August 20, 2003
 *
 * $Id: MatrixSelectionMask.cc,v 1.1.1.1 2005/03/18 23:36:23 silva Exp $
 * $Log: MatrixSelectionMask.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:23  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.7  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.6  2003/11/22 06:54:14  patperry
 * lotsa fixes.
 *
 * Revision 1.5  2003/10/28 06:13:46  patperry
 * Made everything compile.
 *
 * Revision 1.4  2003/10/28 04:57:53  patperry
 * Work on preliminary version of MatrixSelectionMask.
 *
 * Revision 1.3  2003/10/27 01:09:20  patperry
 * Started work on GeomSparseMatrix.
 * Preliminary work on MatrixSelectionMask and SelectionMaskColumnIterator.
 * Doesn't compile yet.
 *
 *
 */

#include <algorithm>
#include <iterator>


template <class Element_t, class ColumnIterator_t, class Alloc>
template <class InputIterator1, class InputIterator2>
MatrixSelectionMask<Element_t, ColumnIterator_t, Alloc>::
MatrixSelectionMask (const Matrix<Element_t, ColumnIterator_t, Alloc>& matrix, 
				 InputIterator1 rowsBegin, InputIterator1 rowsEnd,
				 InputIterator2 columnsBegin, InputIterator2 columnsEnd)
  : Matrix<Element_t, SelectionMaskColumnIterator<Element_t, 
										ColumnIterator_t, Alloc>, 
		 Alloc>
      (std::distance(rowsBegin, rowsEnd),
	  std::distance(columnsBegin, columnsEnd)),
    matrix(matrix),
    numSelectionRows(std::distance(rowsBegin, rowsEnd)), 
    rows(IntAlloc.allocate(numSelectionRows)),
    numSelectionColumns(std::distance(columnsBegin, columnsEnd)),
    columns(IntAlloc.allocate(numSelectionColumns))
{
  std::copy(rowsBegin, rowsEnd, rows);
  std::copy(columnsBegin, columnsEnd, columns);
}


template <class Element_t, class ColumnIterator_t, class Alloc>
MatrixSelectionMask<Element_t, ColumnIterator_t, Alloc>::
~MatrixSelectionMask ()
{
}


template <class Element_t,  class ColumnIterator_t, class Alloc>
Element_t
MatrixSelectionMask<Element_t, ColumnIterator_t, Alloc>::
getElement (int i, int j) const
{
  if (rowPermutationInverse) {
    i = rowPermutationInverse[i];
  }
  if (columnPermutationInverse) {
    j = columnPermutationInverse[j];
  }

  return matrix.getElement(rows[i], columns[j]);
}


template <class Element_t,  class ColumnIterator_t, class Alloc>
typename 
MatrixSelectionMask<Element_t, ColumnIterator_t, Alloc>::ColumnIterator
MatrixSelectionMask<Element_t, ColumnIterator_t, Alloc>::
getColumnBegin (int column) const
{
  ColumnIterator_t begin = matrix.getColumnBegin(columns[column]);

  if (numRows) {
    begin += rows[0];
  }

  SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>
    result(begin, numSelectionRows, rows, rowPermutationInverse, 0);

  return result;
}


template <class Element_t,  class ColumnIterator_t, class Alloc>
typename 
MatrixSelectionMask<Element_t, ColumnIterator_t, Alloc>::ColumnIterator
MatrixSelectionMask<Element_t, ColumnIterator_t, Alloc>::
getColumnEnd (int column) const
{
  ColumnIterator_t end = matrix.getColumnEnd(columns[column]);

  if (numRows) {
    end += rows[numRows - 1];
  }

  SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>
    result(end, numSelectionRows, rows, rowPermutationInverse, 
		 numSelectionRows);
  
  return result;
}

