/* MatrixSelectionMask.h
 * ---------------------
 * Allows created a new matrix by selecting a subset of the rows
 * and columns of an existing matrix.
 *
 * Written by Patrick Perry
 * Original Version on August 20, 2003
 *
 * $Id: MatrixSelectionMask.h,v 1.2 2005/11/02 01:59:52 patperry Exp $
 * $Log: MatrixSelectionMask.h,v $
 * Revision 1.2  2005/11/02 01:59:52  patperry
 * The last (?) gcc4.0 fixes\!\!\!
 *
 * Revision 1.1.1.1  2005/03/18 23:36:23  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.1  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.6  2003/11/22 06:54:14  patperry
 * lotsa fixes.
 *
 * Revision 1.5  2003/10/28 06:13:46  patperry
 * Made everything compile.
 *
 * Revision 1.4  2003/10/28 04:57:53  patperry
 * Work on preliminary version of MatrixSelectionMask.
 *
 * Revision 1.3  2003/10/27 01:09:20  patperry
 * Started work on GeomSparseMatrix.
 * Preliminary work on MatrixSelectionMask and SelectionMaskColumnIterator.
 * Doesn't compile yet.
 *
 *
 */

#ifndef _MATRIXSELECTIONMASK_H
#define _MATRIXSELECTIONMASK_H

#include <memory>
#include <vector>
#include "RowColumnIterator.h"
#include "Matrix.h"

template <class Element_t, class ColumnIterator_t, 
		class Alloc = std::allocator<void> >
class MatrixSelectionMask;
#include "SelectionMaskColumnIterator.h"


/**
 * Class that "masks" one matrix to create another.  This does
 * not store any data, but facilitates an easy interface for logical
 * submatrices of a given matrix.
 */
template <class Element_t, class ColumnIterator_t, class Alloc>
class MatrixSelectionMask 
  : public Matrix<Element_t, 
			   SelectionMaskColumnIterator<Element_t, 
									 ColumnIterator_t, Alloc>, 
			   Alloc>
{
public:
  //! column iterator type
  typedef typename Matrix<Element_t, 
			  SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>,
			  Alloc>::ColumnIterator ColumnIterator;

private:

  //! the matrix this is masking
  const Matrix<Element_t, ColumnIterator_t, Alloc>& matrix;

  //! the number of rows in the mask
  int numSelectionRows;

  //! the rows in the mask
  int * rows;

  //! the number of columns in the mask
  int numSelectionColumns;

  //! the columns in the mask
  int * columns;

  using Matrix<Element_t, 
			SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>,
			Alloc>::IntAlloc;
  using Matrix<Element_t, 
			SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>,
			Alloc>::ElementAlloc;
  using Matrix<Element_t, 
			SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>,
			Alloc>::numRows;
  using Matrix<Element_t, 
			SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>,
			Alloc>::numColumns;
  using Matrix<Element_t, 
			SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>,
			Alloc>::rowPermutationInverse;
  using Matrix<Element_t, 
			SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>,
			Alloc>::columnPermutationInverse;

public:

  /**
   * Constructor.   Creates a MatrixSelectionMask by using the given rows and
   * columns of the passed-in matrix.
   *
   * \param matrix the matrix to mask.
   * \param rowsBegin an int iterator to the begin of the rows.
   * \param rowsEnd an int iterator to the end of the rows.
   * \param columnsBegin an int iterator to the begin of the columns.
   * \param columnsEnd an int iterator to the end of the columns.
   */
  template <class InputIterator1, class InputIterator2>
  MatrixSelectionMask (const Matrix<Element_t, ColumnIterator_t, Alloc>& matrix, 
				   InputIterator1 rowsBegin, InputIterator1 rowsEnd,
				   InputIterator2 columnsBegin, InputIterator2 columnsEnd);

  /**
   * Destructor.
   */
  virtual ~MatrixSelectionMask ();

  /**
   * Returns the appropriate element.
   *
   * \param i the row index of the element.
   * \param j the column index of the element.
   * \returns the element at (i, j).
   */
  Element_t getElement (int i, int j) const;

  /**
   * Get a column iterator to the begin of a column.  Note that the
   * iterator is read only.
   *
   * \param column the index of the column to get.
   * \returns a ColumnIterator to the begin of the requested column.
   */
  ColumnIterator getColumnBegin (int column) const;

  /**
   * Get a column iterator to the end of a column.
   *
   * \param column the index of the column to get.
   * \returns a ColumnIterator to the end of the requested column.
   */
  ColumnIterator getColumnEnd (int column) const;
  
};


// get function definitions
#include "MatrixSelectionMask.cc"


#endif // _MATRIXSELECTIONMASK_H
