// NerveSimplex.cc
// ---------------
// Implements NerveSimplex.h
//
// Author: Patrick Perry
// Date:   July 8, 2003
//

#ifndef _NERVESIMPLEX_CC
#define _NERVESIMPLEX_CC


#include <algorithm>
#include <iterator>
#include "NerveSimplex.h"


const std::set<int>& 
NerveSimplex::
getRows () const
{
  return rows;
}
 

const std::set<int>& 
NerveSimplex::
getColumns () const
{
  return columns;
}
 

int
NerveSimplex::
getDimension () const
{
  return dimension;
}


int
NerveSimplex::
getID () const
{
  return id;
}


const std::set<int>&
NerveSimplex::
getSimplexLabel () const
{
  return simplexLabel;
}


int
NerveSimplex::
getNumFaces () const
{
  return faces.size();
}


NerveSimplex::const_iterator
NerveSimplex::
facesBegin () const
{
  return faces.begin();
}


NerveSimplex::const_iterator
NerveSimplex::
facesEnd () const
{
  return faces.end();
}


int
NerveSimplex::
getNumDimensionNFaces (int n) const
{
  int codimension = highestSimplexDimension - n;

  return (faceDimensionOffsets[codimension + 1] -
		faceDimensionOffsets[codimension]);
}


NerveSimplex::const_iterator
NerveSimplex::
dimensionNFacesBegin (int n) const
{
  int codimension = highestSimplexDimension - n;

  return faces.begin() + faceDimensionOffsets[codimension];
}


NerveSimplex::const_iterator
NerveSimplex::
dimensionNFacesEnd (int n) const
{
  int codimension = highestSimplexDimension - n;

  return faces.begin() + faceDimensionOffsets[codimension + 1];
}


int 
NerveSimplex::
getNumCofaces () const
{
  return cofaces.size();
}


NerveSimplex::const_iterator 
NerveSimplex::
cofacesBegin () const
{
  return cofaces.begin();
}


NerveSimplex::const_iterator 
NerveSimplex::
cofacesEnd () const
{
  return cofaces.end();
}


int 
NerveSimplex::
getNumDimensionNCofaces (int n) const
{
  int codimension = highestSimplexDimension - n;

  return (cofaceDimensionOffsets[codimension + 1] 
		- cofaceDimensionOffsets[codimension]);
}


NerveSimplex::const_iterator 
NerveSimplex::
dimensionNCofacesBegin (int n) const
{
  int codimension = highestSimplexDimension - n;

  return cofaces.begin() + cofaceDimensionOffsets[codimension];
}


NerveSimplex::const_iterator 
NerveSimplex::
dimensionNCofacesEnd (int n) const
{
  int codimension = highestSimplexDimension - n;

  return cofaces.begin() + cofaceDimensionOffsets[codimension + 1];
}


std::ostream&
NerveSimplex::
put (std::ostream& s) const
{
  s << "Simplex of dimension " << getDimension() << "\n"
    << "Rows: { ";
  std::copy(rows.begin(), rows.end(), 
		  std::ostream_iterator<int>(s, " "));
  s  << "}\nColumns: { ";
  std::copy(columns.begin(), columns.end(), 
		  std::ostream_iterator<int>(s, " "));
  s << "}\n";

  return s;
}


NerveSimplex::
NerveSimplex ()
{
}


NerveSimplex::
~NerveSimplex ()
{
  delete[] faceDimensionOffsets;
  delete[] cofaceDimensionOffsets;
}


bool operator< (const NerveSimplex& x, const NerveSimplex& y)
{
  return (x.getID() < y.getID());
}


std::ostream& operator<< (std::ostream& s, const NerveSimplex& simplex)
{
  return simplex.put(s);
}


#endif // _NERVESIMPLEX_CC
