/* OffDiagonalBlock.cc
 * -------------------
 * Implements OffDiagonalBlock.h
 *
 * Written by Patrick Perry
 * Original Version on October 24, 2003
 *
 * $Id: OffDiagonalBlock.cc,v 1.1.1.1 2005/03/18 23:36:25 silva Exp $
 * $Log: OffDiagonalBlock.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:25  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.7  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.6  2003/11/30 05:36:29  patperry
 * more bugfixes
 *
 * Revision 1.5  2003/11/30 00:24:43  patperry
 * fixed reduction bugs.  inserted printfs
 *
 * Revision 1.4  2003/11/22 06:54:14  patperry
 * lotsa fixes.
 *
 * Revision 1.3  2003/10/28 06:13:46  patperry
 * Made everything compile.
 *
 * Revision 1.2  2003/10/28 04:43:51  patperry
 * Preliminary version of SelectionMaskColumnIterator.
 * Copy constructors for all full matrix types.
 *
 * Revision 1.1  2003/10/26 00:24:51  patperry
 * Preliminary Version of OffDiagonalBlock.  Deleted unnecessary files.
 *
 *
 */

template <class Element_t, class Alloc>
OffDiagonalBlock<Element_t, Alloc>::
OffDiagonalBlock (const DiagonalBlock * rowBlock,
			   const DiagonalBlock * columnBlock)
  : LUCancelFullMatrix<Element_t, Alloc>(rowBlock, columnBlock),
    rowID(rowBlock->getID()), columnID(columnBlock->getID())
{
}


template <class Element_t, class Alloc>
template <class ColumnIterator_t, class Alloc1>
OffDiagonalBlock<Element_t, Alloc>::
OffDiagonalBlock (const Matrix<Element_t, ColumnIterator_t, Alloc1>& matrix,
			   const DiagonalBlock * rowBlock, 
			   const DiagonalBlock * columnBlock)
  : LUCancelFullMatrix<Element_t, Alloc>(matrix, rowBlock, columnBlock),
    rowID(rowBlock->getID()), columnID(columnBlock->getID())
{
}
    

template <class Element_t, class Alloc>
OffDiagonalBlock<Element_t, Alloc>::
~OffDiagonalBlock ()
{
}


template <class Element_t, class Alloc>
int
OffDiagonalBlock<Element_t, Alloc>::
getRowID () const
{
  return rowID;
}


template <class Element_t, class Alloc>
int
OffDiagonalBlock<Element_t, Alloc>::
getColumnID () const
{
  return columnID;
}


template <class Element_t, class Alloc>
void
OffDiagonalBlock<Element_t, Alloc>::
addColumnFace (OffDiagonalBlock * face)
{
  if (face != NULL) {
    columnFaces[face->getRowID()] = face;
  }
}


template <class Element_t, class Alloc>
template <class InputIterator>
void
OffDiagonalBlock<Element_t, Alloc>::
addColumnFaces (InputIterator begin, InputIterator end)
{
  for (InputIterator it = begin; it != end; ++it) {
    if ((*it) != NULL) {
	 columnFaces[(*it)->getRowID()] = (*it);
    }
  }
}


template <class Element_t, class Alloc>
void
OffDiagonalBlock<Element_t, Alloc>::
addRowFace (OffDiagonalBlock * face)
{
  rowFaces.push_back(face);
}


template <class Element_t, class Alloc>
template <class InputIterator>
void
OffDiagonalBlock<Element_t, Alloc>::
addRowFaces (InputIterator begin, InputIterator end)
{
  rowFaces.insert(rowFaces.end(), begin, end);
}


template <class Element_t, class Alloc>
void
OffDiagonalBlock<Element_t, Alloc>::
cancelRow (int row, int pivotRow, Element_t scalar)
{
  LUCancelFullMatrix<Element_t, Alloc>::cancelRow(row, pivotRow, scalar);
  
  for (typename std::vector<OffDiagonalBlock *>::iterator it 
	    = rowFaces.begin(); it != rowFaces.end(); ++it) {
    (*it)->addScalarTimesRowFromBlockToRow(scalar, pivotRow, columnID, row);
  }
}


template <class Element_t, class Alloc>
void
OffDiagonalBlock<Element_t, Alloc>::
addScalarTimesRowFromBlockToRow (Element_t scalar, int blockRow,
						   int blockID, int row)
{
  typename std::map<int, OffDiagonalBlock *>::iterator block =
    columnFaces.find(blockID);

  if (block != columnFaces.end()) {
    const OffDiagonalBlock * blockMatrix = (block->second);

    addScalarTimesVectorToRow (scalar, blockMatrix->getRowBegin(blockRow), 
						 row);
  }
}
