// Partition.h
// -----------
// Partitions a list of indices by assigning a label 
// {-1,0,...,numGroups-1} to each index in 
// {0,...,groupsList.length-1}. -1 means index is not part 
// of the partition.
//
// Author: Erik Carlsson
// Date:   August 27, 2003
//

#ifndef _PARTITION_H
#define _PARTITION_H

#include "IndexList.h"

class Partition
{
private:
  int numGroups;
  int numElems;
  IndexList groupings;
  IndexList* groupList;

public:
  Partition();
  Partition(const Partition& partition);
  Partition(int numGroups, const IndexList& groupings);
  Partition(int numGroups, const IndexList& groupings, IndexList* groupList);
  ~Partition();
  void setVals(int numGroups, const IndexList& groupings);
  void setVals(const Partition& partition);
  void setElementAt(int index, int val);
  void updateGroups();
  void display() const;
  IndexList getElemsInGroup(int group) const; //returns an IndexList of all
  //indices with label 'group'. These lists are stored, no no search is done.
  int getGroupFromElem(int elem); //returns the label associated with 'elem'.
  int getNumGroups() const;
  int getNumElems() const;
  int getMaxIndex() const;
  void markWith(const IndexList& markerGroup, int length);
  void intersect(IndexList indexList);
  void setDiff(IndexList indexList);
  void elimEmptyGroup(int groupNum);
  void restrict(IndexList indexList);

private:
  void buildGroups();
  void refineGroupings();
};

#endif // _PARTITION_H
