/* SelectionMaskColumnIterator.cc
 * ------------------------------
 * Implements SelectionMaskColumnIterator.h
 *
 * Written by Patrick Perry
 * Original Version on October 26, 2003
 *
 * $Id: SelectionMaskColumnIterator.cc,v 1.1.1.1 2005/03/18 23:36:27 silva Exp $
 * $Log: SelectionMaskColumnIterator.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:27  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.4  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.3  2003/10/28 06:13:46  patperry
 * Made everything compile.
 *
 * Revision 1.2  2003/10/28 04:43:51  patperry
 * Preliminary version of SelectionMaskColumnIterator.
 * Copy constructors for all full matrix types.
 *
 * Revision 1.1  2003/10/27 01:09:20  patperry
 * Started work on GeomSparseMatrix.
 * Preliminary work on MatrixSelectionMask and SelectionMaskColumnIterator.
 * Doesn't compile yet.
 *
 *
 */

template <class Element_t, class ColumnIterator_t, class Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
SelectionMaskColumnIterator ()
  : RowColumnIterator<Element_t, Alloc>(),
    numRows(0), rows(NULL), rowPermutationInverse(NULL)
{
}


template <class Element_t, class ColumnIterator_t, class Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
SelectionMaskColumnIterator (ColumnIterator_t columnIterator,
					    int numRows, const int * rows,
					    const int * rowPermutationInverse,
					    int logicalPosition)
  : RowColumnIterator<Element_t, Alloc>(logicalPosition),
    columnIterator(columnIterator), numRows(numRows), rows(rows), 
    rowPermutationInverse(rowPermutationInverse)
{
}


template <class Element_t, class ColumnIterator_t, class Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
~SelectionMaskColumnIterator ()
{
}


template <class Element_t, class ColumnIterator_t, class Alloc>
Element_t 
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator* ()
{
  return *columnIterator;
}


template <class Element_t, class ColumnIterator_t, class Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>&
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator++ ()
{
  ++logicalPosition;

  if ((logicalPosition < numRows) && (logicalPosition > 0)) {
    if (!rowPermutationInverse) {
	 columnIterator += rows[logicalPosition] - rows[logicalPosition - 1];
    } else {
	 columnIterator += (rows[rowPermutationInverse[logicalPosition]]
					- rows[rowPermutationInverse[logicalPosition - 1]]);
    }
  }
 
  return *this;
}


template <class Element_t, class ColumnIterator_t, class Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator++ (int post)
{
  SelectionMaskColumnIterator result = *this;
  ++logicalPosition;

  return result;
}


template <class Element_t, class ColumnIterator_t, class Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>&
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator-- ()
{
  --logicalPosition;

  if ((logicalPosition < numRows - 1) && (logicalPosition >= 0)) {
    if (!rowPermutationInverse) {
	 columnIterator -= (rows[logicalPosition + 1] - rows[logicalPosition]);
    } else {
	 columnIterator -= (rows[rowPermutationInverse[logicalPosition + 1]]
					- rows[rowPermutationInverse[logicalPosition]]);
    }
  }

  return *this;
}


template <class Element_t, class ColumnIterator_t, class Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator-- (int post)
{
  SelectionMaskColumnIterator result = *this;
  --logicalPosition;

  return result;
}


template <class Element_t, class ColumnIterator_t, class Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>&
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator+= (int n)
{
  int oldLogicalPosition = logicalPosition;
  logicalPosition += n;

  n = std::min(n, numRows - 1);
  n = std::max(n, 0);
  
  if (!rowPermutationInverse) {
    columnIterator += rows[oldLogicalPosition + n] - rows[oldLogicalPosition];
  } else {
    columnIterator += (rows[rowPermutationInverse[oldLogicalPosition + n]]
				   - rows[rowPermutationInverse[oldLogicalPosition]]);
  }

  return *this;
}


template <class Element_t, class ColumnIterator_t, class Alloc>
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>&
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator-= (int n)
{
  return ((*this) += (-n));
}


template <class Element_t, class ColumnIterator_t, class Alloc>
int 
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator- (const SelectionMaskColumnIterator& x) const
{
  return (logicalPosition - x.logicalPosition);
}


template <class Element_t, class ColumnIterator_t, class Alloc>
Element_t 
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator[] (int n) const
{
  if (!rowPermutationInverse) {
    return (columnIterator[rows[logicalPosition + n] - rows[logicalPosition]]);
  } else {
    return (columnIterator[rows[rowPermutationInverse[logicalPosition + n]] 
					  - rows[rowPermutationInverse[logicalPosition]]]);
  }
}


template <class Element_t, class ColumnIterator_t, class Alloc>
bool 
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator== (const SelectionMaskColumnIterator& x) const
{
  return (logicalPosition == x.logicalPosition);
}


template <class Element_t, class ColumnIterator_t, class Alloc>
bool 
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator!= (const SelectionMaskColumnIterator& x) const
{
  return (logicalPosition != x.logicalPosition);
}


template <class Element_t, class ColumnIterator_t, class Alloc>
bool 
SelectionMaskColumnIterator<Element_t, ColumnIterator_t, Alloc>::
operator< (const SelectionMaskColumnIterator& x) const
{
  return (logicalPosition < x.logicalPosition);
}

