/* SelectionMaskColumnIterator.h
 * -----------------------------
 * Written by Patrick Perry
 * Original Version on October 26, 2003 (my 22nd birthday!)
 *
 * $Id: SelectionMaskColumnIterator.h,v 1.2 2005/11/02 01:59:52 patperry Exp $
 * $Log: SelectionMaskColumnIterator.h,v $
 * Revision 1.2  2005/11/02 01:59:52  patperry
 * The last (?) gcc4.0 fixes\!\!\!
 *
 * Revision 1.1.1.1  2005/03/18 23:36:27  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.1  2004/01/15 07:13:36  patperry
 * Changed file extensions.
 *
 * Revision 1.2  2003/10/28 06:13:46  patperry
 * Made everything compile.
 *
 * Revision 1.1  2003/10/27 01:09:20  patperry
 * Started work on GeomSparseMatrix.
 * Preliminary work on MatrixSelectionMask and SelectionMaskColumnIterator.
 * Doesn't compile yet.
 *
 *
 */

#ifndef _SELECTIONMASKCOLUMNITERATOR_H
#define _SELECTIONMASKCOLUMNITERATOR_H

#include "RowColumnIterator.h"

template <class Element_t, class ColumnIterator_t, class Alloc>
class SelectionMaskColumnIterator;
#include "MatrixSelectionMask.h"


/**
 * Column iterator class for a matrix selection mask.
 */
template <class Element_t, class ColumnIterator_t, class Alloc>
class SelectionMaskColumnIterator 
  : public RowColumnIterator<Element_t, Alloc>
{
  //! the underlying column iterator
  ColumnIterator_t columnIterator;

  //! the number of rows in the selection mask
  int numRows;

  //! the rows in the section mask
  const int * rows;

  //! the inverse of the row permutation
  const int * rowPermutationInverse;

protected:
  
  using RowColumnIterator<Element_t, Alloc>::logicalPosition;

public:

  /**
   * Constructor.  Creates an iterator pointing to nowhere.
   */
  SelectionMaskColumnIterator ();

private:
  /**
   * Constructor.  Creates an iterator with the given data and 
   * row permutation, pointing to the given position.  This is a private 
   * function.
   * 
   * \param data the column data, stored in an array.
   * \param rowPermutationInverse the row permutation for the column.
   * \param logicalPosition the logical position of the iterator.
   */
  SelectionMaskColumnIterator (ColumnIterator_t columnIterator,
						 int numRows, const int * rows,
						 const int * rowPermutationInverse,
						 int logicalPosition);

public:

  /**
   * Destructor.
   */
  ~SelectionMaskColumnIterator ();

  /**
   * De-refernce operator.
   *
   * \returns the value pointed to by the iterator.
   */
  Element_t operator* ();

  /**
   * Pre-increment operator.  Increments the iterator.
   *
   * \returns the iterator at (this + 1).
   */
  SelectionMaskColumnIterator& operator++ ();

  /**
   * Post-increment operator.
   *
   * \param post dummy argument.
   * \returns this iterator before incrementing.
   */
  SelectionMaskColumnIterator operator++ (int post);

  /**
   * Pre-decrement operator.  Decrements the iterator.
   *
   * \returns the iterator at (this - 1).
   */
  SelectionMaskColumnIterator& operator-- ();

  /**
   * Post-decrement operator.
   *
   * \param post dummy argument.
   * \returns this iterator before decrementing.
   */
  SelectionMaskColumnIterator operator-- (int post);

  /**
   * Forward-advance operator.  Increments the iterator by n.
   *
   * \param n an integer.
   * \returns this after it has been incremented.
   */
  SelectionMaskColumnIterator& operator+= (int n);

  /**
   * Backward-reverse operator.  Decrements the iterator by n.
   *
   * \param n an integer.
   * \returns this after it has been decremented.
   */
  SelectionMaskColumnIterator& operator-= (int n);

  /**
   * Distance operator.
   *
   * \param x another iterator.
   * \returns the distance between this and x.
   */
  int operator- (const SelectionMaskColumnIterator& x) const;

  /**
   * Index operator.
   *
   * \param n an integer.
   * \returns the value at this[n].
   */
  Element_t operator[] (int n) const;

  /**
   * Equals comparator.
   *
   * \param x iterator to compare this to.
   * \returns (*this) == x.
   */
  bool operator== (const SelectionMaskColumnIterator& x) const;

  /**
   * Not-Equals comparator.
   *
   * \param x iterator to compare this to.
   * \returns (*this) != x.
   */
  bool operator!= (const SelectionMaskColumnIterator& x) const;

  /**
   * Less-than comparator.
   *
   * \param x iterator to compare this to.
   * \returns (*this) < x.
   */
  bool operator< (const SelectionMaskColumnIterator& x) const;


  //! this is a friend of it's corresponding matrix type.
  friend class MatrixSelectionMask<Element_t, ColumnIterator_t, Alloc>;

};

// get function definitions
#include "SelectionMaskColumnIterator.cc"


#endif // _SELECTIONMASKCOLUMNITERATOR_H
