/* attach.cc
 * ---------
 * Adds simplices to a plex object.
 *
 * $Id: attach.cc,v 1.2 2005/10/24 16:20:25 patperry Exp $
 * $Log: attach.cc,v $
 * Revision 1.2  2005/10/24 16:20:25  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:36:47  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.8  2004/06/21 17:29:40  patperry
 * Added maxdim option to attach
 *
 * Revision 1.7  2004/04/03 23:05:46  patperry
 * Bugfix and document attach
 *
 * Revision 1.6  2004/02/26 06:49:24  patperry
 * Converted mexfiles to use new scomplex interface
 *
 * Revision 1.5  2004/02/09 06:30:44  patperry
 * Got rid of MatlabAllocator.  A few small bugfixes.
 *
 * Revision 1.4  2004/01/28 09:57:15  patperry
 * Changed the +1 offset in how simplices are stored.
 *
 * Revision 1.3  2004/01/15 07:16:51  patperry
 * moved support to matlab-support
 *
 * Revision 1.2  2003/11/18 08:57:38  patperry
 * Added support code.
 *
 * Revision 1.1  2003/11/16 07:15:21  patperry
 * added attach
 *
 *
 */

#include "PlexObject.h"
#include "MxUtility.h"

extern "C" {
#include "mex.h"
#include "matrix.h"
}

#include <set>

extern "C" {

void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  SimplicialComplex_t * scomplex;
  SimplicialComplex_t * result;
  double * values;
  int k;
  int maxDim;
  int numSimplices;

  // check input
  if ((nrhs != 2) && (nrhs != 3)) {
    mexErrMsgTxt("Two or three inputs required.");
  } else if (nlhs > 1) {
    mexErrMsgTxt("Too many output arguments.");
  } else if (!IsPlexObject(prhs[0])) {
    mexErrMsgTxt("First argument must be a valid plex object.");
  } else if (!mxIsDouble(prhs[1]) || mxIsComplex(prhs[1])) {
    mexErrMsgTxt("Second argument must be noncomplex real.");
  } else {
    scomplex = GetSimplicialComplex(prhs[0]);
    values = mxGetPr(prhs[1]);
    k = mxGetM(prhs[1]) - 1;
    numSimplices = mxGetN(prhs[1]);

    if (k < 0) {
	 mexErrMsgTxt("Second argument must have at least 1 row.");
    }

    if (nrhs == 3) {
	 maxDim = GetIntFromMxArray(prhs[2]);
    } else {
	 maxDim = k;
    }
  }

  // set up output
  plhs[0] = AllocPlexObject();
  result = new SimplicialComplex_t(*scomplex);
  SetSimplicialComplex(plhs[0], result);

  for (int i = 0; i < numSimplices; ++i) {
    std::set<int> label;

    for (int j = 0; j <= k; ++j) {
	 label.insert(static_cast<int>(*values++));
    }

    if (static_cast<int>(label.size()) == k + 1) {
	 result->addFaces(k, label.begin(), maxDim);
    }
  }
}

}
