function b = betti (C, k)

%BETTI   rational Betti numbers of a simplicial complex
%   b = BETTI(C, k) returns the k-th Betti number of the simplicial
%   complex C, computed with rational coefficients.
%
%   This is a shortcut for the sequence
%
%      >> H = harmonic(C, k);
%      >> b = size(H, 2);
%
%   so if H itself is required, it becomes wasteful to make a separate
%   call to BETTI.
%
%   Warning: for large complexes, rounding errors in floating-point
%   arithmetic may invalidate the results. It is usually preferably to
%   use BETTI2, which is calculated exactly.
%
%   See also HARMONIC, BETTI2, HOMOLOGY2.
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

error(nargchk(2, 2, nargin));

if (nargout > 1)
  error('Too many output arguments.')
end
if ~isnumeric(k) || (length(k) ~=1) || (k ~= floor(k)) ...
      || (isinf(k))
  error('Dimension must be an integer.')
end

% return 0 if k is out of range
if (k > dim(C)) | (k < 0)
  b = 0;

else
  b = size(harmonic(C, k), 2);
end
