function b = betti2 (C, k)

%BETTI2
%   b = BETTI2(C, k) returns the k-th Betti number of the simplicial
%   complex C, computed with mod 2 coefficients.
%
%   This is a shortcut for the sequence
%
%      >> H = homology2(C, k);
%      >> b = size(H, 2);
%
%   so if H itself is required, it becomes wasteful to make a separate
%   call to BETTI2.
%
%   See also BETTI, HARMONIC, HOMOLOGY2.
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]
error(nargchk(2, 2, nargin));

if (nargout > 1)
  error('Too many output arguments.')
end
if ~isnumeric(k) || (length(k) ~=1) || (k ~= floor(k)) ...
      || (isinf(k))
  error('Dimension must be an integer.')
end

% return 0 if k out of range
if (k < 0) | (k > dim(C))
  b = 0;

else
  %[H, W] = homology2(C, k);
  H = homology2(C, k);
  b = size(H, 2);
end
