/* boundary.cc
 * -----------
 * Returns the boundary map of a plex object.
 *
 * $Id: boundary.cc,v 1.2 2005/10/24 16:20:25 patperry Exp $
 * $Log: boundary.cc,v $
 * Revision 1.2  2005/10/24 16:20:25  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:36:48  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.1  2004/06/28 22:03:47  patperry
 * Added Plex Garbage Collector
 *
 *
 */

#include <algorithm>
#include "BoundaryMap.h"

#include "PlexObject.h"
#include "MxUtility.h"

extern "C" {
#include "mex.h"
#include "matrix.h"
}

extern "C" {

void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  const SimplicialComplex_t * scomplex;
  int k;
  mxArray * result;

  // check input and output
  if (nrhs != 2) {
    mexErrMsgTxt("Two inputs required.");
  } else if (nlhs > 1) {
    mexErrMsgTxt("Too many output arguments.");
  } else if (!IsPlexObject(prhs[0])) {
    mexErrMsgTxt("First argument must be a plex object.");
  } else if (!IsScalarMxArray(prhs[1])) {
    mexErrMsgTxt("Second argument must be a scalar.");
  } else {
    scomplex = GetSimplicialComplex(prhs[0]);
    k = GetIntFromMxArray(prhs[1]);

    if (k < 0) {
	 mexErrMsgTxt("Second argument must be non-negative.");
    } else if (k > scomplex->getDimension() + 1) {
	 mexErrMsgTxt("Second argument must be less than or equal to the dimension of the complex.");
    }
  }

  if ((k > 0) && (k < scomplex->getDimension() + 1)){
    BoundaryMap<double, Simplex_t> 
	 bmap(scomplex->simplicesBegin(k), scomplex->simplicesEnd(k),
		 scomplex->simplicesBegin(k - 1), scomplex->simplicesEnd(k - 1));
    
    int m = bmap.getNumRows();
    int n = bmap.getNumColumns();
    int nnz = bmap.getNumNonzeroElements();
    const double * pr = bmap.getDataPointer();
    const int * ir = bmap.getRowIndexPointer();
    const int * jc = bmap.getColumnOffsetPointer();

    result = mxCreateSparse(m, n, nnz, mxREAL);
    std::copy(pr, pr + nnz, mxGetPr(result));
    std::copy(ir, ir + nnz, mxGetIr(result));
    std::copy(jc, jc + n + 1, mxGetJc(result));
  } else if (k == 0){
    result = mxCreateSparse(0, scomplex->getNumSimplices(0) 
					   - scomplex->getNumDegenerateSimplices(0), 
					   0, mxREAL);
  } else {
    result = mxCreateSparse(scomplex->getNumSimplices(k - 1) 
					   - scomplex->getNumDegenerateSimplices(k - 1),
					   0, 0, mxREAL);
  }

  plhs[0] = result;
}

}
