function [C_f, k0] = chmapping(C, D, f, k)

%CHMAPPING   simplicial map induced from vertex map
%   C_f = CHMAPPING(C, D, f) returns the chain-map induced by a vertex
%   mapping f between two simplicial complexes, up to the highest
%   dimension in which the map is fully defined.
%
%   The map fails to be defined in dimension j if there is a j-simplex
%   of C which cannot be mapped to D.
%
%   C_f = CHMAPPING(C, D, f, k) does not compute beyond dimension k,
%   and may stop earlier.
%
%   These forms additionally return the stopping dimension k0:
%
%   [C_f, k0] = CHMAPPING(C, D, f)
%   [C_f, k0] = CHMAPPING(C, D, f, k)
%   
%   Input arguments:
%      C : plex object
%      D : plex object
%      f : n-by-2 matrix, where f(:,1) is a list of vertices of C, and
%          f(:,2) is the list of corresponding vertices of D.		
%
%   Output arguments:
%      C_f : vector cell array of length (k1+1), where C_f{d+1} is a
%            sparse matrix representing the chain map at dimension d.
%      k0  : non-negative integer, the stopping dimension
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

% $Id: chmapping.m,v 1.1.1.1 2005/03/18 23:36:49 silva Exp $
% $Log: chmapping.m,v $
% Revision 1.1.1.1  2005/03/18 23:36:49  silva
% Imported Sources
%
% Revision 1.4  2004/10/26 22:30:51  silva
%
% Improved help text.
%
% Revision 1.3  2004/10/24 07:28:46  silva
%
% Improved help text.
%
% Revision 1.2  2004/10/22 01:28:13  silva
%
% Improving help-text and adding tags.
%
% Revision 1.1.1.1  2004/09/25 22:04:09  patperry
% Imported sources
%
% Revision 1.1  2004/05/19 05:05:52  patperry
% Added doc and output option for chmapping
%
