/* chrank.cc
 * ---------
 * Returns the dimension of the chain group of a plex object.
 *
 * $Id: chrank.cc,v 1.1.1.1 2005/03/18 23:36:49 silva Exp $
 * $Log: chrank.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:49  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.8  2004/03/13 07:27:05  patperry
 * Fixed bugs in degenerate simpelx handling.
 *
 * Revision 1.7  2004/03/13 07:21:44  patperry
 * fixed degenerate simplex counting
 *
 * Revision 1.6  2004/02/26 06:49:24  patperry
 * Converted mexfiles to use new scomplex interface
 *
 * Revision 1.5  2004/02/09 06:30:44  patperry
 * Got rid of MatlabAllocator.  A few small bugfixes.
 *
 * Revision 1.4  2004/01/23 04:36:40  patperry
 * Cleaned up MATLAB support code.
 *
 * Revision 1.3  2004/01/15 07:16:51  patperry
 * moved support to matlab-support
 *
 * Revision 1.2  2003/11/18 08:57:38  patperry
 * Added support code.
 *
 * Revision 1.1  2003/11/16 03:45:55  patperry
 * implemented chrank
 *
 *
 */

#include "PlexObject.h"
#include "MxUtility.h"

extern "C" {
#include "mex.h"
#include "matrix.h"
}

extern "C" {

void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  SimplicialComplex_t * scomplex;
  int k;

  // check input and output
  if ((nrhs != 1) && (nrhs != 2)) {
    mexErrMsgTxt("One or two inputs required.");
  } else if (nlhs > 1) {
    mexErrMsgTxt("Too many output arguments.");
  } else if (!IsPlexObject(prhs[0])) {
    mexErrMsgTxt("First argument must be a plex object.");
  } else if ((nrhs == 2) && (!IsScalarMxArray(prhs[1]))) {
    mexErrMsgTxt("Second argument must be a scalar.");
  } else {
  
    scomplex = GetSimplicialComplex(prhs[0]);

    if (nrhs == 2) {
	 k = GetIntFromMxArray(prhs[1]);

	 if (k < 0) {
	   mexErrMsgTxt("Second argument must be non-negative.");
	 }
    }
  }


  if (nrhs == 2) {
    plhs[0] = mxCreateDoubleScalar(static_cast<double>
							(scomplex->getNumSimplices(k)
							 - scomplex->getNumDegenerateSimplices(k)));
  } else {
    int dimension = scomplex->getDimension();
    double * ranks;

    plhs[0] = mxCreateDoubleMatrix(1, dimension + 1, mxREAL);
    ranks = mxGetPr(plhs[0]);
    
    for (int i = 0; i <= dimension; ++i) {
	 ranks[i] = static_cast<double>(scomplex->getNumSimplices(i)
							  - scomplex->getNumDegenerateSimplices(i));
    }
  }
}

}
