/* display.cc
 * ----------
 * Pretty-print a plex object.
 *
 * $Id: display.cc,v 1.1.1.1 2005/03/18 23:36:49 silva Exp $
 * $Log: display.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:49  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.7  2004/03/13 07:21:44  patperry
 * fixed degenerate simplex counting
 *
 * Revision 1.6  2004/02/26 02:38:07  patperry
 * Updated display
 *
 * Revision 1.5  2004/02/09 06:30:44  patperry
 * Got rid of MatlabAllocator.  A few small bugfixes.
 *
 * Revision 1.4  2004/01/15 07:16:51  patperry
 * moved support to matlab-support
 *
 * Revision 1.3  2003/11/18 08:57:38  patperry
 * Added support code.
 *
 * Revision 1.2  2003/11/16 03:45:38  patperry
 * changed output for display
 *
 * Revision 1.1.1.1  2003/11/14 10:08:56  patperry
 * Initial version.
 *
 *
 */

#include "PlexObject.h"

extern "C" {
#include "mex.h"
#include "matrix.h"
}

extern "C" {

void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  SimplicialComplex_t * scomplex;

  // check input and output
  if (nrhs != 1) {
    mexErrMsgTxt("One input required.");
  } else if (nlhs != 0) {
    mexErrMsgTxt("No outputs should be given.");
  } else if (!IsPlexObject(prhs[0])) {
    mexErrMsgTxt("Input should be a plex object.");
  }
  
  scomplex = GetSimplicialComplex(prhs[0]);

  mexPrintf("\n%d-dimensional simplicial complex\n\n", 
		  scomplex->getDimension());
  mexPrintf("\t[ ");
  for (unsigned short i = 0; i <= scomplex->getDimension(); ++i) {
    mexPrintf("%d ", scomplex->getNumSimplices(i) 
		    - scomplex->getNumDegenerateSimplices(i));
  }
  mexPrintf("]\n\n");
}

}
