/* expand.cc
 * ---------
 * Does a Ripps expansion of a simplicial complex.
 *
 * $Id: expand.cc,v 1.1.1.1 2005/03/18 23:36:50 silva Exp $
 * $Log: expand.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:50  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.7  2004/09/15 18:14:15  patperry
 * Added "fromDimension" functionality for expand.
 *
 * Revision 1.6  2004/04/15 04:37:14  patperry
 * Bugfix and doc for expand, relative
 *
 * Revision 1.5  2004/02/26 06:49:24  patperry
 * Converted mexfiles to use new scomplex interface
 *
 * Revision 1.4  2004/02/09 06:30:44  patperry
 * Got rid of MatlabAllocator.  A few small bugfixes.
 *
 * Revision 1.3  2004/01/15 07:16:51  patperry
 * moved support to matlab-support
 *
 * Revision 1.2  2003/11/18 08:57:38  patperry
 * Added support code.
 *
 * Revision 1.1.1.1  2003/11/14 10:08:56  patperry
 * Initial version.
 *
 *
 */

#include "PlexObject.h"
#include "MxUtility.h"

extern "C" {
#include "mex.h"
#include "matrix.h"
}

extern "C" {

void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  const SimplicialComplex_t * scomplex;
  SimplicialComplex_t * result;
  int fromDimension;
  int toDimension;

  // check input and output
  if ((nrhs < 1) || (nrhs > 3)) {
    mexErrMsgTxt("One, two, or three inputs required.");
  } else if (nlhs > 1) {
    mexErrMsgTxt("Too many output arguments.");
  } else if (!IsPlexObject(prhs[0])) {
    mexErrMsgTxt("First argument must be a plex object.");
  } else if ((nrhs >= 2) && (!IsScalarMxArray(prhs[1]))) {
    mexErrMsgTxt("Second argument must be a scalar.");
  } else if ((nrhs == 3) && (!IsScalarMxArray(prhs[2]))) {
    mexErrMsgTxt("Third argument must be a scalar.");
  } else {
  
    scomplex = GetSimplicialComplex(prhs[0]);

    switch (nrhs) {
    case 1:
	 fromDimension = scomplex->getDimension();
	 toDimension = fromDimension + 1;
	 break;

    case 2:
	 fromDimension = scomplex->getDimension();
	 toDimension = GetIntFromMxArray(prhs[1]);
	 break;

    default:
	 fromDimension = GetIntFromMxArray(prhs[1]);
	 toDimension = GetIntFromMxArray(prhs[2]);
	 break;
    }
  }

  // set up output
  plhs[0] = AllocPlexObject();
  result = new SimplicialComplex_t(*scomplex);
  SetSimplicialComplex(plhs[0], result);

  result->rippsExpand(fromDimension, toDimension);
}

}
