function D = expand(C,k)

%EXPAND   induce higher-dimensional simplices
%   D = EXPAND(C, k0, k)
%   D = EXPAND(C, k)
%   D = EXPAND(C)
%
%   Input arguments:
%      C  : plex object
%      k0 : non-negative integer
%      k  : non negative integer, k0 < k
%
%   Output arguments:
%      D : plex object
%
%   D = EXPAND(C, k0, k) returns a simplicial complex which contains every
%   simplex in C as well as every i-simplex (k0 < i <= k) for which all
%   the k0-faces belong to C. In other words, D is the largest simplicial
%   complex having the same j-cells as C, for j <= k0 and j > k.
%   
%   A common use of EXPAND is to induce higher-dimensional cells of a
%   simplicial complex from a graph or other low-dimensional skeleton.
%
%   There are two simplified forms:
%
%      D = EXPAND(C, k) : defaults to k0 = DIM(C).
%      D = EXPAND(C)    : defaults to k0 = DIM(C), k = DIM(C)+1.
%
%   Beware that these last two forms can behave unexpectedly, if the
%   dimension of C is less than the expected value.
%
%   See also DIM, EXTEND.
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

