function F_prime = extend (C, F, k)

%EXTEND   induce filtration values over a simplicial complex C
%   F1 = EXTEND(C, F)
%   F1 = EXTEND(C, F, k)
%
%   Input arguments:
%      C  : plex object
%      F  : cell array, partial filtration of C
%
%   Output argument:
%      F1 : cell array, filtration or partial filtration of C
%
%   See PERSISTENCE for an explanation of filtrations.
%
%   F1 = EXTEND(C, F) extends the partial filtration F to the full set of
%   simplices of C. Each simplex is assigned the smallest filtration value
%   compatible with the filtration values defined by F. Equivalently, F1
%   assigns to each simplex the maximum of the filtration values already
%   assigned by F to its subsimplices.
% 
%   F1 = EXTEND(C, F, k) calculates F1 up to dimension k only.
%
%   See also EXPAND.
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

% $Id: extend.m,v 1.1.1.1 2005/03/18 23:36:50 silva Exp $
% $Log: extend.m,v $
% Revision 1.1.1.1  2005/03/18 23:36:50  silva
% Imported Sources
%
% Revision 1.4  2004/11/01 05:04:28  silva
%
% Improved help text.
%
% Revision 1.3  2004/10/26 22:30:51  silva
%
% Improved help text.
%
% Revision 1.2  2004/10/22 01:28:13  silva
%
% Improving help-text and adding tags.
%
% Revision 1.1.1.1  2004/09/25 22:04:09  patperry
% Imported sources
%
% Revision 1.1  2004/05/19 04:48:21  patperry
% Added doc for extend
%
