/* graph.cc
 * --------
 * Get the graph of a plex object.
 *
 * $Id: graph.cc,v 1.1.1.1 2005/03/18 23:36:50 silva Exp $
 * $Log: graph.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:50  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.2  2004/04/15 04:21:46  patperry
 * Fixed bugs in graph
 *
 * Revision 1.1  2004/04/08 08:21:49  patperry
 * Added graph mexfile
 *
 *
 */

#include <algorithm>
#include <map>
#include "PlexObject.h"

extern "C" {
#include "mex.h"
#include "matrix.h"
}

extern "C" {

void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  const SimplicialComplex_t * scomplex;
  int numVertices;
  int numEdges;
  std::map<int, int> vertexToIndex;

  // check input and output
  if (nrhs != 1) {
    mexErrMsgTxt("One input required.");
  } else if (nlhs > 1) {
    mexErrMsgTxt("Too many output arguments.");
  } 
  
  scomplex = GetSimplicialComplex(prhs[0]);
  numVertices = (scomplex->getNumSimplices(0) 
			  - scomplex->getNumDegenerateSimplices(0));
  numEdges = (scomplex->getNumSimplices(1) 
		    - scomplex->getNumDegenerateSimplices(1));

  SimplicialComplex_t::ConstSimplexIterator v_it = scomplex->simplicesBegin(0);
  SimplicialComplex_t::ConstSimplexIterator v_end = scomplex->simplicesEnd(0);
  int index = 0;

  while (v_it != v_end) {
    const Simplex_t * vertex = *v_it++;
    if (!(vertex->isDegenerate())) {
	 vertexToIndex[*(vertex->getLabel())] = index++;
    }
  }

  plhs[0] = mxCreateSparseLogicalMatrix(numVertices, numVertices, 
								2 * numEdges);
  mxLogical * pr = reinterpret_cast<mxLogical *>(mxGetData(plhs[0]));
  int * ir = mxGetIr(plhs[0]);
  int * jc = mxGetJc(plhs[0]);

  std::uninitialized_fill(pr, pr + 2 * numEdges, true);

  *jc = 0;
  v_it = scomplex->simplicesBegin(0);
  while (v_it != v_end) {
    const Simplex_t * vertex = *v_it++;
    if (!(vertex->isDegenerate())) {
	 int vertexLabel = *(vertex->getLabel());
	 mxLogical column[vertex->getNumCofaces()];
	 Simplex_t::ConstCofaceIterator e_it = vertex->cofacesBegin();
	 Simplex_t::ConstCofaceIterator e_end = vertex->cofacesEnd();

	 ++jc;
	 *jc = jc[-1];
	 
	 // note: no coface of a non-degenerate vertex is degenerate
	 while (e_it != e_end) {
	   const Simplex_t * edge = *e_it++;
	   Simplex_t::LabelIterator label = edge->getLabel();
	   int otherVertex;
	   
	   if (label[0] == vertexLabel) {
		otherVertex = label[1];
	   } else {
		otherVertex = label[0];
	   }
	   
	   *ir++ = vertexToIndex[otherVertex];
	   *jc = *jc + 1;
	 }

	 std::sort(ir - vertex->getNumCofaces(), ir);
    }
  }
  
}

}
