function H = harmonic (C, k)

%HARMONIC
%   H = HARMONIC(C, k) returns a matrix whose columns form an orthonormal
%   basis for the space of harmonic k-chains in C.
%
%   If v is a vector representing a closed k-chain for C (so the i-th
%   entry of v represents the coefficient for the i-th k-simplex of C)
%   then vH = (H * H' * v) returns the harmonic representative for the
%   homology class [v].
%
%   Warning: for large complexes, rounding errors in floating-point
%   arithmetic may invalidate the results.
%
%   See also BETTI, BETTI2, HOMOLOGY2.
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

error(nargchk(2, 2, nargin));

if (nargout > 1)
  error('Too many output arguments.')
end
if ~isnumeric(k) || (length(k) ~=1) || (k ~= floor(k)) ...
      || (isinf(k))
  error('Dimension must be an integer.')
end

L = laplacian(C, k);
H = null(full(L)); % replace this with an eigs calculation?
