/* intersect.cc
 * ------------
 * Take the intersections of simplicial complexes.
 *
 * $Id: intersect.cc,v 1.4 2005/10/24 16:20:25 patperry Exp $
 * $Log: intersect.cc,v $
 * Revision 1.4  2005/10/24 16:20:25  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.3  2005/06/15 22:46:18  patperry
 * No filtration crash in intersect fixed
 *
 * Revision 1.2  2005/05/03 22:34:13  patperry
 * Fixed intersect and union bugs
 *
 * Revision 1.1.1.1  2005/03/18 23:36:51  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.5  2004/05/28 05:58:36  patperry
 * Added filters to intersect
 *
 */

#include <functional>
#include "ComplexMap.h"
#include "PlexFiltration.h"
#include "PlexObject.h"
#include "IntersectFilter.h"


extern "C" {
#include "mex.h"
#include "matrix.h"
}

extern "C" {

void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  SimplicialComplex_t * inputScomplex[nrhs];
  Filtration_t * inputFiltration[nrhs];
  SimplicialComplex_t * outputScomplex;
  int numComplexes = 0;
  int minFiltrationDimension = 0;
  bool includeFiltrations = false;

  // check input and output
  if (nrhs  < 2) {
    mexErrMsgTxt("At least two inputs required.");
  } else {
    includeFiltrations = !IsPlexObject(prhs[1]);

    if (!includeFiltrations) {
	 for (int i = 0; i < nrhs; ++i) {
	   if (!IsPlexObject(prhs[i])) {
		mexErrMsgTxt("All arguments must be plex objects.");
	   } else {
		inputScomplex[i] = GetSimplicialComplex(prhs[i]);
	   }
	 }

	 numComplexes = nrhs;

    } else {
	 minFiltrationDimension = mxGetNumberOfElements(prhs[1]) - 1;

	 for (int i = 0; i < nrhs / 2; ++i) {
	   if (!IsPlexObject(prhs[2 * i])) {
		mexErrMsgTxt("Odd arguments must be plex objects.");
	   } else {
		inputScomplex[i] = GetSimplicialComplex(prhs[2 * i]);
	   }

	   if (!IsValidFiltration(*(inputScomplex[i]), prhs[2 * i + 1])) {
		mexErrMsgTxt("Even arguments must be filtrations.");
	   } else {
		inputFiltration[i] 
		  = ImportFiltration(*inputScomplex[i], prhs[2 * i + 1],
						 inputScomplex[i]->getDimension());
		minFiltrationDimension 
		  = std::min(minFiltrationDimension,
				   mxGetNumberOfElements(prhs[2*i + 1]) - 1);
	   }
	 }

	 numComplexes = nrhs / 2;
    }
  }

  outputScomplex = new SimplicialComplex_t(*inputScomplex[0]);

  for (int i = 1; i < numComplexes; ++i) {
    outputScomplex->intersectComplex(*inputScomplex[i]);
  }

  plhs[0] = AllocPlexObject();
  SetSimplicialComplex(plhs[0], outputScomplex);

  if (includeFiltrations) {
    std::vector<
    std::binder1st<
    std::const_mem_fun1_t<FiltrationValue_t, Filtration_t, SimplexHandle_t> > >
	 //std::unary_function<SimplexHandle_t, FiltrationValue_t> > 
	 filtrationPtrs;

    for (int i = 0; i < numComplexes; ++i) {
	 filtrationPtrs.push_back
	   (std::bind1st(std::mem_fun(&Filtration_t::operator()),
	 			  inputFiltration[i]));
    }
	 
    IntersectFilter<
      const SimplicialComplex_t, FiltrationValue_t,
	 std::binder1st<
	 std::const_mem_fun1_t<FiltrationValue_t, Filtration_t, 
	 SimplexHandle_t> > >
	 //std::unary_function<SimplexHandle_t, FiltrationValue_t> > 
    filter(filtrationPtrs.begin(), filtrationPtrs.end(),
		 inputScomplex, inputScomplex + numComplexes);

    plhs[1] = ExportFiltration(*outputScomplex, filter, 
						 minFiltrationDimension);
  }

}

}
