function H_f = mapping(C,D, C_f, k)

%MAPPING   homology map induced by a simplicial map
%   H_f = MAPPING(C, D, C_f, k)
%
%   Input arguments: 
%      C,D are plex objects, C_f is a chain-mapping (such as may be
%      produced by CHMAPPING), and k is a non-negative integer.
%
%   Output argument:
%      H_f is a d-by-c matrix which represents the map in k-dimensional
%      homology from C to D. Here c = BETTI(C,k) and d = BETTI(D,k).
%
%      This map is given in terms of the bases of harmonic chains computed
%      by Plex as HARMONIC(C,k), HARMONIC(D,k).
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

H_C = harmonic(C,k);
H_D = harmonic(D,k);

H_f = H_D' * C_f{k+1} * H_C;
