function H_f = mapping2(C,D, C_f, k)

%MAPPING2   mod 2 homology map induced by a simplicial map
%   H_f = MAPPING2(C,D, C_f, k)
%
%   Inputs: 
%     C,D are plex objects, C_f is a chain-mapping (such as may be
%     produced by CHMAPPING), and k is a non-negative integer.
%
%   Output:
%     H_f is a d-by-c matrix, where c = BETTI2(C,k) and d = BETTI2(D,k),
%     which represents the map in k-dimensional homology from C to D.
%     This map is given in terms of the homology bases computed by Plex in
%     the mod2 routines HOMOLOGY2(C,k), HOMOLOGY2(D,k).
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

%   [June.3.2000] -- preliminary version, modified [Jun.10.2001] for
%   mod 2 calculations.

[H_C, W_C] = homology2(C,k);
[H_D, W_D] = homology2(D,k);

H_f = W_D * C_f{k+1} * H_C;

