/* nbhood.cc
 * ---------
 * Returns the neighborhood (closed star) of a set of vertices in
 * a simplicial complex.
 *
 * $Id: nbhood.cc,v 1.1.1.1 2005/03/18 23:36:54 silva Exp $
 * $Log: nbhood.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:54  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.6  2004/03/09 09:12:46  patperry
 * Implemented nbhood
 *
 * Revision 1.5  2004/02/26 06:49:24  patperry
 * Converted mexfiles to use new scomplex interface
 *
 * Revision 1.4  2004/02/26 02:34:04  patperry
 * Fixed bugs in PlexObject
 *
 * Revision 1.3  2004/02/09 06:30:44  patperry
 * Got rid of MatlabAllocator.  A few small bugfixes.
 *
 * Revision 1.2  2004/01/30 23:58:01  patperry
 * Added nbhood function.
 *
 * Revision 1.1  2004/01/30 22:45:22  patperry
 * added nbhood
 *
 *
 */


extern "C" {
#include "/matlabdir/extern/include/mex.h"
#include "/matlabdir/extern/include/matrix.h"
}

#include <iterator>
#include <vector>
#include "PlexObject.h"
#include "VertexSet.h"


extern "C" {


/*   
 * D = NBHOOD(C,u)
 */
void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  SimplicialComplex_t * scomplex;
  SimplicialComplex_t * result;
  std::vector<int> vertexSet;
  std::back_insert_iterator<std::vector<int> > 
    vertexSetInserter(vertexSet);
  
  // check input and output
  if (nrhs != 2) {
    mexErrMsgTxt("Two inputs required.");
  } else if (nlhs > 1) {
    mexErrMsgTxt("Too many output arguments.");
  } else if (!IsPlexObject(prhs[0])) {
    mexErrMsgTxt("First argument must be a plex object.");
  } else if (!IsValidVertexSet(prhs[1])) {
    mexErrMsgTxt("Second argument must be a valid vertex set description.");
  }

  if (IsPlexObject(plhs[0])) {
    delete GetSimplicialComplex(plhs[0]);
  } else {
    plhs[0] = AllocPlexObject();
  }

  scomplex = GetSimplicialComplex(prhs[0]);
  GetVertexSetFromMxArray(prhs[1], scomplex, vertexSetInserter);

  result = scomplex->getNeighborhood(vertexSet.begin(), vertexSet.end());
  SetSimplicialComplex(plhs[0], result);
}

}
