/* restrict.cc
 * -----------
 * Returns the restriction of a set of vertices in a simplicial complex.
 *
 * Written by Patrick Perry
 * Initial Version on March 9, 2004
 *
 * $Id: restrict.cc,v 1.1.1.1 2005/03/18 23:36:56 silva Exp $
 * $Log: restrict.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:56  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.2  2004/04/15 04:43:51  patperry
 * Bugfix and doc restrict
 *
 * Revision 1.1  2004/03/09 09:16:14  patperry
 * Initial version of restrict.
 *
 */


extern "C" {
#include "/matlabdir/extern/include/mex.h"
#include "/matlabdir/extern/include/matrix.h"
}

#include <iterator>
#include <vector>
#include "PlexObject.h"
#include "VertexSet.h"


extern "C" {


/*   
 * D = Restrict(C,u)
 */
void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  SimplicialComplex_t * scomplex;
  SimplicialComplex_t * result;
  std::vector<int> vertexSet;
  std::back_insert_iterator<std::vector<int> > 
    vertexSetInserter(vertexSet);
  
  // check input and output
  if (nrhs != 2) {
    mexErrMsgTxt("Two inputs required.");
  } else if (nlhs > 1) {
    mexErrMsgTxt("Too many output arguments.");
  } else if (!IsPlexObject(prhs[0])) {
    mexErrMsgTxt("First argument must be a plex object.");
  } else if (!IsValidVertexSet(prhs[1])) {
    mexErrMsgTxt("Second argument must be a valid vertex set description.");
  }

  scomplex = GetSimplicialComplex(prhs[0]);

  // set up output
  plhs[0] = AllocPlexObject();

  GetVertexSetFromMxArray(prhs[1], scomplex, vertexSetInserter);
  result = scomplex->getRestriction(vertexSet.begin(), vertexSet.end());

  SetSimplicialComplex(plhs[0], result);
}

}
