/* simplices.cc
 * ------------
 * Returns the simplices in a plex object.
 *
 * $Id: simplices.cc,v 1.1.1.1 2005/03/18 23:36:56 silva Exp $
 * $Log: simplices.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:56  silva
 * Imported Sources
 *
 * Revision 1.1  2004/10/16 21:31:48  silva
 *
 * Renaming FACES to SIMPLICES.
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.1  2004/04/15 05:06:28  patperry
 * Bugfix and doc for faces, vertices
 *
 * Revision 1.10  2004/03/13 07:01:01  patperry
 * updated vertices to handle relative simplices
 *
 * Revision 1.9  2004/03/13 00:04:52  patperry
 * fixed tiny bug in restrict
 *
 * Revision 1.8  2004/02/26 06:49:24  patperry
 * Converted mexfiles to use new scomplex interface
 *
 * Revision 1.7  2004/02/26 02:34:04  patperry
 * Fixed bugs in PlexObject
 *
 * Revision 1.6  2004/02/09 06:30:44  patperry
 * Got rid of MatlabAllocator.  A few small bugfixes.
 *
 * Revision 1.5  2004/01/28 09:57:15  patperry
 * Changed the +1 offset in how simplices are stored.
 *
 * Revision 1.4  2004/01/23 04:36:39  patperry
 * Cleaned up MATLAB support code.
 *
 * Revision 1.3  2004/01/15 07:16:51  patperry
 * moved support to matlab-support
 *
 * Revision 1.2  2003/11/18 08:57:38  patperry
 * Added support code.
 *
 * Revision 1.1  2003/11/16 04:21:08  patperry
 * added vertices
 *
 *
 */

#include "PlexObject.h"
#include "MxUtility.h"

extern "C" {
#include "mex.h"
#include "matrix.h"
}

extern "C" {

void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  const SimplicialComplex_t * scomplex;
  double * values;
  int k;
  int numNondegenerateSimplices = 0;

  // check input and output
  if (nrhs != 2) {
    mexErrMsgTxt("Two inputs required.");
  } else if (nlhs > 1) {
    mexErrMsgTxt("Too many output arguments.");
  } else if (!IsPlexObject(prhs[0])) {
    mexErrMsgTxt("First input must be a plex object.");
  } else {
    k = GetIntFromMxArray(prhs[1]);
    if (k < 0) {
      mexErrMsgTxt("Second argument must be non-negative.");
    }
  } 

  scomplex = GetSimplicialComplex(prhs[0]);    

  plhs[0] = mxCreateNumericMatrix(k + 1, scomplex->getNumSimplices(k),
						    mxDOUBLE_CLASS, mxREAL);
  values = mxGetPr(plhs[0]);


  if (k <= scomplex->getDimension()) {
    for (SimplicialComplex_t::ConstSimplexIterator
		 it = scomplex->simplicesBegin(k);
	    it != scomplex->simplicesEnd(k); ++it) {
	 if (!(*it)->isDegenerate()) {
	   ++numNondegenerateSimplices;

	   Simplex_t::LabelIterator simplexLabel = (*it)->getLabel();
	   
	   for (int i = 0; i <= k; ++i) {
		*values = static_cast<double>(simplexLabel[i]);
		++values;
	   }
	 }
    }
  }

  mxSetN(plhs[0], numNondegenerateSimplices);
}

}
