/* skeleton.cc
 * -----------
 * Gets the k-skeleton of a simplicial complex.
 *
 * $Id: skeleton.cc,v 1.1.1.1 2005/03/18 23:36:56 silva Exp $
 * $Log: skeleton.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:56  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.5  2004/04/15 04:46:18  patperry
 * Bugfix and doc skeleton
 *
 * Revision 1.4  2004/02/26 06:49:24  patperry
 * Converted mexfiles to use new scomplex interface
 *
 * Revision 1.3  2004/02/09 06:30:44  patperry
 * Got rid of MatlabAllocator.  A few small bugfixes.
 *
 * Revision 1.2  2004/01/15 07:16:51  patperry
 * moved support to matlab-support
 *
 * Revision 1.1  2003/11/18 08:58:03  patperry
 * Added skeleton.
 *
 *
 */

#include "PlexObject.h"
#include "MxUtility.h"

extern "C" {
#include "mex.h"
#include "matrix.h"
}

extern "C" {

void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  const SimplicialComplex_t * scomplex;
  SimplicialComplex_t * result;
  int k = 1;

  // check input and output
  if ((nrhs  != 1) && (nrhs != 2)) {
    mexErrMsgTxt("One or two inputs required.");
  } else if (nlhs > 1) {
    mexErrMsgTxt("Too many output arguments.");
  } else if (!IsPlexObject(prhs[0])) {
    mexErrMsgTxt("First argument must be a plex object.");
  } else if ((nrhs == 2) && !IsScalarMxArray(prhs[1])) {
    mexErrMsgTxt("Second argument must be a scalar.");
  } else {
    scomplex = GetSimplicialComplex(prhs[0]);
    k = GetIntFromMxArray(prhs[1]);

    if (k < 0) {
	 mexErrMsgTxt("Second argument must be non-negative.");
    } 
  } 

  plhs[0] = AllocPlexObject();
  result = scomplex->getSkeleton(k);
  SetSimplicialComplex(plhs[0], result);
}

}
