function dd = px_euclid(a,b)

%PX_EUCLID  Compute Euclidean distance matrix.
%   D = PX_EUCLID(A,B)
%
%   Input arguments:
%      A : (d-by-M) matrix representing M vectors in R^d
%      B : (d-by-N) matrix representing N vectors in R^d
%
%   Output arguments:
%      D : (M-by-N) matrix of Euclidean distances between vectors in A
%          and B
%
%    Description:
%       This fully vectorized (VERY FAST!) m-file computes the Euclidean
%       distance between two vectors by:
%
%                 ||A-B|| = sqrt(||A||^2 + ||B||^2 - 2*A.B)
%
%    Example : 
%       A = rand(400,100); B = rand(400,200);
%       D = px_euclid(A,B);
%
%Original version by Roland Bunschoten. See comment text in px_euclid.m
%for details.
%
%Plex Metric Data Toolbox version 2.0 by Vin de Silva, Patrick Perry and
%contributors. See PX_PLEXINFO for credits and licensing information.
%Released with Plex version 2.0. [2005-May-18]

% Author   : Roland Bunschoten
%            University of Amsterdam
%            Intelligent Autonomous Systems (IAS) group
%            Kruislaan 403  1098 SJ Amsterdam
%            tel.(+31)20-5257524
%            bunschot@wins.uva.nl
% Last Rev : Wed Oct 20 08:58:08 MET DST 1999
% Tested   : PC Matlab v5.2 and Solaris Matlab v5.3

% Copyright notice: You are free to modify, extend and distribute 
%    this code granted that the author of the original code is 
%    mentioned as the original author of the code.

if (nargin < 1)
   error('Not enough input arguments');
end

if (nargin == 1)
	b = a;
end

if (size(a,1) ~= size(b,1))
   error('A and B should be of same dimensionality');
end

aa=sum(a.*a,1); bb=sum(b.*b,1); ab=a'*b; 
dd = sqrt(...
    max(repmat(aa',[1 size(bb,2)]) + repmat(bb,[size(aa,2) 1]) - 2*ab, 0)...
    );

