/* px_landmarks.cc
 * ---------------
 * Written by Patrick Perry
 * Original Version on April 20, 2004
 *
 * $Id: px_landmarkd.cc,v 1.1.1.1 2005/03/18 23:37:00 silva Exp $
 * $Log: px_landmarkd.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:37:00  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.2  2004/09/15 21:47:34  silva
 * *** empty log message ***
 *
 * Revision 1.1  2004/09/15 19:09:01  silva
 * Renamed with px_prefix for Plex 2.0 release.
 *
 * Revision 1.1  2004/04/21 00:13:18  patperry
 * Bugfix in wfilt, persistence.  Added landmarkd.
 *
 */

extern "C" {
#include "/matlabdir/extern/include/mex.h"
#include "/matlabdir/extern/include/matrix.h"
}

extern "C" {
void
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  if (nrhs != 2) {
    mexErrMsgTxt("Two input arguments required.");
  } else if (nlhs > 1) {
    mexErrMsgTxt("Too many output arguments.");
  } else if (mxGetM(prhs[0]) != mxGetM(prhs[1])) {
    mexErrMsgTxt("Point arrays must be of the same dimension.");
  } else {
    for (int i = 0; i < 2; ++i) {
	 if (!(mxIsDouble(prhs[i]) && !mxIsSparse(prhs[i]) 
		  && !mxIsComplex(prhs[i]))) {
	   mexErrMsgTxt("Arguments must be full nonsparse double.");
	 }
    }
  }

  const int dim = mxGetM(prhs[0]);
  const int numPoints = mxGetN(prhs[0]);
  const int numLandmarks = mxGetN(prhs[1]);
  const double * pointData = mxGetPr(prhs[0]);
  const double * landmarkData = mxGetPr(prhs[1]);

  // allocate result;
  plhs[0] = mxCreateNumericMatrix(numLandmarks, numPoints, 
						    mxDOUBLE_CLASS, mxREAL);
  double * resultData = mxGetPr(plhs[0]);

  const double * currentPoint = pointData;  
  for (int j = 0; j < numPoints; ++j) {

    const double * currentLandmark = landmarkData;
    for (int i = 0; i < numLandmarks; ++i) {
	 double value = 0;

	 for (int d = 0; d < dim; ++d) {
	   double difference_d = currentPoint[d] - currentLandmark[d];
	   value += difference_d * difference_d;
	 }
	 
	 *resultData++ = value;
	 currentLandmark += dim;
    }

    currentPoint += dim;
  }

  
}

}
