function H_p = px_plot(varargin);

%PX_PLOT -- 2-dimensional plot from data matrix
%
% PX_PLOT(X)
%   displays the N data points represented by the 2-by-N matrix X.
%
% PX_PLOT(X, style)
%   allows use of a string such as 'r-', as in the built-in function PLOT.
%   The default style is 'b.'.
%
%   If X has more than two rows, then the first two rows are used.
%
% PX_PLOT(X, [a b])
%   is equivalent to PX_PLOT(X([a b],:)).
%
% PX_PLOT(X, [a b], style) and PX_PLOT(X, style, [a b])
%   are equivalent to PX_PLOT(X([a b],:), style).
%
% H = PX_PLOT(...) returns the handle of the plot object.
%
%Plex Metric Data Toolbox version 2.0 by Vin de Silva, Patrick Perry and
%contributors. See PX_PLEXINFO for credits and licensing information.
%Released with Plex version 2.0. [2005-May-18]

error(nargchk(1, 3, nargin));

switch nargin
 case 1
  X = varargin{1};
  rows = [1 2];
  style = 'b.';
  
 case 2
  X = varargin{1};
 
  if ischar(varargin{2})
    rows = [1 2];
    style = varargin{2};
    
  elseif isnumeric(varargin{2})
    rows = varargin{2}(1:2);
    style = 'b.';
  
  else
    error('Invalid input.')
  end
  
 case 3
  X = varargin{1};
  
  if ischar(varargin{2}) & isnumeric(varargin{3})
  
    rows = varargin{3}(1:2);
    style = varargin{2};
    
  elseif ischar(varargin{3}) & isnumeric(varargin{2})
  
    rows = varargin{2}(1:2);
    style = varargin{3};
  
  else
    error('Invalid input.')
  end
  
end

H = plot(X(rows(1), :), X(rows(2), :), style);

if (nargout == 1)
  H_p = H;
end
