function H_p = px_plot3(varargin);

%PX_PLOT3 -- 3-dimensional plot from data matrix
%
% PX_PLOT3(X)
%   displays the N data points represented by the 3-by-N matrix X.
%
% PX_PLOT3(X, style)
%   allows use of a string such as 'r-', as in the built-in function PLOT.
%   The default style is 'b.'.
%
%   If X has more than three rows, then the first three rows are used.
%
% PX_PLOT3(X, [a b c])
%   is equivalent to PX_PLOT(X([a b c],:)).
%
% PX_PLOT(X, [a b c], style) and PX_PLOT(X, style, [a b c])
%   are equivalent to PX_PLOT(X([a b c],:), style).
%
% H = PX_PLOT(...) returns the handle of the plot object.
%
%Plex Metric Data Toolbox version 2.0 by Vin de Silva, Patrick Perry and
%contributors. See PX_PLEXINFO for credits and licensing information.
%Released with Plex version 2.0. [2005-May-18]

error(nargchk(1, 3, nargin));

switch nargin
 case 1
  X = varargin{1};
  rows = [1 2 3];
  style = 'b.';
  
 case 2
  X = varargin{1};

  if ischar(varargin{2})
    rows = [1 2 3];
    style = varargin{2};
    
  elseif isnumeric(varargin{2})
    rows = varargin{2}(1:3);
    style = 'b.';
  
  else
    error('Invalid input.')
  end
  
 case 3
  X = varargin{1};

  if ischar(varargin{2}) & isnumeric(varargin{3})
    rows = varargin{3}(1:3);
    style = varargin{2};
    
  elseif ischar(varargin{3}) & isnumeric(varargin{2})
    rows = varargin{2}(1:3);
    style = varargin{3};
    
  else
    error('Invalid input.')  
  end
  
end

H = plot3(X(rows(1), :), X(rows(2), :), X(rows(3), :), style);

if (nargout == 1)
  H_p = H;
end
