function Ho_out = px_viewgraph(G,P,style)

% PX_VIEWGRAPH -- display a graph with Euclidean vertex set
%
%  PX_VIEWGRAPH(G,P)
%  PX_VIEWGRAPH(G,P,style)
%
% Input arguments:
%
%  P : d-by-n matrix representing n points in R^d
%  G : n-by-n symmetric logical (or 0-1) matrix, with edges of the
%      graph represented by the 1s.
%
% If d = 2 this uses GPLOT to produce a 2-dimensional graph plot. If d > 2
% then the first three dimensions are plotted in a 3D graph plot.
%
% H = PX_VIEWGRAPH(...) returns the handle of the plot object.
%
%Plex Metric Data Toolbox version 2.0 by Vin de Silva, Patrick Perry and
%contributors. See PX_PLEXINFO for credits and licensing information.
%Released with Plex version 2.0. [2005-May-18]
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
error(nargchk(2,3,nargin));

if (nargin < 3)
  % default style
  style='*b-';
end

[d, n] = size(P); % d = dimension, n = order of graph;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ~isequal(size(G),[n n])
  error('First input must be a square matrix of the correct size')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (d == 2)
  G = G + eye(n);
  [A,B] = gplot(G, P([1 2], :)');
  Ho = plot(A,B,style);
  
elseif (d > 2)
  G = G + eye(n);
  [A,B] = gplot(G, P([1 2], :)');
  [B,C] = gplot(G, P([2 3], :)');	% slightly wasteful!
  Ho = plot3(A, B, C, style);
  
else
  error('Vectors must be at least 2-dimensional')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (nargout == 1)
  Ho_out = Ho;		% returns handle of plot object
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
