function C = px_witness (D, nu, r, k)

%PX_WITNESS -- build a witness complex
%
%   C = PX_WITNESS(D, nu, r)
%   C = PX_WITNESS(D, nu, r, k)
%
%   This builds, as a Plex object, the witness complex defined by the
%   landmark-to-point distance matrix D, discrete parameter nu, and metric
%   parameter r. The optional input argument k specifies that C is built
%   up to the k-skeleton only.
%
%   To compute the "arrival time" for each simplex in C (that is, the
%   smallest value of r for which that simplex appears in the witness
%   complex), follow up with a call to WFILT. Persistent homology can then
%   be computed using PERSISTENCE. The following sequence is typical:
%
%      >> C = px_witness(D, nu, r, k);
%      >> F = wfilt(C, D, nu);
%      >> I = persistence(C, I);
%
%   PX_WITNESS is called by PX_WEAK, PX_STRONG.
%
%   Input arguments: 
%
%      D  : n-by-N matrix of distances between n landmarks and N data points
%      nu : non-negative integer
%      r  : scalar (possibly inf)
%      k  : non-negative integer
%
%   Output argument:
%
%      C  : Plex object on n vertices with dimension at most k.
%
%   In the case nu = 0, a simplex with vertex set I = [i0, ..., ip]
%   belongs to C if and only if there exists j in {1, .., N} such that the
%   condition ALL(D(I, j) <= r) is true.
%
%   In the case nu > 0, let f(j) denote the nu-th smallest entry of the
%   vector D(:, j). Thus f(j) is the distance between the j-th data point
%   and its nu-th nearest landmark neighbour. Then the condition on a
%   simplex for membership of C is that there exists j in {1, ..., N} such
%   that ALL(D(I, j) <= r + f(j)) is true.
%
%   PX_WITNESS is no longer intended to be called directly. Use
%   PX_WITNESSNU instead.
%
%Plex Metric Data Toolbox version 2.0 by Vin de Silva, Patrick Perry and
%contributors. See PX_PLEXINFO for credits and licensing information.
%Released with Plex version 2.0. [2005-May-18]

% $Id: px_witness.m,v 1.1.1.1 2005/03/18 23:37:03 silva Exp $
% $Log: px_witness.m,v $
% Revision 1.1.1.1  2005/03/18 23:37:03  silva
% Imported Sources
%
% Revision 1.3  2004/10/22 01:28:13  silva
%
% Improving help-text and adding tags.
%
% Revision 1.2  2004/09/30 04:31:57  silva
%
% Small improvement to help text.
%
% Revision 1.1.1.1  2004/09/25 22:04:09  patperry
% Imported sources
%
% Revision 1.2  2004/09/15 18:32:59  silva
% Wrote more detailed help text.
%
% Revision 1.1  2004/09/14 23:55:21  silva
%
% Renaming files with the 'px_' prefix and making small changes to the help
% text and to older code.
%
% Revision 1.1  2004/05/19 04:15:07  patperry
% Added doc for witness
%
%
