/* px_mod2lu_compact.cc
 * --------------------
 * Find the (mod2) LU-decomposition of a matrix.
 *
 * $Id: px_mod2lu_compact.cc,v 1.1.1.1 2005/03/18 23:37:06 silva Exp $
 * $Log: px_mod2lu_compact.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:37:06  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.1  2004/09/15 22:22:16  silva
 * Renamed with px_ prefix for Plex 2.0 release.
 *
 * Revision 1.5  2004/04/03 23:54:10  patperry
 * Bugfix and document betti2
 *
 * Revision 1.4  2004/02/09 06:30:44  patperry
 * Got rid of MatlabAllocator.  A few small bugfixes.
 *
 * Revision 1.3  2004/01/23 04:36:37  patperry
 * Cleaned up MATLAB support code.
 *
 * Revision 1.2  2004/01/15 07:27:09  patperry
 * added global makefile
 *
 * Revision 1.1  2003/12/04 14:24:56  patperry
 * added homology calculation tools
 *
 */

#include <iostream>
#include "LUFullMatrix.h"
#include "Mod2.h"
#include "MxSupport.h"

extern "C" {
#include "mex.h"
#include "matrix.h"
}

extern "C" {

/**
 * Takes a graph and creates a simplicial complex from it.  If no
 * graph is passed-in, an empty complex is created.
 */
void 
mexFunction (int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  // Check for proper number of arguments.
  if (nrhs > 1) {
    mexErrMsgTxt("One input required.");
  } else if (nlhs != 3) {
    mexErrMsgTxt("Three output arguments required.");
  }

  // allocate an empty LU full matrix decomposer
  LUFullMatrix<Mod2> * matrix;

  // handle full and sparse inputs differently
  if (mxIsSparse(prhs[0])) {
    CSCSparseMatrix<Mod2> * input
	 = getSparseMod2Matrix(prhs[0]);
   
    matrix = new LUFullMatrix<Mod2>(*input);

    delete input;
  } else {
    FullMatrix<Mod2> * input
	 = getFullMod2Matrix(prhs[0]);
    
    matrix = new LUFullMatrix<Mod2>(*input);
    
    delete input;
  }
  
  // LU-reduce the matrix
  matrix->reduce();

  // copy the matrix into the output
  plhs[0] = getFullMatlabMatrix(*matrix);

  // copy the row permutation into the output
  plhs[1] = getMatlabArray(matrix->getP(),
					  matrix->getP() + matrix->getNumRows());
  
  // copy the column permutation into the output
  plhs[2] = getMatlabArray(matrix->getQ(), 
					  matrix->getQ() + matrix->getNumColumns());

  delete matrix;
}

}
