function px_free(C)

%PX_FREE  Free memory allocated to Plex objects.
%   ***Caution: for emergency use only!***
%
%   Background: Plex objects are stored in MATLAB as pointers to C++
%   objects residing in allocated memory. MATLAB itself does not see the
%   object and does not know about the allocated memory.
%
%   Problem: There is a danger that Plex objects may not be fully
%   cleared from memory after use. Plex takes certain steps to minimise
%   this, but this can still happen. The effect is that MATLAB memory
%   gradually fills up undetected, and eventually the program crashes. 
%   This is particularly likely to happen if a MATLAB program repeatedly
%   creates and clears large Plex objects.
%
%   Workaround: If the user experiences unexpected crashes in situations
%   of this nature, the following advice may solve the problem. Whenever
%   a created Plex object C is no longer needed, clear it from memory
%   using the following sequence of commands.
%
%      >> px_free(C);
%      >> clear C
%
%   PX_FREE should always be immediately followed by CLEAR.
%
%   Caveat: In certain situations this may create other problems. For
%   instance, after an assignment of the form 'D = C', the new object D
%   in MATLAB is simply a pointer to the same Plex object residing in
%   memory as C. If C is cleared in the manner suggested above, then
%   the MATLAB variable D points nowhere, and the program will crash
%   if Plex operations are attempted on D. Let the user beware.
%
%   At the present time, MATLAB does not appear to have any support for
%   user-created object classes other than those implemented as MATLAB
%   structured arrays. We have not found any entirely succesful way
%   around the resulting problems.
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]
