function [L, U, P, Q] = px_mod2lu (A, cover1, cover2, cover3)

%PX_MOD2LU
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

if (nargin == 1)
  [LU, p, q] = px_mod2lu_compact(A);
else
  A = sparse(A);
  
  if (nargin == 2) 
    [LU, p, q] = px_gsmod2lu_compact(A, logical(full(cover1)));
  elseif (nargin == 3)
    [LU, p, q] = px_gsmod2lu_compact(A, logical(full(cover1)), ...
						    logical(full(cover2)));
  else 
    [LU, p, q] = px_gsmod2lu_compact(A, logical(full(cover1)), ...
						    logical(full(cover2)), ...
						    logical(full(cover3)));
  end
end

L = tril(LU, -1);
L = L(1:end, 1:min(size(L,1), size(L,2)));
L = [L, zeros(size(L,1), size(L,1) - size(L,2))] + eye(size(L,1));

U = triu(LU);

p = int32(p + 1);
q = int32(q + 1);

P = zeros(length(p));
for i = 1:length(p)
  P(p(i), i) = 1;
end

Q = zeros(length(q));
for (i = 1:length(q))
  Q(i, q(i)) = 1;
end

if (issparse(A)) 
  U = sparse(U);
  L = sparse(L); 
  P = sparse(P);
  Q = sparse(Q);
end

