function [K,varargout] = px_mod2null (A, cover1, cover2, cover3)

%PX_MOD2NULL
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

if nargin >= 4
  [L, U, P, Q] = px_mod2lu(A, cover1, cover2, cover3);
elseif nargin == 3
  [L, U, P, Q] = px_mod2lu(A, cover1, cover2);
elseif nargin == 2
  [L, U, P, Q] = px_mod2lu(A, cover1);
else
  [L, U, P, Q] = px_mod2lu(A);
end

numPivots = length(find(diag(U)));
U_pivot = U(1:numPivots, 1:numPivots);

K = zeros(size(U,2), 0);

% for each nonpivot column, u_k
for k = (numPivots + 1):size(U,2)
  u = U(1:numPivots,k);
  
  % Let u_inv be such that U * u_inv = u
  u_inv = U_pivot \ u;
  u_inv = [u_inv; zeros(size(U,2) - numPivots, 1)];
  
  % subtract e_k from u_inv
  u_inv(k) = u_inv(k) - 1;
  
  % we know U * (-e_k) = -u_k, and U * u_inv = u_k, so this
  % vector is in the kernel
  K = [K, u_inv];
end

% change to mod2
K = mod(K, 2);

if (nargout == 2)
  varargout(1) = {Q};
else
  % reverse the column permutation
  K = Q * K;
end

