function t = plexinfo_shell(name)

%PX_PLEXINFO  Display Plex licensing and other information.
%
%   PX_PLEXINFO topicname, PX_PLEXINFO('topicname') both display the
%   information text specified by 'topicname'. The following options
%   are supported.
% 
%   PX_PLEXINFO         : display this message
%   PX_PLEXINFO LICENSE : license agreement
%   PX_PLEXINFO CREDITS : authorship and credits
%   PX_PLEXINFO README  : important general information
%   PX_PLEXINFO NEWS    : late-breaking news
%   PX_PLEXINFO CHANGES : important changes from previous versions
%
%   T = PX_PLEXINFO(string) returns the text as a character array T.
%
%   PX_PLEXINFO is case insensitive, in that each 'topicname' can be
%   entered in upper, lower or mixed case.
%
%   Type 'help Plex' and 'help Plex/metric' for Plex library contents.
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors.
%[2004-October-17]

%-------------------------------------------------------
if (nargin == 0)
  name = 'default';
else
  name = lower(name);
end

%-------------------------------------------------------
t0 = [];
switch name
 case {'default'}
  name = 'px_plexinfo';
  t0 = help('px_plexinfo');
  
 case {'license', 'copying'}
t0 = strvcat(...
' 	 	     G N U   L E S S E R   G E N E R A L   P U B L I C   L I C E N S E  ', ...
' 	 	               V e r s i o n   2 . 1 ,   F e b r u a r y   1 9 9 9  ', ...
'  ', ...
'   C o p y r i g h t   ( C )   1 9 9 1 ,   1 9 9 9   F r e e   S o f t w a r e   F o u n d a t i o n ,   I n c .  ', ...
'           5 9   T e m p l e   P l a c e ,   S u i t e   3 3 0 ,   B o s t o n ,   M A     0 2 1 1 1 - 1 3 0 7     U S A  ', ...
'   E v e r y o n e   i s   p e r m i t t e d   t o   c o p y   a n d   d i s t r i b u t e   v e r b a t i m   c o p i e s  ', ...
'   o f   t h i s   l i c e n s e   d o c u m e n t ,   b u t   c h a n g i n g   i t   i s   n o t   a l l o w e d .  ', ...
'  ', ...
' [ T h i s   i s   t h e   f i r s t   r e l e a s e d   v e r s i o n   o f   t h e   L e s s e r   G P L .     I t   a l s o   c o u n t s  ', ...
'   a s   t h e   s u c c e s s o r   o f   t h e   G N U   L i b r a r y   P u b l i c   L i c e n s e ,   v e r s i o n   2 ,   h e n c e  ', ...
'   t h e   v e r s i o n   n u m b e r   2 . 1 . ]  ', ...
'  ', ...
' 	 	 	         P r e a m b l e  ', ...
'  ', ...
'     T h e   l i c e n s e s   f o r   m o s t   s o f t w a r e   a r e   d e s i g n e d   t o   t a k e   a w a y   y o u r  ', ...
' f r e e d o m   t o   s h a r e   a n d   c h a n g e   i t .     B y   c o n t r a s t ,   t h e   G N U   G e n e r a l   P u b l i c  ', ...
' L i c e n s e s   a r e   i n t e n d e d   t o   g u a r a n t e e   y o u r   f r e e d o m   t o   s h a r e   a n d   c h a n g e  ', ...
' f r e e   s o f t w a r e - - t o   m a k e   s u r e   t h e   s o f t w a r e   i s   f r e e   f o r   a l l   i t s   u s e r s .  ', ...
'  ', ...
'     T h i s   l i c e n s e ,   t h e   L e s s e r   G e n e r a l   P u b l i c   L i c e n s e ,   a p p l i e s   t o   s o m e  ', ...
' s p e c i a l l y   d e s i g n a t e d   s o f t w a r e   p a c k a g e s - - t y p i c a l l y   l i b r a r i e s - - o f   t h e  ', ...
' F r e e   S o f t w a r e   F o u n d a t i o n   a n d   o t h e r   a u t h o r s   w h o   d e c i d e   t o   u s e   i t .     Y o u  ', ...
' c a n   u s e   i t   t o o ,   b u t   w e   s u g g e s t   y o u   f i r s t   t h i n k   c a r e f u l l y   a b o u t   w h e t h e r  ', ...
' t h i s   l i c e n s e   o r   t h e   o r d i n a r y   G e n e r a l   P u b l i c   L i c e n s e   i s   t h e   b e t t e r  ', ...
' s t r a t e g y   t o   u s e   i n   a n y   p a r t i c u l a r   c a s e ,   b a s e d   o n   t h e   e x p l a n a t i o n s   b e l o w .  ', ...
'  ', ...
'     W h e n   w e   s p e a k   o f   f r e e   s o f t w a r e ,   w e   a r e   r e f e r r i n g   t o   f r e e d o m   o f   u s e ,  ', ...
' n o t   p r i c e .     O u r   G e n e r a l   P u b l i c   L i c e n s e s   a r e   d e s i g n e d   t o   m a k e   s u r e   t h a t  ', ...
' y o u   h a v e   t h e   f r e e d o m   t o   d i s t r i b u t e   c o p i e s   o f   f r e e   s o f t w a r e   ( a n d   c h a r g e  ', ...
' f o r   t h i s   s e r v i c e   i f   y o u   w i s h ) ;   t h a t   y o u   r e c e i v e   s o u r c e   c o d e   o r   c a n   g e t  ', ...
' i t   i f   y o u   w a n t   i t ;   t h a t   y o u   c a n   c h a n g e   t h e   s o f t w a r e   a n d   u s e   p i e c e s   o f  ', ...
' i t   i n   n e w   f r e e   p r o g r a m s ;   a n d   t h a t   y o u   a r e   i n f o r m e d   t h a t   y o u   c a n   d o  ', ...
' t h e s e   t h i n g s .  ', ...
'  ', ...
'     T o   p r o t e c t   y o u r   r i g h t s ,   w e   n e e d   t o   m a k e   r e s t r i c t i o n s   t h a t   f o r b i d  ', ...
' d i s t r i b u t o r s   t o   d e n y   y o u   t h e s e   r i g h t s   o r   t o   a s k   y o u   t o   s u r r e n d e r   t h e s e  ', ...
' r i g h t s .     T h e s e   r e s t r i c t i o n s   t r a n s l a t e   t o   c e r t a i n   r e s p o n s i b i l i t i e s   f o r  ', ...
' y o u   i f   y o u   d i s t r i b u t e   c o p i e s   o f   t h e   l i b r a r y   o r   i f   y o u   m o d i f y   i t .  ', ...
'  ', ...
'     F o r   e x a m p l e ,   i f   y o u   d i s t r i b u t e   c o p i e s   o f   t h e   l i b r a r y ,   w h e t h e r   g r a t i s  ', ...
' o r   f o r   a   f e e ,   y o u   m u s t   g i v e   t h e   r e c i p i e n t s   a l l   t h e   r i g h t s   t h a t   w e   g a v e  ', ...
' y o u .     Y o u   m u s t   m a k e   s u r e   t h a t   t h e y ,   t o o ,   r e c e i v e   o r   c a n   g e t   t h e   s o u r c e  ', ...
' c o d e .     I f   y o u   l i n k   o t h e r   c o d e   w i t h   t h e   l i b r a r y ,   y o u   m u s t   p r o v i d e  ', ...
' c o m p l e t e   o b j e c t   f i l e s   t o   t h e   r e c i p i e n t s ,   s o   t h a t   t h e y   c a n   r e l i n k   t h e m  ', ...
' w i t h   t h e   l i b r a r y   a f t e r   m a k i n g   c h a n g e s   t o   t h e   l i b r a r y   a n d   r e c o m p i l i n g  ', ...
' i t .     A n d   y o u   m u s t   s h o w   t h e m   t h e s e   t e r m s   s o   t h e y   k n o w   t h e i r   r i g h t s .  ', ...
'  ', ...
'     W e   p r o t e c t   y o u r   r i g h t s   w i t h   a   t w o - s t e p   m e t h o d :   ( 1 )   w e   c o p y r i g h t   t h e  ', ...
' l i b r a r y ,   a n d   ( 2 )   w e   o f f e r   y o u   t h i s   l i c e n s e ,   w h i c h   g i v e s   y o u   l e g a l  ', ...
' p e r m i s s i o n   t o   c o p y ,   d i s t r i b u t e   a n d / o r   m o d i f y   t h e   l i b r a r y .  ', ...
'  ', ...
'     T o   p r o t e c t   e a c h   d i s t r i b u t o r ,   w e   w a n t   t o   m a k e   i t   v e r y   c l e a r   t h a t  ', ...
' t h e r e   i s   n o   w a r r a n t y   f o r   t h e   f r e e   l i b r a r y .     A l s o ,   i f   t h e   l i b r a r y   i s  ', ...
' m o d i f i e d   b y   s o m e o n e   e l s e   a n d   p a s s e d   o n ,   t h e   r e c i p i e n t s   s h o u l d   k n o w  ', ...
' t h a t   w h a t   t h e y   h a v e   i s   n o t   t h e   o r i g i n a l   v e r s i o n ,   s o   t h a t   t h e   o r i g i n a l  ', ...
' a u t h o r '' s   r e p u t a t i o n   w i l l   n o t   b e   a f f e c t e d   b y   p r o b l e m s   t h a t   m i g h t   b e  ', ...
' i n t r o d u c e d   b y   o t h e r s .  ', ...
'   ', ...
'     F i n a l l y ,   s o f t w a r e   p a t e n t s   p o s e   a   c o n s t a n t   t h r e a t   t o   t h e   e x i s t e n c e   o f  ', ...
' a n y   f r e e   p r o g r a m .     W e   w i s h   t o   m a k e   s u r e   t h a t   a   c o m p a n y   c a n n o t  ', ...
' e f f e c t i v e l y   r e s t r i c t   t h e   u s e r s   o f   a   f r e e   p r o g r a m   b y   o b t a i n i n g   a  ', ...
' r e s t r i c t i v e   l i c e n s e   f r o m   a   p a t e n t   h o l d e r .     T h e r e f o r e ,   w e   i n s i s t   t h a t  ', ...
' a n y   p a t e n t   l i c e n s e   o b t a i n e d   f o r   a   v e r s i o n   o f   t h e   l i b r a r y   m u s t   b e  ', ...
' c o n s i s t e n t   w i t h   t h e   f u l l   f r e e d o m   o f   u s e   s p e c i f i e d   i n   t h i s   l i c e n s e .  ', ...
'  ', ...
'     M o s t   G N U   s o f t w a r e ,   i n c l u d i n g   s o m e   l i b r a r i e s ,   i s   c o v e r e d   b y   t h e  ', ...
' o r d i n a r y   G N U   G e n e r a l   P u b l i c   L i c e n s e .     T h i s   l i c e n s e ,   t h e   G N U   L e s s e r  ', ...
' G e n e r a l   P u b l i c   L i c e n s e ,   a p p l i e s   t o   c e r t a i n   d e s i g n a t e d   l i b r a r i e s ,   a n d  ', ...
' i s   q u i t e   d i f f e r e n t   f r o m   t h e   o r d i n a r y   G e n e r a l   P u b l i c   L i c e n s e .     W e   u s e  ', ...
' t h i s   l i c e n s e   f o r   c e r t a i n   l i b r a r i e s   i n   o r d e r   t o   p e r m i t   l i n k i n g   t h o s e  ', ...
' l i b r a r i e s   i n t o   n o n - f r e e   p r o g r a m s .  ', ...
'  ', ...
'     W h e n   a   p r o g r a m   i s   l i n k e d   w i t h   a   l i b r a r y ,   w h e t h e r   s t a t i c a l l y   o r   u s i n g  ', ...
' a   s h a r e d   l i b r a r y ,   t h e   c o m b i n a t i o n   o f   t h e   t w o   i s   l e g a l l y   s p e a k i n g   a  ', ...
' c o m b i n e d   w o r k ,   a   d e r i v a t i v e   o f   t h e   o r i g i n a l   l i b r a r y .     T h e   o r d i n a r y  ', ...
' G e n e r a l   P u b l i c   L i c e n s e   t h e r e f o r e   p e r m i t s   s u c h   l i n k i n g   o n l y   i f   t h e  ', ...
' e n t i r e   c o m b i n a t i o n   f i t s   i t s   c r i t e r i a   o f   f r e e d o m .     T h e   L e s s e r   G e n e r a l  ', ...
' P u b l i c   L i c e n s e   p e r m i t s   m o r e   l a x   c r i t e r i a   f o r   l i n k i n g   o t h e r   c o d e   w i t h  ', ...
' t h e   l i b r a r y .  ', ...
'  ', ...
'     W e   c a l l   t h i s   l i c e n s e   t h e   " L e s s e r "   G e n e r a l   P u b l i c   L i c e n s e   b e c a u s e   i t  ', ...
' d o e s   L e s s   t o   p r o t e c t   t h e   u s e r '' s   f r e e d o m   t h a n   t h e   o r d i n a r y   G e n e r a l  ', ...
' P u b l i c   L i c e n s e .     I t   a l s o   p r o v i d e s   o t h e r   f r e e   s o f t w a r e   d e v e l o p e r s   L e s s  ', ...
' o f   a n   a d v a n t a g e   o v e r   c o m p e t i n g   n o n - f r e e   p r o g r a m s .     T h e s e   d i s a d v a n t a g e s  ', ...
' a r e   t h e   r e a s o n   w e   u s e   t h e   o r d i n a r y   G e n e r a l   P u b l i c   L i c e n s e   f o r   m a n y  ', ...
' l i b r a r i e s .     H o w e v e r ,   t h e   L e s s e r   l i c e n s e   p r o v i d e s   a d v a n t a g e s   i n   c e r t a i n  ', ...
' s p e c i a l   c i r c u m s t a n c e s .  ', ...
'  ', ...
'     F o r   e x a m p l e ,   o n   r a r e   o c c a s i o n s ,   t h e r e   m a y   b e   a   s p e c i a l   n e e d   t o  ', ...
' e n c o u r a g e   t h e   w i d e s t   p o s s i b l e   u s e   o f   a   c e r t a i n   l i b r a r y ,   s o   t h a t   i t   b e c o m e s  ', ...
' a   d e - f a c t o   s t a n d a r d .     T o   a c h i e v e   t h i s ,   n o n - f r e e   p r o g r a m s   m u s t   b e  ', ...
' a l l o w e d   t o   u s e   t h e   l i b r a r y .     A   m o r e   f r e q u e n t   c a s e   i s   t h a t   a   f r e e  ', ...
' l i b r a r y   d o e s   t h e   s a m e   j o b   a s   w i d e l y   u s e d   n o n - f r e e   l i b r a r i e s .     I n   t h i s  ', ...
' c a s e ,   t h e r e   i s   l i t t l e   t o   g a i n   b y   l i m i t i n g   t h e   f r e e   l i b r a r y   t o   f r e e  ', ...
' s o f t w a r e   o n l y ,   s o   w e   u s e   t h e   L e s s e r   G e n e r a l   P u b l i c   L i c e n s e .  ', ...
'  ', ...
'     I n   o t h e r   c a s e s ,   p e r m i s s i o n   t o   u s e   a   p a r t i c u l a r   l i b r a r y   i n   n o n - f r e e  ', ...
' p r o g r a m s   e n a b l e s   a   g r e a t e r   n u m b e r   o f   p e o p l e   t o   u s e   a   l a r g e   b o d y   o f  ', ...
' f r e e   s o f t w a r e .     F o r   e x a m p l e ,   p e r m i s s i o n   t o   u s e   t h e   G N U   C   L i b r a r y   i n  ', ...
' n o n - f r e e   p r o g r a m s   e n a b l e s   m a n y   m o r e   p e o p l e   t o   u s e   t h e   w h o l e   G N U  ', ...
' o p e r a t i n g   s y s t e m ,   a s   w e l l   a s   i t s   v a r i a n t ,   t h e   G N U / L i n u x   o p e r a t i n g  ', ...
' s y s t e m .  ', ...
'  ', ...
'     A l t h o u g h   t h e   L e s s e r   G e n e r a l   P u b l i c   L i c e n s e   i s   L e s s   p r o t e c t i v e   o f   t h e  ', ...
' u s e r s ''   f r e e d o m ,   i t   d o e s   e n s u r e   t h a t   t h e   u s e r   o f   a   p r o g r a m   t h a t   i s  ', ...
' l i n k e d   w i t h   t h e   L i b r a r y   h a s   t h e   f r e e d o m   a n d   t h e   w h e r e w i t h a l   t o   r u n  ', ...
' t h a t   p r o g r a m   u s i n g   a   m o d i f i e d   v e r s i o n   o f   t h e   L i b r a r y .  ', ...
'  ', ...
'     T h e   p r e c i s e   t e r m s   a n d   c o n d i t i o n s   f o r   c o p y i n g ,   d i s t r i b u t i o n   a n d  ', ...
' m o d i f i c a t i o n   f o l l o w .     P a y   c l o s e   a t t e n t i o n   t o   t h e   d i f f e r e n c e   b e t w e e n   a  ', ...
' " w o r k   b a s e d   o n   t h e   l i b r a r y "   a n d   a   " w o r k   t h a t   u s e s   t h e   l i b r a r y " .     T h e  ', ...
' f o r m e r   c o n t a i n s   c o d e   d e r i v e d   f r o m   t h e   l i b r a r y ,   w h e r e a s   t h e   l a t t e r   m u s t  ', ...
' b e   c o m b i n e d   w i t h   t h e   l i b r a r y   i n   o r d e r   t o   r u n .  ', ...
'   ', ...
' 	 	     G N U   L E S S E R   G E N E R A L   P U B L I C   L I C E N S E  ', ...
'       T E R M S   A N D   C O N D I T I O N S   F O R   C O P Y I N G ,   D I S T R I B U T I O N   A N D   M O D I F I C A T I O N  ', ...
'  ', ...
'     0 .   T h i s   L i c e n s e   A g r e e m e n t   a p p l i e s   t o   a n y   s o f t w a r e   l i b r a r y   o r   o t h e r  ', ...
' p r o g r a m   w h i c h   c o n t a i n s   a   n o t i c e   p l a c e d   b y   t h e   c o p y r i g h t   h o l d e r   o r  ', ...
' o t h e r   a u t h o r i z e d   p a r t y   s a y i n g   i t   m a y   b e   d i s t r i b u t e d   u n d e r   t h e   t e r m s   o f  ', ...
' t h i s   L e s s e r   G e n e r a l   P u b l i c   L i c e n s e   ( a l s o   c a l l e d   " t h i s   L i c e n s e " ) .  ', ...
' E a c h   l i c e n s e e   i s   a d d r e s s e d   a s   " y o u " .  ', ...
'  ', ...
'     A   " l i b r a r y "   m e a n s   a   c o l l e c t i o n   o f   s o f t w a r e   f u n c t i o n s   a n d / o r   d a t a  ', ...
' p r e p a r e d   s o   a s   t o   b e   c o n v e n i e n t l y   l i n k e d   w i t h   a p p l i c a t i o n   p r o g r a m s  ', ...
' ( w h i c h   u s e   s o m e   o f   t h o s e   f u n c t i o n s   a n d   d a t a )   t o   f o r m   e x e c u t a b l e s .  ', ...
'  ', ...
'     T h e   " L i b r a r y " ,   b e l o w ,   r e f e r s   t o   a n y   s u c h   s o f t w a r e   l i b r a r y   o r   w o r k  ', ...
' w h i c h   h a s   b e e n   d i s t r i b u t e d   u n d e r   t h e s e   t e r m s .     A   " w o r k   b a s e d   o n   t h e  ', ...
' L i b r a r y "   m e a n s   e i t h e r   t h e   L i b r a r y   o r   a n y   d e r i v a t i v e   w o r k   u n d e r  ', ...
' c o p y r i g h t   l a w :   t h a t   i s   t o   s a y ,   a   w o r k   c o n t a i n i n g   t h e   L i b r a r y   o r   a  ', ...
' p o r t i o n   o f   i t ,   e i t h e r   v e r b a t i m   o r   w i t h   m o d i f i c a t i o n s   a n d / o r   t r a n s l a t e d  ', ...
' s t r a i g h t f o r w a r d l y   i n t o   a n o t h e r   l a n g u a g e .     ( H e r e i n a f t e r ,   t r a n s l a t i o n   i s  ', ...
' i n c l u d e d   w i t h o u t   l i m i t a t i o n   i n   t h e   t e r m   " m o d i f i c a t i o n " . )  ', ...
'  ', ...
'     " S o u r c e   c o d e "   f o r   a   w o r k   m e a n s   t h e   p r e f e r r e d   f o r m   o f   t h e   w o r k   f o r  ', ...
' m a k i n g   m o d i f i c a t i o n s   t o   i t .     F o r   a   l i b r a r y ,   c o m p l e t e   s o u r c e   c o d e   m e a n s  ', ...
' a l l   t h e   s o u r c e   c o d e   f o r   a l l   m o d u l e s   i t   c o n t a i n s ,   p l u s   a n y   a s s o c i a t e d  ', ...
' i n t e r f a c e   d e f i n i t i o n   f i l e s ,   p l u s   t h e   s c r i p t s   u s e d   t o   c o n t r o l   c o m p i l a t i o n  ', ...
' a n d   i n s t a l l a t i o n   o f   t h e   l i b r a r y .  ', ...
'  ', ...
'     A c t i v i t i e s   o t h e r   t h a n   c o p y i n g ,   d i s t r i b u t i o n   a n d   m o d i f i c a t i o n   a r e   n o t  ', ...
' c o v e r e d   b y   t h i s   L i c e n s e ;   t h e y   a r e   o u t s i d e   i t s   s c o p e .     T h e   a c t   o f  ', ...
' r u n n i n g   a   p r o g r a m   u s i n g   t h e   L i b r a r y   i s   n o t   r e s t r i c t e d ,   a n d   o u t p u t   f r o m  ', ...
' s u c h   a   p r o g r a m   i s   c o v e r e d   o n l y   i f   i t s   c o n t e n t s   c o n s t i t u t e   a   w o r k   b a s e d  ', ...
' o n   t h e   L i b r a r y   ( i n d e p e n d e n t   o f   t h e   u s e   o f   t h e   L i b r a r y   i n   a   t o o l   f o r  ', ...
' w r i t i n g   i t ) .     W h e t h e r   t h a t   i s   t r u e   d e p e n d s   o n   w h a t   t h e   L i b r a r y   d o e s  ', ...
' a n d   w h a t   t h e   p r o g r a m   t h a t   u s e s   t h e   L i b r a r y   d o e s .  ', ...
'      ', ...
'     1 .   Y o u   m a y   c o p y   a n d   d i s t r i b u t e   v e r b a t i m   c o p i e s   o f   t h e   L i b r a r y '' s  ', ...
' c o m p l e t e   s o u r c e   c o d e   a s   y o u   r e c e i v e   i t ,   i n   a n y   m e d i u m ,   p r o v i d e d   t h a t  ', ...
' y o u   c o n s p i c u o u s l y   a n d   a p p r o p r i a t e l y   p u b l i s h   o n   e a c h   c o p y   a n  ', ...
' a p p r o p r i a t e   c o p y r i g h t   n o t i c e   a n d   d i s c l a i m e r   o f   w a r r a n t y ;   k e e p   i n t a c t  ', ...
' a l l   t h e   n o t i c e s   t h a t   r e f e r   t o   t h i s   L i c e n s e   a n d   t o   t h e   a b s e n c e   o f   a n y  ', ...
' w a r r a n t y ;   a n d   d i s t r i b u t e   a   c o p y   o f   t h i s   L i c e n s e   a l o n g   w i t h   t h e  ', ...
' L i b r a r y .  ', ...
'  ', ...
'     Y o u   m a y   c h a r g e   a   f e e   f o r   t h e   p h y s i c a l   a c t   o f   t r a n s f e r r i n g   a   c o p y ,  ', ...
' a n d   y o u   m a y   a t   y o u r   o p t i o n   o f f e r   w a r r a n t y   p r o t e c t i o n   i n   e x c h a n g e   f o r   a  ', ...
' f e e .  ', ...
'   ', ...
'     2 .   Y o u   m a y   m o d i f y   y o u r   c o p y   o r   c o p i e s   o f   t h e   L i b r a r y   o r   a n y   p o r t i o n  ', ...
' o f   i t ,   t h u s   f o r m i n g   a   w o r k   b a s e d   o n   t h e   L i b r a r y ,   a n d   c o p y   a n d  ', ...
' d i s t r i b u t e   s u c h   m o d i f i c a t i o n s   o r   w o r k   u n d e r   t h e   t e r m s   o f   S e c t i o n   1  ', ...
' a b o v e ,   p r o v i d e d   t h a t   y o u   a l s o   m e e t   a l l   o f   t h e s e   c o n d i t i o n s :  ', ...
'  ', ...
'         a )   T h e   m o d i f i e d   w o r k   m u s t   i t s e l f   b e   a   s o f t w a r e   l i b r a r y .  ', ...
'  ', ...
'         b )   Y o u   m u s t   c a u s e   t h e   f i l e s   m o d i f i e d   t o   c a r r y   p r o m i n e n t   n o t i c e s  ', ...
'         s t a t i n g   t h a t   y o u   c h a n g e d   t h e   f i l e s   a n d   t h e   d a t e   o f   a n y   c h a n g e .  ', ...
'  ', ...
'         c )   Y o u   m u s t   c a u s e   t h e   w h o l e   o f   t h e   w o r k   t o   b e   l i c e n s e d   a t   n o  ', ...
'         c h a r g e   t o   a l l   t h i r d   p a r t i e s   u n d e r   t h e   t e r m s   o f   t h i s   L i c e n s e .  ', ...
'  ', ...
'         d )   I f   a   f a c i l i t y   i n   t h e   m o d i f i e d   L i b r a r y   r e f e r s   t o   a   f u n c t i o n   o r   a  ', ...
'         t a b l e   o f   d a t a   t o   b e   s u p p l i e d   b y   a n   a p p l i c a t i o n   p r o g r a m   t h a t   u s e s  ', ...
'         t h e   f a c i l i t y ,   o t h e r   t h a n   a s   a n   a r g u m e n t   p a s s e d   w h e n   t h e   f a c i l i t y  ', ...
'         i s   i n v o k e d ,   t h e n   y o u   m u s t   m a k e   a   g o o d   f a i t h   e f f o r t   t o   e n s u r e   t h a t ,  ', ...
'         i n   t h e   e v e n t   a n   a p p l i c a t i o n   d o e s   n o t   s u p p l y   s u c h   f u n c t i o n   o r  ', ...
'         t a b l e ,   t h e   f a c i l i t y   s t i l l   o p e r a t e s ,   a n d   p e r f o r m s   w h a t e v e r   p a r t   o f  ', ...
'         i t s   p u r p o s e   r e m a i n s   m e a n i n g f u l .  ', ...
'  ', ...
'         ( F o r   e x a m p l e ,   a   f u n c t i o n   i n   a   l i b r a r y   t o   c o m p u t e   s q u a r e   r o o t s   h a s  ', ...
'         a   p u r p o s e   t h a t   i s   e n t i r e l y   w e l l - d e f i n e d   i n d e p e n d e n t   o f   t h e  ', ...
'         a p p l i c a t i o n .     T h e r e f o r e ,   S u b s e c t i o n   2 d   r e q u i r e s   t h a t   a n y  ', ...
'         a p p l i c a t i o n - s u p p l i e d   f u n c t i o n   o r   t a b l e   u s e d   b y   t h i s   f u n c t i o n   m u s t  ', ...
'         b e   o p t i o n a l :   i f   t h e   a p p l i c a t i o n   d o e s   n o t   s u p p l y   i t ,   t h e   s q u a r e  ', ...
'         r o o t   f u n c t i o n   m u s t   s t i l l   c o m p u t e   s q u a r e   r o o t s . )  ', ...
'  ', ...
' T h e s e   r e q u i r e m e n t s   a p p l y   t o   t h e   m o d i f i e d   w o r k   a s   a   w h o l e .     I f  ', ...
' i d e n t i f i a b l e   s e c t i o n s   o f   t h a t   w o r k   a r e   n o t   d e r i v e d   f r o m   t h e   L i b r a r y ,  ', ...
' a n d   c a n   b e   r e a s o n a b l y   c o n s i d e r e d   i n d e p e n d e n t   a n d   s e p a r a t e   w o r k s   i n  ', ...
' t h e m s e l v e s ,   t h e n   t h i s   L i c e n s e ,   a n d   i t s   t e r m s ,   d o   n o t   a p p l y   t o   t h o s e  ', ...
' s e c t i o n s   w h e n   y o u   d i s t r i b u t e   t h e m   a s   s e p a r a t e   w o r k s .     B u t   w h e n   y o u  ', ...
' d i s t r i b u t e   t h e   s a m e   s e c t i o n s   a s   p a r t   o f   a   w h o l e   w h i c h   i s   a   w o r k   b a s e d  ', ...
' o n   t h e   L i b r a r y ,   t h e   d i s t r i b u t i o n   o f   t h e   w h o l e   m u s t   b e   o n   t h e   t e r m s   o f  ', ...
' t h i s   L i c e n s e ,   w h o s e   p e r m i s s i o n s   f o r   o t h e r   l i c e n s e e s   e x t e n d   t o   t h e  ', ...
' e n t i r e   w h o l e ,   a n d   t h u s   t o   e a c h   a n d   e v e r y   p a r t   r e g a r d l e s s   o f   w h o   w r o t e  ', ...
' i t .  ', ...
'  ', ...
' T h u s ,   i t   i s   n o t   t h e   i n t e n t   o f   t h i s   s e c t i o n   t o   c l a i m   r i g h t s   o r   c o n t e s t  ', ...
' y o u r   r i g h t s   t o   w o r k   w r i t t e n   e n t i r e l y   b y   y o u ;   r a t h e r ,   t h e   i n t e n t   i s   t o  ', ...
' e x e r c i s e   t h e   r i g h t   t o   c o n t r o l   t h e   d i s t r i b u t i o n   o f   d e r i v a t i v e   o r  ', ...
' c o l l e c t i v e   w o r k s   b a s e d   o n   t h e   L i b r a r y .  ', ...
'  ', ...
' I n   a d d i t i o n ,   m e r e   a g g r e g a t i o n   o f   a n o t h e r   w o r k   n o t   b a s e d   o n   t h e   L i b r a r y  ', ...
' w i t h   t h e   L i b r a r y   ( o r   w i t h   a   w o r k   b a s e d   o n   t h e   L i b r a r y )   o n   a   v o l u m e   o f  ', ...
' a   s t o r a g e   o r   d i s t r i b u t i o n   m e d i u m   d o e s   n o t   b r i n g   t h e   o t h e r   w o r k   u n d e r  ', ...
' t h e   s c o p e   o f   t h i s   L i c e n s e .  ', ...
'  ', ...
'     3 .   Y o u   m a y   o p t   t o   a p p l y   t h e   t e r m s   o f   t h e   o r d i n a r y   G N U   G e n e r a l   P u b l i c  ', ...
' L i c e n s e   i n s t e a d   o f   t h i s   L i c e n s e   t o   a   g i v e n   c o p y   o f   t h e   L i b r a r y .     T o   d o  ', ...
' t h i s ,   y o u   m u s t   a l t e r   a l l   t h e   n o t i c e s   t h a t   r e f e r   t o   t h i s   L i c e n s e ,   s o  ', ...
' t h a t   t h e y   r e f e r   t o   t h e   o r d i n a r y   G N U   G e n e r a l   P u b l i c   L i c e n s e ,   v e r s i o n   2 ,  ', ...
' i n s t e a d   o f   t o   t h i s   L i c e n s e .     ( I f   a   n e w e r   v e r s i o n   t h a n   v e r s i o n   2   o f   t h e  ', ...
' o r d i n a r y   G N U   G e n e r a l   P u b l i c   L i c e n s e   h a s   a p p e a r e d ,   t h e n   y o u   c a n   s p e c i f y  ', ...
' t h a t   v e r s i o n   i n s t e a d   i f   y o u   w i s h . )     D o   n o t   m a k e   a n y   o t h e r   c h a n g e   i n  ', ...
' t h e s e   n o t i c e s .  ', ...
'   ', ...
'     O n c e   t h i s   c h a n g e   i s   m a d e   i n   a   g i v e n   c o p y ,   i t   i s   i r r e v e r s i b l e   f o r  ', ...
' t h a t   c o p y ,   s o   t h e   o r d i n a r y   G N U   G e n e r a l   P u b l i c   L i c e n s e   a p p l i e s   t o   a l l  ', ...
' s u b s e q u e n t   c o p i e s   a n d   d e r i v a t i v e   w o r k s   m a d e   f r o m   t h a t   c o p y .  ', ...
'  ', ...
'     T h i s   o p t i o n   i s   u s e f u l   w h e n   y o u   w i s h   t o   c o p y   p a r t   o f   t h e   c o d e   o f  ', ...
' t h e   L i b r a r y   i n t o   a   p r o g r a m   t h a t   i s   n o t   a   l i b r a r y .  ', ...
'  ', ...
'     4 .   Y o u   m a y   c o p y   a n d   d i s t r i b u t e   t h e   L i b r a r y   ( o r   a   p o r t i o n   o r  ', ...
' d e r i v a t i v e   o f   i t ,   u n d e r   S e c t i o n   2 )   i n   o b j e c t   c o d e   o r   e x e c u t a b l e   f o r m  ', ...
' u n d e r   t h e   t e r m s   o f   S e c t i o n s   1   a n d   2   a b o v e   p r o v i d e d   t h a t   y o u   a c c o m p a n y  ', ...
' i t   w i t h   t h e   c o m p l e t e   c o r r e s p o n d i n g   m a c h i n e - r e a d a b l e   s o u r c e   c o d e ,   w h i c h  ', ...
' m u s t   b e   d i s t r i b u t e d   u n d e r   t h e   t e r m s   o f   S e c t i o n s   1   a n d   2   a b o v e   o n   a  ', ...
' m e d i u m   c u s t o m a r i l y   u s e d   f o r   s o f t w a r e   i n t e r c h a n g e .  ', ...
'  ', ...
'     I f   d i s t r i b u t i o n   o f   o b j e c t   c o d e   i s   m a d e   b y   o f f e r i n g   a c c e s s   t o   c o p y  ', ...
' f r o m   a   d e s i g n a t e d   p l a c e ,   t h e n   o f f e r i n g   e q u i v a l e n t   a c c e s s   t o   c o p y   t h e  ', ...
' s o u r c e   c o d e   f r o m   t h e   s a m e   p l a c e   s a t i s f i e s   t h e   r e q u i r e m e n t   t o  ', ...
' d i s t r i b u t e   t h e   s o u r c e   c o d e ,   e v e n   t h o u g h   t h i r d   p a r t i e s   a r e   n o t  ', ...
' c o m p e l l e d   t o   c o p y   t h e   s o u r c e   a l o n g   w i t h   t h e   o b j e c t   c o d e .  ', ...
'  ', ...
'     5 .   A   p r o g r a m   t h a t   c o n t a i n s   n o   d e r i v a t i v e   o f   a n y   p o r t i o n   o f   t h e  ', ...
' L i b r a r y ,   b u t   i s   d e s i g n e d   t o   w o r k   w i t h   t h e   L i b r a r y   b y   b e i n g   c o m p i l e d   o r  ', ...
' l i n k e d   w i t h   i t ,   i s   c a l l e d   a   " w o r k   t h a t   u s e s   t h e   L i b r a r y " .     S u c h   a  ', ...
' w o r k ,   i n   i s o l a t i o n ,   i s   n o t   a   d e r i v a t i v e   w o r k   o f   t h e   L i b r a r y ,   a n d  ', ...
' t h e r e f o r e   f a l l s   o u t s i d e   t h e   s c o p e   o f   t h i s   L i c e n s e .  ', ...
'  ', ...
'     H o w e v e r ,   l i n k i n g   a   " w o r k   t h a t   u s e s   t h e   L i b r a r y "   w i t h   t h e   L i b r a r y  ', ...
' c r e a t e s   a n   e x e c u t a b l e   t h a t   i s   a   d e r i v a t i v e   o f   t h e   L i b r a r y   ( b e c a u s e   i t  ', ...
' c o n t a i n s   p o r t i o n s   o f   t h e   L i b r a r y ) ,   r a t h e r   t h a n   a   " w o r k   t h a t   u s e s   t h e  ', ...
' l i b r a r y " .     T h e   e x e c u t a b l e   i s   t h e r e f o r e   c o v e r e d   b y   t h i s   L i c e n s e .  ', ...
' S e c t i o n   6   s t a t e s   t e r m s   f o r   d i s t r i b u t i o n   o f   s u c h   e x e c u t a b l e s .  ', ...
'  ', ...
'     W h e n   a   " w o r k   t h a t   u s e s   t h e   L i b r a r y "   u s e s   m a t e r i a l   f r o m   a   h e a d e r   f i l e  ', ...
' t h a t   i s   p a r t   o f   t h e   L i b r a r y ,   t h e   o b j e c t   c o d e   f o r   t h e   w o r k   m a y   b e   a  ', ...
' d e r i v a t i v e   w o r k   o f   t h e   L i b r a r y   e v e n   t h o u g h   t h e   s o u r c e   c o d e   i s   n o t .  ', ...
' W h e t h e r   t h i s   i s   t r u e   i s   e s p e c i a l l y   s i g n i f i c a n t   i f   t h e   w o r k   c a n   b e  ', ...
' l i n k e d   w i t h o u t   t h e   L i b r a r y ,   o r   i f   t h e   w o r k   i s   i t s e l f   a   l i b r a r y .     T h e  ', ...
' t h r e s h o l d   f o r   t h i s   t o   b e   t r u e   i s   n o t   p r e c i s e l y   d e f i n e d   b y   l a w .  ', ...
'  ', ...
'     I f   s u c h   a n   o b j e c t   f i l e   u s e s   o n l y   n u m e r i c a l   p a r a m e t e r s ,   d a t a  ', ...
' s t r u c t u r e   l a y o u t s   a n d   a c c e s s o r s ,   a n d   s m a l l   m a c r o s   a n d   s m a l l   i n l i n e  ', ...
' f u n c t i o n s   ( t e n   l i n e s   o r   l e s s   i n   l e n g t h ) ,   t h e n   t h e   u s e   o f   t h e   o b j e c t  ', ...
' f i l e   i s   u n r e s t r i c t e d ,   r e g a r d l e s s   o f   w h e t h e r   i t   i s   l e g a l l y   a   d e r i v a t i v e  ', ...
' w o r k .     ( E x e c u t a b l e s   c o n t a i n i n g   t h i s   o b j e c t   c o d e   p l u s   p o r t i o n s   o f   t h e  ', ...
' L i b r a r y   w i l l   s t i l l   f a l l   u n d e r   S e c t i o n   6 . )  ', ...
'  ', ...
'     O t h e r w i s e ,   i f   t h e   w o r k   i s   a   d e r i v a t i v e   o f   t h e   L i b r a r y ,   y o u   m a y  ', ...
' d i s t r i b u t e   t h e   o b j e c t   c o d e   f o r   t h e   w o r k   u n d e r   t h e   t e r m s   o f   S e c t i o n   6 .  ', ...
' A n y   e x e c u t a b l e s   c o n t a i n i n g   t h a t   w o r k   a l s o   f a l l   u n d e r   S e c t i o n   6 ,  ', ...
' w h e t h e r   o r   n o t   t h e y   a r e   l i n k e d   d i r e c t l y   w i t h   t h e   L i b r a r y   i t s e l f .  ', ...
'   ', ...
'     6 .   A s   a n   e x c e p t i o n   t o   t h e   S e c t i o n s   a b o v e ,   y o u   m a y   a l s o   c o m b i n e   o r  ', ...
' l i n k   a   " w o r k   t h a t   u s e s   t h e   L i b r a r y "   w i t h   t h e   L i b r a r y   t o   p r o d u c e   a  ', ...
' w o r k   c o n t a i n i n g   p o r t i o n s   o f   t h e   L i b r a r y ,   a n d   d i s t r i b u t e   t h a t   w o r k  ', ...
' u n d e r   t e r m s   o f   y o u r   c h o i c e ,   p r o v i d e d   t h a t   t h e   t e r m s   p e r m i t  ', ...
' m o d i f i c a t i o n   o f   t h e   w o r k   f o r   t h e   c u s t o m e r '' s   o w n   u s e   a n d   r e v e r s e  ', ...
' e n g i n e e r i n g   f o r   d e b u g g i n g   s u c h   m o d i f i c a t i o n s .  ', ...
'  ', ...
'     Y o u   m u s t   g i v e   p r o m i n e n t   n o t i c e   w i t h   e a c h   c o p y   o f   t h e   w o r k   t h a t   t h e  ', ...
' L i b r a r y   i s   u s e d   i n   i t   a n d   t h a t   t h e   L i b r a r y   a n d   i t s   u s e   a r e   c o v e r e d   b y  ', ...
' t h i s   L i c e n s e .     Y o u   m u s t   s u p p l y   a   c o p y   o f   t h i s   L i c e n s e .     I f   t h e   w o r k  ', ...
' d u r i n g   e x e c u t i o n   d i s p l a y s   c o p y r i g h t   n o t i c e s ,   y o u   m u s t   i n c l u d e   t h e  ', ...
' c o p y r i g h t   n o t i c e   f o r   t h e   L i b r a r y   a m o n g   t h e m ,   a s   w e l l   a s   a   r e f e r e n c e  ', ...
' d i r e c t i n g   t h e   u s e r   t o   t h e   c o p y   o f   t h i s   L i c e n s e .     A l s o ,   y o u   m u s t   d o   o n e  ', ...
' o f   t h e s e   t h i n g s :  ', ...
'  ', ...
'         a )   A c c o m p a n y   t h e   w o r k   w i t h   t h e   c o m p l e t e   c o r r e s p o n d i n g  ', ...
'         m a c h i n e - r e a d a b l e   s o u r c e   c o d e   f o r   t h e   L i b r a r y   i n c l u d i n g   w h a t e v e r  ', ...
'         c h a n g e s   w e r e   u s e d   i n   t h e   w o r k   ( w h i c h   m u s t   b e   d i s t r i b u t e d   u n d e r  ', ...
'         S e c t i o n s   1   a n d   2   a b o v e ) ;   a n d ,   i f   t h e   w o r k   i s   a n   e x e c u t a b l e   l i n k e d  ', ...
'         w i t h   t h e   L i b r a r y ,   w i t h   t h e   c o m p l e t e   m a c h i n e - r e a d a b l e   " w o r k   t h a t  ', ...
'         u s e s   t h e   L i b r a r y " ,   a s   o b j e c t   c o d e   a n d / o r   s o u r c e   c o d e ,   s o   t h a t   t h e  ', ...
'         u s e r   c a n   m o d i f y   t h e   L i b r a r y   a n d   t h e n   r e l i n k   t o   p r o d u c e   a   m o d i f i e d  ', ...
'         e x e c u t a b l e   c o n t a i n i n g   t h e   m o d i f i e d   L i b r a r y .     ( I t   i s   u n d e r s t o o d  ', ...
'         t h a t   t h e   u s e r   w h o   c h a n g e s   t h e   c o n t e n t s   o f   d e f i n i t i o n s   f i l e s   i n   t h e  ', ...
'         L i b r a r y   w i l l   n o t   n e c e s s a r i l y   b e   a b l e   t o   r e c o m p i l e   t h e   a p p l i c a t i o n  ', ...
'         t o   u s e   t h e   m o d i f i e d   d e f i n i t i o n s . )  ', ...
'  ', ...
'         b )   U s e   a   s u i t a b l e   s h a r e d   l i b r a r y   m e c h a n i s m   f o r   l i n k i n g   w i t h   t h e  ', ...
'         L i b r a r y .     A   s u i t a b l e   m e c h a n i s m   i s   o n e   t h a t   ( 1 )   u s e s   a t   r u n   t i m e   a  ', ...
'         c o p y   o f   t h e   l i b r a r y   a l r e a d y   p r e s e n t   o n   t h e   u s e r '' s   c o m p u t e r   s y s t e m ,  ', ...
'         r a t h e r   t h a n   c o p y i n g   l i b r a r y   f u n c t i o n s   i n t o   t h e   e x e c u t a b l e ,   a n d   ( 2 )  ', ...
'         w i l l   o p e r a t e   p r o p e r l y   w i t h   a   m o d i f i e d   v e r s i o n   o f   t h e   l i b r a r y ,   i f  ', ...
'         t h e   u s e r   i n s t a l l s   o n e ,   a s   l o n g   a s   t h e   m o d i f i e d   v e r s i o n   i s  ', ...
'         i n t e r f a c e - c o m p a t i b l e   w i t h   t h e   v e r s i o n   t h a t   t h e   w o r k   w a s   m a d e   w i t h .  ', ...
'  ', ...
'         c )   A c c o m p a n y   t h e   w o r k   w i t h   a   w r i t t e n   o f f e r ,   v a l i d   f o r   a t  ', ...
'         l e a s t   t h r e e   y e a r s ,   t o   g i v e   t h e   s a m e   u s e r   t h e   m a t e r i a l s  ', ...
'         s p e c i f i e d   i n   S u b s e c t i o n   6 a ,   a b o v e ,   f o r   a   c h a r g e   n o   m o r e  ', ...
'         t h a n   t h e   c o s t   o f   p e r f o r m i n g   t h i s   d i s t r i b u t i o n .  ', ...
'  ', ...
'         d )   I f   d i s t r i b u t i o n   o f   t h e   w o r k   i s   m a d e   b y   o f f e r i n g   a c c e s s   t o   c o p y  ', ...
'         f r o m   a   d e s i g n a t e d   p l a c e ,   o f f e r   e q u i v a l e n t   a c c e s s   t o   c o p y   t h e   a b o v e  ', ...
'         s p e c i f i e d   m a t e r i a l s   f r o m   t h e   s a m e   p l a c e .  ', ...
'  ', ...
'         e )   V e r i f y   t h a t   t h e   u s e r   h a s   a l r e a d y   r e c e i v e d   a   c o p y   o f   t h e s e  ', ...
'         m a t e r i a l s   o r   t h a t   y o u   h a v e   a l r e a d y   s e n t   t h i s   u s e r   a   c o p y .  ', ...
'  ', ...
'     F o r   a n   e x e c u t a b l e ,   t h e   r e q u i r e d   f o r m   o f   t h e   " w o r k   t h a t   u s e s   t h e  ', ...
' L i b r a r y "   m u s t   i n c l u d e   a n y   d a t a   a n d   u t i l i t y   p r o g r a m s   n e e d e d   f o r  ', ...
' r e p r o d u c i n g   t h e   e x e c u t a b l e   f r o m   i t .     H o w e v e r ,   a s   a   s p e c i a l   e x c e p t i o n ,  ', ...
' t h e   m a t e r i a l s   t o   b e   d i s t r i b u t e d   n e e d   n o t   i n c l u d e   a n y t h i n g   t h a t   i s  ', ...
' n o r m a l l y   d i s t r i b u t e d   ( i n   e i t h e r   s o u r c e   o r   b i n a r y   f o r m )   w i t h   t h e   m a j o r  ', ...
' c o m p o n e n t s   ( c o m p i l e r ,   k e r n e l ,   a n d   s o   o n )   o f   t h e   o p e r a t i n g   s y s t e m   o n  ', ...
' w h i c h   t h e   e x e c u t a b l e   r u n s ,   u n l e s s   t h a t   c o m p o n e n t   i t s e l f   a c c o m p a n i e s  ', ...
' t h e   e x e c u t a b l e .  ', ...
'  ', ...
'     I t   m a y   h a p p e n   t h a t   t h i s   r e q u i r e m e n t   c o n t r a d i c t s   t h e   l i c e n s e  ', ...
' r e s t r i c t i o n s   o f   o t h e r   p r o p r i e t a r y   l i b r a r i e s   t h a t   d o   n o t   n o r m a l l y  ', ...
' a c c o m p a n y   t h e   o p e r a t i n g   s y s t e m .     S u c h   a   c o n t r a d i c t i o n   m e a n s   y o u   c a n n o t  ', ...
' u s e   b o t h   t h e m   a n d   t h e   L i b r a r y   t o g e t h e r   i n   a n   e x e c u t a b l e   t h a t   y o u  ', ...
' d i s t r i b u t e .  ', ...
'   ', ...
'     7 .   Y o u   m a y   p l a c e   l i b r a r y   f a c i l i t i e s   t h a t   a r e   a   w o r k   b a s e d   o n   t h e  ', ...
' L i b r a r y   s i d e - b y - s i d e   i n   a   s i n g l e   l i b r a r y   t o g e t h e r   w i t h   o t h e r   l i b r a r y  ', ...
' f a c i l i t i e s   n o t   c o v e r e d   b y   t h i s   L i c e n s e ,   a n d   d i s t r i b u t e   s u c h   a   c o m b i n e d  ', ...
' l i b r a r y ,   p r o v i d e d   t h a t   t h e   s e p a r a t e   d i s t r i b u t i o n   o f   t h e   w o r k   b a s e d   o n  ', ...
' t h e   L i b r a r y   a n d   o f   t h e   o t h e r   l i b r a r y   f a c i l i t i e s   i s   o t h e r w i s e  ', ...
' p e r m i t t e d ,   a n d   p r o v i d e d   t h a t   y o u   d o   t h e s e   t w o   t h i n g s :  ', ...
'  ', ...
'         a )   A c c o m p a n y   t h e   c o m b i n e d   l i b r a r y   w i t h   a   c o p y   o f   t h e   s a m e   w o r k  ', ...
'         b a s e d   o n   t h e   L i b r a r y ,   u n c o m b i n e d   w i t h   a n y   o t h e r   l i b r a r y  ', ...
'         f a c i l i t i e s .     T h i s   m u s t   b e   d i s t r i b u t e d   u n d e r   t h e   t e r m s   o f   t h e  ', ...
'         S e c t i o n s   a b o v e .  ', ...
'  ', ...
'         b )   G i v e   p r o m i n e n t   n o t i c e   w i t h   t h e   c o m b i n e d   l i b r a r y   o f   t h e   f a c t  ', ...
'         t h a t   p a r t   o f   i t   i s   a   w o r k   b a s e d   o n   t h e   L i b r a r y ,   a n d   e x p l a i n i n g  ', ...
'         w h e r e   t o   f i n d   t h e   a c c o m p a n y i n g   u n c o m b i n e d   f o r m   o f   t h e   s a m e   w o r k .  ', ...
'  ', ...
'     8 .   Y o u   m a y   n o t   c o p y ,   m o d i f y ,   s u b l i c e n s e ,   l i n k   w i t h ,   o r   d i s t r i b u t e  ', ...
' t h e   L i b r a r y   e x c e p t   a s   e x p r e s s l y   p r o v i d e d   u n d e r   t h i s   L i c e n s e .     A n y  ', ...
' a t t e m p t   o t h e r w i s e   t o   c o p y ,   m o d i f y ,   s u b l i c e n s e ,   l i n k   w i t h ,   o r  ', ...
' d i s t r i b u t e   t h e   L i b r a r y   i s   v o i d ,   a n d   w i l l   a u t o m a t i c a l l y   t e r m i n a t e   y o u r  ', ...
' r i g h t s   u n d e r   t h i s   L i c e n s e .     H o w e v e r ,   p a r t i e s   w h o   h a v e   r e c e i v e d   c o p i e s ,  ', ...
' o r   r i g h t s ,   f r o m   y o u   u n d e r   t h i s   L i c e n s e   w i l l   n o t   h a v e   t h e i r   l i c e n s e s  ', ...
' t e r m i n a t e d   s o   l o n g   a s   s u c h   p a r t i e s   r e m a i n   i n   f u l l   c o m p l i a n c e .  ', ...
'  ', ...
'     9 .   Y o u   a r e   n o t   r e q u i r e d   t o   a c c e p t   t h i s   L i c e n s e ,   s i n c e   y o u   h a v e   n o t  ', ...
' s i g n e d   i t .     H o w e v e r ,   n o t h i n g   e l s e   g r a n t s   y o u   p e r m i s s i o n   t o   m o d i f y   o r  ', ...
' d i s t r i b u t e   t h e   L i b r a r y   o r   i t s   d e r i v a t i v e   w o r k s .     T h e s e   a c t i o n s   a r e  ', ...
' p r o h i b i t e d   b y   l a w   i f   y o u   d o   n o t   a c c e p t   t h i s   L i c e n s e .     T h e r e f o r e ,   b y  ', ...
' m o d i f y i n g   o r   d i s t r i b u t i n g   t h e   L i b r a r y   ( o r   a n y   w o r k   b a s e d   o n   t h e  ', ...
' L i b r a r y ) ,   y o u   i n d i c a t e   y o u r   a c c e p t a n c e   o f   t h i s   L i c e n s e   t o   d o   s o ,   a n d  ', ...
' a l l   i t s   t e r m s   a n d   c o n d i t i o n s   f o r   c o p y i n g ,   d i s t r i b u t i n g   o r   m o d i f y i n g  ', ...
' t h e   L i b r a r y   o r   w o r k s   b a s e d   o n   i t .  ', ...
'  ', ...
'     1 0 .   E a c h   t i m e   y o u   r e d i s t r i b u t e   t h e   L i b r a r y   ( o r   a n y   w o r k   b a s e d   o n   t h e  ', ...
' L i b r a r y ) ,   t h e   r e c i p i e n t   a u t o m a t i c a l l y   r e c e i v e s   a   l i c e n s e   f r o m   t h e  ', ...
' o r i g i n a l   l i c e n s o r   t o   c o p y ,   d i s t r i b u t e ,   l i n k   w i t h   o r   m o d i f y   t h e   L i b r a r y  ', ...
' s u b j e c t   t o   t h e s e   t e r m s   a n d   c o n d i t i o n s .     Y o u   m a y   n o t   i m p o s e   a n y   f u r t h e r  ', ...
' r e s t r i c t i o n s   o n   t h e   r e c i p i e n t s ''   e x e r c i s e   o f   t h e   r i g h t s   g r a n t e d   h e r e i n .  ', ...
' Y o u   a r e   n o t   r e s p o n s i b l e   f o r   e n f o r c i n g   c o m p l i a n c e   b y   t h i r d   p a r t i e s   w i t h  ', ...
' t h i s   L i c e n s e .  ', ...
'   ', ...
'     1 1 .   I f ,   a s   a   c o n s e q u e n c e   o f   a   c o u r t   j u d g m e n t   o r   a l l e g a t i o n   o f   p a t e n t  ', ...
' i n f r i n g e m e n t   o r   f o r   a n y   o t h e r   r e a s o n   ( n o t   l i m i t e d   t o   p a t e n t   i s s u e s ) ,  ', ...
' c o n d i t i o n s   a r e   i m p o s e d   o n   y o u   ( w h e t h e r   b y   c o u r t   o r d e r ,   a g r e e m e n t   o r  ', ...
' o t h e r w i s e )   t h a t   c o n t r a d i c t   t h e   c o n d i t i o n s   o f   t h i s   L i c e n s e ,   t h e y   d o   n o t  ', ...
' e x c u s e   y o u   f r o m   t h e   c o n d i t i o n s   o f   t h i s   L i c e n s e .     I f   y o u   c a n n o t  ', ...
' d i s t r i b u t e   s o   a s   t o   s a t i s f y   s i m u l t a n e o u s l y   y o u r   o b l i g a t i o n s   u n d e r   t h i s  ', ...
' L i c e n s e   a n d   a n y   o t h e r   p e r t i n e n t   o b l i g a t i o n s ,   t h e n   a s   a   c o n s e q u e n c e   y o u  ', ...
' m a y   n o t   d i s t r i b u t e   t h e   L i b r a r y   a t   a l l .     F o r   e x a m p l e ,   i f   a   p a t e n t  ', ...
' l i c e n s e   w o u l d   n o t   p e r m i t   r o y a l t y - f r e e   r e d i s t r i b u t i o n   o f   t h e   L i b r a r y   b y  ', ...
' a l l   t h o s e   w h o   r e c e i v e   c o p i e s   d i r e c t l y   o r   i n d i r e c t l y   t h r o u g h   y o u ,   t h e n  ', ...
' t h e   o n l y   w a y   y o u   c o u l d   s a t i s f y   b o t h   i t   a n d   t h i s   L i c e n s e   w o u l d   b e   t o  ', ...
' r e f r a i n   e n t i r e l y   f r o m   d i s t r i b u t i o n   o f   t h e   L i b r a r y .  ', ...
'  ', ...
' I f   a n y   p o r t i o n   o f   t h i s   s e c t i o n   i s   h e l d   i n v a l i d   o r   u n e n f o r c e a b l e   u n d e r   a n y  ', ...
' p a r t i c u l a r   c i r c u m s t a n c e ,   t h e   b a l a n c e   o f   t h e   s e c t i o n   i s   i n t e n d e d   t o   a p p l y ,  ', ...
' a n d   t h e   s e c t i o n   a s   a   w h o l e   i s   i n t e n d e d   t o   a p p l y   i n   o t h e r   c i r c u m s t a n c e s .  ', ...
'  ', ...
' I t   i s   n o t   t h e   p u r p o s e   o f   t h i s   s e c t i o n   t o   i n d u c e   y o u   t o   i n f r i n g e   a n y  ', ...
' p a t e n t s   o r   o t h e r   p r o p e r t y   r i g h t   c l a i m s   o r   t o   c o n t e s t   v a l i d i t y   o f   a n y  ', ...
' s u c h   c l a i m s ;   t h i s   s e c t i o n   h a s   t h e   s o l e   p u r p o s e   o f   p r o t e c t i n g   t h e  ', ...
' i n t e g r i t y   o f   t h e   f r e e   s o f t w a r e   d i s t r i b u t i o n   s y s t e m   w h i c h   i s  ', ...
' i m p l e m e n t e d   b y   p u b l i c   l i c e n s e   p r a c t i c e s .     M a n y   p e o p l e   h a v e   m a d e  ', ...
' g e n e r o u s   c o n t r i b u t i o n s   t o   t h e   w i d e   r a n g e   o f   s o f t w a r e   d i s t r i b u t e d  ', ...
' t h r o u g h   t h a t   s y s t e m   i n   r e l i a n c e   o n   c o n s i s t e n t   a p p l i c a t i o n   o f   t h a t  ', ...
' s y s t e m ;   i t   i s   u p   t o   t h e   a u t h o r / d o n o r   t o   d e c i d e   i f   h e   o r   s h e   i s   w i l l i n g  ', ...
' t o   d i s t r i b u t e   s o f t w a r e   t h r o u g h   a n y   o t h e r   s y s t e m   a n d   a   l i c e n s e e   c a n n o t  ', ...
' i m p o s e   t h a t   c h o i c e .  ', ...
'  ', ...
' T h i s   s e c t i o n   i s   i n t e n d e d   t o   m a k e   t h o r o u g h l y   c l e a r   w h a t   i s   b e l i e v e d   t o  ', ...
' b e   a   c o n s e q u e n c e   o f   t h e   r e s t   o f   t h i s   L i c e n s e .  ', ...
'  ', ...
'     1 2 .   I f   t h e   d i s t r i b u t i o n   a n d / o r   u s e   o f   t h e   L i b r a r y   i s   r e s t r i c t e d   i n  ', ...
' c e r t a i n   c o u n t r i e s   e i t h e r   b y   p a t e n t s   o r   b y   c o p y r i g h t e d   i n t e r f a c e s ,   t h e  ', ...
' o r i g i n a l   c o p y r i g h t   h o l d e r   w h o   p l a c e s   t h e   L i b r a r y   u n d e r   t h i s   L i c e n s e   m a y   a d d  ', ...
' a n   e x p l i c i t   g e o g r a p h i c a l   d i s t r i b u t i o n   l i m i t a t i o n   e x c l u d i n g   t h o s e   c o u n t r i e s ,  ', ...
' s o   t h a t   d i s t r i b u t i o n   i s   p e r m i t t e d   o n l y   i n   o r   a m o n g   c o u n t r i e s   n o t   t h u s  ', ...
' e x c l u d e d .     I n   s u c h   c a s e ,   t h i s   L i c e n s e   i n c o r p o r a t e s   t h e   l i m i t a t i o n   a s   i f  ', ...
' w r i t t e n   i n   t h e   b o d y   o f   t h i s   L i c e n s e .  ', ...
'  ', ...
'     1 3 .   T h e   F r e e   S o f t w a r e   F o u n d a t i o n   m a y   p u b l i s h   r e v i s e d   a n d / o r   n e w  ', ...
' v e r s i o n s   o f   t h e   L e s s e r   G e n e r a l   P u b l i c   L i c e n s e   f r o m   t i m e   t o   t i m e .  ', ...
' S u c h   n e w   v e r s i o n s   w i l l   b e   s i m i l a r   i n   s p i r i t   t o   t h e   p r e s e n t   v e r s i o n ,  ', ...
' b u t   m a y   d i f f e r   i n   d e t a i l   t o   a d d r e s s   n e w   p r o b l e m s   o r   c o n c e r n s .  ', ...
'  ', ...
' E a c h   v e r s i o n   i s   g i v e n   a   d i s t i n g u i s h i n g   v e r s i o n   n u m b e r .     I f   t h e   L i b r a r y  ', ...
' s p e c i f i e s   a   v e r s i o n   n u m b e r   o f   t h i s   L i c e n s e   w h i c h   a p p l i e s   t o   i t   a n d  ', ...
' " a n y   l a t e r   v e r s i o n " ,   y o u   h a v e   t h e   o p t i o n   o f   f o l l o w i n g   t h e   t e r m s   a n d  ', ...
' c o n d i t i o n s   e i t h e r   o f   t h a t   v e r s i o n   o r   o f   a n y   l a t e r   v e r s i o n   p u b l i s h e d   b y  ', ...
' t h e   F r e e   S o f t w a r e   F o u n d a t i o n .     I f   t h e   L i b r a r y   d o e s   n o t   s p e c i f y   a  ', ...
' l i c e n s e   v e r s i o n   n u m b e r ,   y o u   m a y   c h o o s e   a n y   v e r s i o n   e v e r   p u b l i s h e d   b y  ', ...
' t h e   F r e e   S o f t w a r e   F o u n d a t i o n .  ', ...
'   ', ...
'     1 4 .   I f   y o u   w i s h   t o   i n c o r p o r a t e   p a r t s   o f   t h e   L i b r a r y   i n t o   o t h e r   f r e e  ', ...
' p r o g r a m s   w h o s e   d i s t r i b u t i o n   c o n d i t i o n s   a r e   i n c o m p a t i b l e   w i t h   t h e s e ,  ', ...
' w r i t e   t o   t h e   a u t h o r   t o   a s k   f o r   p e r m i s s i o n .     F o r   s o f t w a r e   w h i c h   i s  ', ...
' c o p y r i g h t e d   b y   t h e   F r e e   S o f t w a r e   F o u n d a t i o n ,   w r i t e   t o   t h e   F r e e  ', ...
' S o f t w a r e   F o u n d a t i o n ;   w e   s o m e t i m e s   m a k e   e x c e p t i o n s   f o r   t h i s .     O u r  ', ...
' d e c i s i o n   w i l l   b e   g u i d e d   b y   t h e   t w o   g o a l s   o f   p r e s e r v i n g   t h e   f r e e   s t a t u s  ', ...
' o f   a l l   d e r i v a t i v e s   o f   o u r   f r e e   s o f t w a r e   a n d   o f   p r o m o t i n g   t h e   s h a r i n g  ', ...
' a n d   r e u s e   o f   s o f t w a r e   g e n e r a l l y .  ', ...
'  ', ...
' 	 	 	         N O   W A R R A N T Y  ', ...
'  ', ...
'     1 5 .   B E C A U S E   T H E   L I B R A R Y   I S   L I C E N S E D   F R E E   O F   C H A R G E ,   T H E R E   I S   N O  ', ...
' W A R R A N T Y   F O R   T H E   L I B R A R Y ,   T O   T H E   E X T E N T   P E R M I T T E D   B Y   A P P L I C A B L E   L A W .  ', ...
' E X C E P T   W H E N   O T H E R W I S E   S T A T E D   I N   W R I T I N G   T H E   C O P Y R I G H T   H O L D E R S   A N D / O R  ', ...
' O T H E R   P A R T I E S   P R O V I D E   T H E   L I B R A R Y   " A S   I S "   W I T H O U T   W A R R A N T Y   O F   A N Y  ', ...
' K I N D ,   E I T H E R   E X P R E S S E D   O R   I M P L I E D ,   I N C L U D I N G ,   B U T   N O T   L I M I T E D   T O ,   T H E  ', ...
' I M P L I E D   W A R R A N T I E S   O F   M E R C H A N T A B I L I T Y   A N D   F I T N E S S   F O R   A   P A R T I C U L A R  ', ...
' P U R P O S E .     T H E   E N T I R E   R I S K   A S   T O   T H E   Q U A L I T Y   A N D   P E R F O R M A N C E   O F   T H E  ', ...
' L I B R A R Y   I S   W I T H   Y O U .     S H O U L D   T H E   L I B R A R Y   P R O V E   D E F E C T I V E ,   Y O U   A S S U M E  ', ...
' T H E   C O S T   O F   A L L   N E C E S S A R Y   S E R V I C I N G ,   R E P A I R   O R   C O R R E C T I O N .  ', ...
'  ', ...
'     1 6 .   I N   N O   E V E N T   U N L E S S   R E Q U I R E D   B Y   A P P L I C A B L E   L A W   O R   A G R E E D   T O   I N  ', ...
' W R I T I N G   W I L L   A N Y   C O P Y R I G H T   H O L D E R ,   O R   A N Y   O T H E R   P A R T Y   W H O   M A Y   M O D I F Y  ', ...
' A N D / O R   R E D I S T R I B U T E   T H E   L I B R A R Y   A S   P E R M I T T E D   A B O V E ,   B E   L I A B L E   T O   Y O U  ', ...
' F O R   D A M A G E S ,   I N C L U D I N G   A N Y   G E N E R A L ,   S P E C I A L ,   I N C I D E N T A L   O R  ', ...
' C O N S E Q U E N T I A L   D A M A G E S   A R I S I N G   O U T   O F   T H E   U S E   O R   I N A B I L I T Y   T O   U S E   T H E  ', ...
' L I B R A R Y   ( I N C L U D I N G   B U T   N O T   L I M I T E D   T O   L O S S   O F   D A T A   O R   D A T A   B E I N G  ', ...
' R E N D E R E D   I N A C C U R A T E   O R   L O S S E S   S U S T A I N E D   B Y   Y O U   O R   T H I R D   P A R T I E S   O R   A  ', ...
' F A I L U R E   O F   T H E   L I B R A R Y   T O   O P E R A T E   W I T H   A N Y   O T H E R   S O F T W A R E ) ,   E V E N   I F  ', ...
' S U C H   H O L D E R   O R   O T H E R   P A R T Y   H A S   B E E N   A D V I S E D   O F   T H E   P O S S I B I L I T Y   O F   S U C H  ', ...
' D A M A G E S .  ', ...
'  ', ...
' 	 	           E N D   O F   T E R M S   A N D   C O N D I T I O N S  ', ...
'   ', ...
'                       H o w   t o   A p p l y   T h e s e   T e r m s   t o   Y o u r   N e w   L i b r a r i e s  ', ...
'  ', ...
'     I f   y o u   d e v e l o p   a   n e w   l i b r a r y ,   a n d   y o u   w a n t   i t   t o   b e   o f   t h e   g r e a t e s t  ', ...
' p o s s i b l e   u s e   t o   t h e   p u b l i c ,   w e   r e c o m m e n d   m a k i n g   i t   f r e e   s o f t w a r e   t h a t  ', ...
' e v e r y o n e   c a n   r e d i s t r i b u t e   a n d   c h a n g e .     Y o u   c a n   d o   s o   b y   p e r m i t t i n g  ', ...
' r e d i s t r i b u t i o n   u n d e r   t h e s e   t e r m s   ( o r ,   a l t e r n a t i v e l y ,   u n d e r   t h e   t e r m s   o f   t h e  ', ...
' o r d i n a r y   G e n e r a l   P u b l i c   L i c e n s e ) .  ', ...
'  ', ...
'     T o   a p p l y   t h e s e   t e r m s ,   a t t a c h   t h e   f o l l o w i n g   n o t i c e s   t o   t h e   l i b r a r y .     I t   i s  ', ...
' s a f e s t   t o   a t t a c h   t h e m   t o   t h e   s t a r t   o f   e a c h   s o u r c e   f i l e   t o   m o s t   e f f e c t i v e l y  ', ...
' c o n v e y   t h e   e x c l u s i o n   o f   w a r r a n t y ;   a n d   e a c h   f i l e   s h o u l d   h a v e   a t   l e a s t   t h e  ', ...
' " c o p y r i g h t "   l i n e   a n d   a   p o i n t e r   t o   w h e r e   t h e   f u l l   n o t i c e   i s   f o u n d .  ', ...
'  ', ...
'         < o n e   l i n e   t o   g i v e   t h e   l i b r a r y '' s   n a m e   a n d   a   b r i e f   i d e a   o f   w h a t   i t   d o e s . >  ', ...
'         C o p y r i g h t   ( C )   < y e a r >     < n a m e   o f   a u t h o r >  ', ...
'  ', ...
'         T h i s   l i b r a r y   i s   f r e e   s o f t w a r e ;   y o u   c a n   r e d i s t r i b u t e   i t   a n d / o r  ', ...
'         m o d i f y   i t   u n d e r   t h e   t e r m s   o f   t h e   G N U   L e s s e r   G e n e r a l   P u b l i c  ', ...
'         L i c e n s e   a s   p u b l i s h e d   b y   t h e   F r e e   S o f t w a r e   F o u n d a t i o n ;   e i t h e r  ', ...
'         v e r s i o n   2 . 1   o f   t h e   L i c e n s e ,   o r   ( a t   y o u r   o p t i o n )   a n y   l a t e r   v e r s i o n .  ', ...
'  ', ...
'         T h i s   l i b r a r y   i s   d i s t r i b u t e d   i n   t h e   h o p e   t h a t   i t   w i l l   b e   u s e f u l ,  ', ...
'         b u t   W I T H O U T   A N Y   W A R R A N T Y ;   w i t h o u t   e v e n   t h e   i m p l i e d   w a r r a n t y   o f  ', ...
'         M E R C H A N T A B I L I T Y   o r   F I T N E S S   F O R   A   P A R T I C U L A R   P U R P O S E .     S e e   t h e   G N U  ', ...
'         L e s s e r   G e n e r a l   P u b l i c   L i c e n s e   f o r   m o r e   d e t a i l s .  ', ...
'  ', ...
'         Y o u   s h o u l d   h a v e   r e c e i v e d   a   c o p y   o f   t h e   G N U   L e s s e r   G e n e r a l   P u b l i c  ', ...
'         L i c e n s e   a l o n g   w i t h   t h i s   l i b r a r y ;   i f   n o t ,   w r i t e   t o   t h e   F r e e   S o f t w a r e  ', ...
'         F o u n d a t i o n ,   I n c . ,   5 9   T e m p l e   P l a c e ,   S u i t e   3 3 0 ,   B o s t o n ,   M A     0 2 1 1 1 - 1 3 0 7     U S A  ', ...
'  ', ...
' A l s o   a d d   i n f o r m a t i o n   o n   h o w   t o   c o n t a c t   y o u   b y   e l e c t r o n i c   a n d   p a p e r   m a i l .  ', ...
'  ', ...
' Y o u   s h o u l d   a l s o   g e t   y o u r   e m p l o y e r   ( i f   y o u   w o r k   a s   a   p r o g r a m m e r )   o r   y o u r  ', ...
' s c h o o l ,   i f   a n y ,   t o   s i g n   a   " c o p y r i g h t   d i s c l a i m e r "   f o r   t h e   l i b r a r y ,   i f  ', ...
' n e c e s s a r y .     H e r e   i s   a   s a m p l e ;   a l t e r   t h e   n a m e s :  ', ...
'  ', ...
'     Y o y o d y n e ,   I n c . ,   h e r e b y   d i s c l a i m s   a l l   c o p y r i g h t   i n t e r e s t   i n   t h e  ', ...
'     l i b r a r y   ` F r o b ''   ( a   l i b r a r y   f o r   t w e a k i n g   k n o b s )   w r i t t e n   b y   J a m e s   R a n d o m   H a c k e r .  ', ...
'  ', ...
'     < s i g n a t u r e   o f   T y   C o o n > ,   1   A p r i l   1 9 9 0  ', ...
'     T y   C o o n ,   P r e s i d e n t   o f   V i c e  ', ...
'  ', ...
' T h a t '' s   a l l   t h e r e   i s   t o   i t !  ', ...
'  ', ...
'  ', ...
'');
  
 case {'credits', 'authors'}
t0 = strvcat(...
' 1 .   M a i n   c r e d i t s  ', ...
' - - - - - - - - - - - - - - -  ', ...
' P l e x   v e r s i o n   2 . 0  ', ...
'       W r i t t e n   b y   P a t r i c k   P e r r y ,   a n d   c o n t r i b u t o r s .  ', ...
'       M A T L A B   i n t e r f a c e   d e s i g n e d   b y   V i n   d e   S i l v a .  ', ...
'  ', ...
' P l e x   M e t r i c   D a t a   T o o l b o x   2 . 0  ', ...
'       W r i t t e n   b y   V i n   d e   S i l v a ,   P a t r i c k   P e r r y   a n d   c o n t r i b u t o r s .  ', ...
'  ', ...
' P u b l i c   r e l e a s e   d a t e   2 0 0 4 - O c t o b e r - 3 1 .  ', ...
'  ', ...
' P l e x   w a s   d e v e l o p e d   a t   t h e   D e p a r t m e n t   o f   M a t h e m a t i c s ,   S t a n f o r d   U n i v e r s i t y  ', ...
' a s   p a r t   o f   a n   o n g o i n g   c o m p u t a t i o n a l   t o p o l o g y / s t a t i s t i c s   p r o j e c t   h e a d e d   b y  ', ...
' P r o f .   G u n n a r   C a r l s s o n .   T h e   m a i n   a u t h o r s   o f   P l e x   o f f e r   t h e i r   s i n c e r e   t h a n k s  ', ...
' t o   G u n n a r   f o r   h i s   g e n e r o u s   s u p p o r t   a n d   e n c o u r a g e m e n t .  ', ...
'  ', ...
' 2 .   H i s t o r y  ', ...
' - - - - - - - - - -  ', ...
' T h e   P l e x   c o m p u t a t i o n a l   t o p o l o g y   l i b r a r y   h a s   b e e n   i n   d e v e l o p m e n t   s i n c e  ', ...
' e a r l y   2 0 0 0 .  ', ...
'  ', ...
' P l e x   b e g a n   a s   a   c o l l e c t i o n   o f   M A T L A B   s c r i p t s   w r i t t e n   b y   V i n   d e   S i l v a .   T h e  ', ...
' P l e x   l i b r a r y   d e f i n e d   a   M A T L A B   o b j e c t   c l a s s   ( t h e   " p l e x   o b j e c t " )   a n d   m e t h o d s  ', ...
' f o r   m a n i p u l a t i n g   s i m p l i c i a l   c o m p l e x e s   a n d   c o m p u t i n g   t h e i r   h o m o l o g y   g r o u p s .  ', ...
'  ', ...
' D a w n   B a n a r d   a n d   P e t e r   L e e   c o n t r i b u t e d   s e v e r a l   i m p r o v e m e n t s   t o   t h e   l i b r a r y  ', ...
' d u r i n g   2 0 0 1 .   T h e s e   w e r e   m o s t l y   w r i t t e n   i n   C + +   u s i n g   M A T L A B '' s   M E X - f i l e  ', ...
' i n t e r f a c e .  ', ...
'  ', ...
' P l e x   1 . 0   ( u n d e r   t h e   m i s l e a d i n g   n a m e   " P l e x   2 . 1 " )   w a s   m a d e   p u b l i c l y  ', ...
' a v a i l a b l e   i n   A u g u s t   2 0 0 3 ,   a f t e r   s o m e   a d d i t i o n a l   w o r k   b y   P a t r i c k   P e r r y .  ', ...
'  ', ...
' P a t r i c k   P e r r y   u n d e r t o o k   a n   a l m o s t   c o m p l e t e   r e w r i t e   o f   P l e x   d u r i n g   2 0 0 3 - 4 .    ', ...
' T h e   e n t i r e   c o r e   l i b r a r y   ( t h e   o b j e c t   c l a s s ,   i t s   m e t h o d s ,   a n d   t h e   m o s t  ', ...
' i m p o r t a n t   l i b r a r y   f u n c t i o n s )   w a s   r e w r i t t e n   f r o m   s c r a t c h .   A t   t h e   h e a r t   o f  ', ...
' P l e x   2 . 0   i s   a   C + +   l i b r a r y   c a l l e d   " s c o m p l e x " ,   w h i c h   m a y   b e   u s e d  ', ...
' i n d e p e n d e n t l y   b y   C + +   p r o g r a m m e r s .   T h e r e   i s   a   M A T L A B   f r o n t   e n d   ( b o l t e d   o n  ', ...
' u s i n g   t h e   M E X   i n t e r f a c e )   w h i c h   i s   f u n c t i o n a l l y   v e r y   s i m i l a r   t o   t h e  ', ...
' o r i g i n a l   v e r s i o n .  ', ...
'  ', ...
' I n   a d d i t i o n   t o   t h e   c o r e   l i b r a r y ,   P l e x   2 . 0   i n c l u d e s   a   " m e t r i c   d a t a   t o o l b o x "  ', ...
' i n c o r p o r a t i n g   v a r i o u s   a l g o r i t h m s   f o r   b u i l d i n g   s i m p l i c i a l   c o m p l e x e s   f r o m  ', ...
' n u m e r i c a l   d a t a .   M o s t   o f   t h i s   c o d e   w a s   w r i t t e n   b y   V i n   d e   S i l v a   a n d   P a t r i c k  ', ...
' P e r r y .  ', ...
'  ', ...
' 3 .   C o n t r i b u t o r s  ', ...
' - - - - - - - - - - - - - - -  ', ...
' W e   a c k n o w l e d g e   t h e   f o l l o w i n g   s i g n i f i c a n t   c o n t r i b u t i o n s   o f   c o d e :  ', ...
'  ', ...
' T h e   p e r s i s t e n c e   f u n c t i o n a l i t y   i s   p r o v i d e d   b y   a   l i b r a r y   w r i t t e n   b y   L u t z  ', ...
' K e t t n e r   a n d   A f r a   Z o m o r o d i a n   a s   p a r t   o f   t h e   C G A L   P r o j e c t   ( w w w . c g a l . o r g ) .  ', ...
'  ', ...
' T h e   g e o m e t r i c a l l y - s p a r s e   L U - d e c o m p o s i t i o n   c o d e   w a s   w r i t t e n   b y   E r i k  ', ...
' C a r l s s o n   a n d   P a t r i c k   P e r r y .  ', ...
'  ', ...
' D a v i d   M o u n t   a n d   S u n i l   A r y a '' s   A p p r o x i m a t e   N e a r e s t   N e i g h b o r   ( A N N )   L i b a r a r y  ', ...
' ( h t t p : / / w w w . c s . u m d . e d u / ~ m o u n t / A N N / )   i s   i n c l u d e d   f o r   n e a r e s t - n e i g h b o r  ', ...
' s e a r c h i n g .  ', ...
'  ', ...
' 4 .   F u r t h e r   a c k n o w l e d g e m e n t s  ', ...
' - - - - - - - - - - - - - - - - - - - - - - - - - - -  ', ...
' S t a n f o r d   U n i v e r s i t y   a n d   i t s   D e p a r t m e n t   o f   M a t h e m a t i c s   h a v e   g i v e n   e x c e l l e n t  ', ...
' s u p p o r t   t o   t h i s   p r o j e c t   s i n c e   i t s   i n c e p t i o n .  ', ...
'  ', ...
' T h e   f o l l o w i n g   g r a n t s   h a v e   h e l p e d   s u p p o r t   t h i s   p r o j e c t .  ', ...
'  ', ...
' ? ?  ', ...
' N a t i o n a l   S c i e n c e   F o u n d a t i o n   g r a n t   D M S - 0 1 0 1 3 6 4 .  ', ...
' ? ?  ', ...
' ? ?  ', ...
'  ', ...
' 5 .   C o n t a c t   i n f o r m a t i o n  ', ...
' - - - - - - - - - - - - - - - - - - - - - -  ', ...
' P l e x   i s   m a i n t a i n e d   b y :  ', ...
'  ', ...
'   P a t r i c k   P e r r y   < p a t p e r r y @ s t a t . s t a n f o r d . e d u >  ', ...
'   V i n   d e   S i l v a   < v i n d u @ m a c . c o m >  ', ...
'  ', ...
' W e   w e l c o m e   f e e d b a c k .  ', ...
'  ', ...
' T h e   c o m p u t a t i o n a l   t o p o l o g y / s t a t i s t i c s   p r o j e c t   h o m e p a g e   c u r r e n t l y   r e s i d e s  ', ...
' a t   t h e   f o l l o w i n g   U R L :  ', ...
'  ', ...
'   h t t p : / / m a t h . s t a n f o r d . e d u / c o m p t o p /  ', ...
'  ', ...
' - -  ', ...
' L a s t   m o d i f i e d   2 0 0 4 - O c t o b e r - 1 9  ', ...
'');
  
 case {'readme'}
t0 = strvcat(...
'');
  
 case {'news'}
t0 = strvcat(...
'');
  
 case {'changes', 'changelog'}
t0 = strvcat(...
'');
  
 otherwise
  error('Unrecognised option.');
  
end
  

%-------------------------------------------------------
if (nargout == 1)
  t = t0;
else
  disp(t0);
end
  
%-------------------------------------------------------
