function px_plexsave (filename, varargin)

% PLEXSAVE -- save Plex objects to a file
%
%   PLEXSAVE(filename) saves all plex objects in the caller workspace
%   to a file with the given filename.
%
%   PLEXSAVE(filename, C) saves only the plex object named C.
%
%   PLEXSAVE(filename, C1, C2, ..., CN) saves multiple plex
%   objects.
%
%   See also PLEXLOAD, PLEXWHO.
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

% $Id: px_plexsave.m,v 1.1.1.1 2005/03/18 23:36:47 silva Exp $
% $Log: px_plexsave.m,v $
% Revision 1.1.1.1  2005/03/18 23:36:47  silva
% Imported Sources
%
% Revision 1.2  2004/10/22 01:28:13  silva
%
% Improving help-text and adding tags.
%
% Revision 1.1.1.1  2004/09/25 22:04:09  patperry
% Imported sources
%
% Revision 1.2  2004/09/16 00:29:56  silva
% Tidying up the help text.
%
% Revision 1.1  2004/07/07 19:32:51  patperry
% Added functions for saving/loading plex objects to/from files.
%

if (nargin < 1) || ~ischar(filename)
  error('First argument must be a string.');
end

ObjectNames = {};
Objects = {};
numObjects = 0;

if length(varargin) > 0
  for i = 1:length(varargin)
    ObjectNames{i} = inputname(i + 1);
    Objects{i} = varargin{i};
    
    if ~strcmp(class(varargin{i}), 'plex')
	 error(['Argument ' int2str(i + 1) ' is not a plex object.']);
    end
    
  end
  
  numObjects = length(Objects);
else
  S = evalin('caller', 'whos');
  
  for i = 1:length(S)
    if strcmp(S(i).class, 'plex')
	 numObjects = numObjects + 1;
	 ObjectNames{numObjects} = S(i).name;
	 Objects{numObjects} = evalin('caller', S(i).name);
    end
  end
end
  
Variables = {};

for i = 1:numObjects
  name = ObjectNames{i};
  object = Objects{i};

  eval([name ' = dim(object);']);
  Variables = { Variables{:} name };
  
  for n = 0:dim(object)
    facesName = ['PLEX__' name '_' int2str(n)];
    eval([facesName ' = faces(object, n);']);
    Variables = { Variables{:} facesName };
  end
end

save(filename, Variables{:});

