function S = px_plexwho (filename, varargin)

% PLEXWHO -- list Plex objects stored in a file
%
%   PLEXWHO(filename) prints the names of the plex objects stored
%   in the given file.
%
%   PLEXWHO(filename, V1, ... VN) restricts the display to the
%   specified variables
%
%   S = PLEXWHO(filename) returns the names in a cell array.
%
%   See also PLEXLOAD, PLEXSAVE.
%
%Plex version 2.0 by Patrick Perry, Vin de Silva and contributors. See
%PX_PLEXINFO for credits and licensing information. [2005-May-18]

% $Id: px_plexwho.m,v 1.1.1.1 2005/03/18 23:36:47 silva Exp $
% $Log: px_plexwho.m,v $
% Revision 1.1.1.1  2005/03/18 23:36:47  silva
% Imported Sources
%
% Revision 1.2  2004/10/22 01:28:13  silva
%
% Improving help-text and adding tags.
%
% Revision 1.1.1.1  2004/09/25 22:04:09  patperry
% Imported sources
%
% Revision 1.2  2004/09/16 00:29:56  silva
% Tidying up the help text.
%
% Revision 1.1  2004/07/07 19:32:51  patperry
% Added functions for saving/loading plex objects to/from files.
%

if (nargin < 1) || ~ischar(filename)
  error('First argument must be a string.');
end

S = {};

if (length(varargin) == 0)
  Variables = who('-file', filename);
  
  for i = 1:length(Variables)
    if ~strncmp(Variables{i}, 'PLEX__', 6)
	 S = { S{:} Variables{i} };
    end
  end
else
  S = who('file', varargin{:});
end

if (nargout == 0)
  
  disp(sprintf('\nYour variables are:\n'));
  
  for i = 1:length(S)
    disp(sprintf('\t%s', S{i}));
  end
  
  disp(' ');
  
  clear S;
end
  
