/* MatlabAllocator.cc
 * ------------------
 * Implements MatlabAllocator.h
 *
 * $Id: MatlabAllocator.cc,v 1.1.1.1 2005/03/18 23:36:35 silva Exp $
 * $Log: MatlabAllocator.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:35  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.3  2004/02/09 06:34:35  patperry
 * Lots of bugfixes.
 *
 * Revision 1.2  2004/01/15 07:15:43  patperry
 * Imported support.{c,h}, changed file extensions
 *
 * Revision 1.1.1.1  2003/11/14 10:12:21  patperry
 * Initial version.
 *
 *
 */

#include <matrix.h>
#include <mex.h>


template <class T> 
typename MatlabAllocator<T>::pointer
MatlabAllocator<T>::
allocate (size_type n)
{
  if (n != 0) {
    void * result = mxMalloc(n * sizeof(T));
    mexMakeMemoryPersistent(result);

    mexPrintf("Allocated %d bytes at %d.\n", n * sizeof(T), result);

    return static_cast<pointer>(result);
  } else {
    return NULL;
  }
}


template <class T> 
typename MatlabAllocator<T>::pointer
MatlabAllocator<T>::
allocate (void)
{
  void * result = mxMalloc(sizeof(T));
  mexMakeMemoryPersistent(result);

  mexPrintf("Allocated %d bytes at %d.\n", sizeof(T), result);

  return static_cast<pointer>(result);
}


template <class T> 
void
MatlabAllocator<T>::
deallocate (pointer p, size_type n)
{
  if (n != 0) {
    mxFree(p);
  }

  mexPrintf("Deallocated %d bytes at %d.\n", n * sizeof(T), p);
}


template <class T> 
void
MatlabAllocator<T>::
deallocate (pointer p)
{
  mxFree(p);

  mexPrintf("Deallocated %d bytes at %d.\n", sizeof(T), p);
}
