/* MxUtility.cc
 * ------------
 * Implements MxUtility.h
 *
 * Written by Patrick Perry
 * Original Version on February 25, 2004
 *
 * $Id: MxUtility.cc,v 1.1.1.1 2005/03/18 23:36:37 silva Exp $
 * $Log: MxUtility.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:37  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.1  2004/02/26 06:49:24  patperry
 * Converted mexfiles to use new scomplex interface
 *
 */

#include "MxUtility.h"

bool
IsScalarMxArray (const mxArray * array)
{
  bool result = false;

  if ((mxGetM(array) == 1) 
	 && (mxGetN(array) == 1)) {
    result = true;
  }

  return result;
}


int 
GetIntFromMxArray (const mxArray * array)
{
  int result = 0;
  double doubleValue;
  float floatValue;
  char charValue;
  short shortValue;
  long longValue;
  unsigned char ucharValue;
  unsigned short ushortValue;
  unsigned int uintValue;
  unsigned long ulongValue;

  switch(mxGetClassID(array)) {
  case mxDOUBLE_CLASS:
    doubleValue = *static_cast<double *>(mxGetData(array));
    result = static_cast<int>(doubleValue);
    break;
  case mxSINGLE_CLASS:
    floatValue = *static_cast<float *>(mxGetData(array));
    result = static_cast<int>(floatValue);
    break;
  case mxINT8_CLASS:
    charValue = *static_cast<char *>(mxGetData(array));
    result = static_cast<int>(charValue);
    break;
  case mxINT16_CLASS:
    shortValue = *static_cast<short *>(mxGetData(array));
    result = static_cast<int>(shortValue);
    break;
  case mxINT32_CLASS:
    result = *static_cast<int *>(mxGetData(array));
    break;
  case mxINT64_CLASS:
    longValue = *static_cast<long *>(mxGetData(array));
    result = static_cast<int>(longValue);
    break;
  case mxUINT8_CLASS:
    ucharValue = *static_cast<unsigned char *>(mxGetData(array));
    result = static_cast<int>(ucharValue);
    break;
  case mxUINT16_CLASS:
    ushortValue = *static_cast<unsigned short *>(mxGetData(array));
    result = static_cast<int>(ushortValue);
    break;
  case mxUINT32_CLASS:
    uintValue = *static_cast<unsigned int *>(mxGetData(array));
    result = static_cast<int>(uintValue);
    break;
  case mxUINT64_CLASS:
    ulongValue = *static_cast<unsigned long *>(mxGetData(array));
    result = static_cast<int>(ulongValue);
    break;
  default:
    result = 0;
  }

  return result;
}
