/* PlexFiltration.cc
 * -----------------
 * Implements PlexFiltration.h
 *
 * Written by Patrick Perry
 * Original Version on May 20, 2004
 *
 * $Id: PlexFiltration.cc,v 1.2 2005/05/03 22:34:13 patperry Exp $
 * $Log: PlexFiltration.cc,v $
 * Revision 1.2  2005/05/03 22:34:13  patperry
 * Fixed intersect and union bugs
 *
 * Revision 1.1.1.1  2005/03/18 23:36:37  silva
 * Imported Sources
 *
 * Revision 1.2  2005/03/04 23:46:29  patperry
 * Added copersistence.
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.2  2004/05/23 20:19:01  patperry
 * Cleaned up Filter interface.
 *
 * Revision 1.1  2004/05/21 21:37:24  patperry
 * Cleaned up Filtration/Persistence interface
 *
 */

#include "PlexFiltration.h"

bool 
IsValidFiltration (const SimplicialComplex_t& scomplex,
			    const mxArray * data)
{
  bool result = false;

  if (mxIsCell(data)) {
    int maxDimension = mxGetNumberOfElements(data) - 1;

    if ((maxDimension == -1) && (scomplex.getNumSimplices(0) == 0)) {
	 result = true;
    } else {
	 for (int i = 0; i <= maxDimension; ++i) {
	   mxArray * simplexFiltration = mxGetCell(data, i);
	   
	   if (!mxIsDouble(simplexFiltration) 
		  || mxIsComplex(simplexFiltration)
		  ||(mxGetNumberOfElements(simplexFiltration) 
			!= scomplex.getNumSimplices(i))) {
		break;
	   } else if (i == maxDimension) {
		result = true;
	   }
	 }
    }
  }

  return result;
}


Filtration_t * 
ImportFiltration (const SimplicialComplex_t& scomplex,
			   const mxArray * data, int maxDimension)
{
  Filtration_t * result = NULL;

  maxDimension = std::min(maxDimension, scomplex.getDimension());

  int numFiltrationValues = 0;
  for (int i = 0; i <= maxDimension; ++i) {
    numFiltrationValues += scomplex.getNumSimplices(i);
  }

  double filtrationValues[numFiltrationValues];
  double * offset = filtrationValues;

  for (int i = 0; i <= maxDimension; ++i) {
    mxArray * simplexFiltration = mxGetCell(data, i);
    double * values = mxGetPr(simplexFiltration);

    offset = std::copy(values, values + scomplex.getNumSimplices(i),
				   offset);
  }

  result = new Filtration_t(scomplex.simplicesBegin(0), 
					   scomplex.simplicesEnd(maxDimension),
					   filtrationValues, filtrationValues 
					   + numFiltrationValues);

  return result;
}


