/* VertexSet.cc
 * ------------
 * Implements VertexSet.h
 *
 * Written by Patrick Perry
 * Original Version on March 8, 2004
 *
 * $Id: VertexSet.cc,v 1.1.1.1 2005/03/18 23:36:39 silva Exp $
 * $Log: VertexSet.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:36:39  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:09  patperry
 * Imported sources
 *
 * Revision 1.2  2004/03/09 09:12:46  patperry
 * Implemented nbhood
 *
 * Revision 1.1  2004/03/09 07:58:55  patperry
 * Initial version of VertexSet code.
 *
 */


bool IsValidVertexSet (const mxArray * array)
{
  bool result = false;
  
  if (mxIsLogical(array)
	 || (mxIsDouble(array) && !mxIsComplex(array))
	 || (mxIsInt32(array))) {
    result = true;
  }

  return result;
}


template <class OutputIterator>
OutputIterator
GetVertexSetFromMxArray (const mxArray * array, 
					const SimplicialComplex_t * scomplex,
					OutputIterator result)
{
  if (mxIsLogical(array)) {
    if (mxGetNumberOfElements(array)== scomplex->getNumSimplices(0)) {
	 result = GetVertexSetFromLogicalIndexArray(array, scomplex, result);
    } else {
	 result = GetVertexSetFromLogicalLabelArray(array, result);
    }
  } else {
    result = GetVertexSetFromList(array, result);
  }

  return result;
}


template <class OutputIterator>
OutputIterator
GetVertexSetFromList (const mxArray * array, OutputIterator result)
{
  if (mxIsDouble(array) && !mxIsComplex(array)) {
    double * pr = mxGetPr(array);
    
    for (int i = 0; i < mxGetNumberOfElements(array); ++i) {
	 *result++ = static_cast<int>(*pr++);
    }
  } else if (mxIsInt32(array)) {
    int * pr = reinterpret_cast<int *>(mxGetData(array));
    
    for (int i = 0; i < mxGetNumberOfElements(array); ++i) {
	 *result++ = *pr++;
    }
  }

  return result;
}
				  

template <class OutputIterator>
OutputIterator
GetVertexSetFromLogicalIndexArray (const mxArray * array, 
							const SimplicialComplex_t * scomplex,
							OutputIterator result)
{
  mxLogical * pr = reinterpret_cast<mxLogical *>(mxGetData(array));
  SimplicialComplex_t::ConstSimplexIterator it = scomplex->simplicesBegin(0);

  for (int i = 0; i < mxGetNumberOfElements(array); ++i, ++it) {
    if (*pr++) {
	 *result++ = *((*it)->getLabel());
    }
  }
  
  return result;
}



template <class OutputIterator>
OutputIterator
GetVertexSetFromLogicalLabelArray (const mxArray * array, 
							OutputIterator result)
{
  mxLogical * pr = reinterpret_cast<mxLogical *>(mxGetData(array));

  for (int i = 0; i < mxGetNumberOfElements(array); ++i) {
    if (*pr++) {
	 *result++ = i;
    }
  }

  return result;
}
