// pivot.h
// October 31, 2003
// Lutz Kettner and Afra Zomorodian

#ifndef _PIVOT_H_
#define _PIVOT_H_

#include <iterator>
#include "chain.h"

// Class:  Pivot
// *************
// Note for IsPositive to make any sense, the pivots must
// be declared in an array
template <class SimplexHandle, class OutputPolicy, class CoefficientPolicy>
class Pivot {
public:
  // members
  typedef SimplexHandle Simplex_handle;
  typedef OutputPolicy  Output_policy;
  typedef typename std::vector< Pivot< Simplex_handle, OutputPolicy, 
	  CoefficientPolicy> >::iterator               Pivot_handle;
  typedef std::less< Pivot_handle>                     CompareWrtoFiltration;
  // define chain, boundary (and extended versions)
  typedef typename CoefficientPolicy::template 
    Bind< Pivot_handle, CompareWrtoFiltration>::Chain     Chain;
  typedef typename CoefficientPolicy::template 
    Bind< Pivot_handle, CompareWrtoFiltration>::Ext_Chain Ext_Chain;
  typedef typename Output_policy::template 
    Bind< Chain>::Boundary                                Boundary;
  typedef typename Output_policy::template 
    Bind< Ext_Chain>::Boundary                            Ext_Boundary;

protected:
  static Pivot_handle base_;          // needed for printing purposes
  Pivot_handle   paired_with_;
  Boundary       boundary_;
  Simplex_handle simplex_;            // need to store to return answer  
public:
  const Pivot_handle&   paired_with() const { return paired_with_; }
  Pivot_handle&         paired_with()       { return paired_with_; }
  const Boundary&       boundary()    const { return boundary_;    }
  Boundary&             boundary()          { return boundary_;    }
  const Simplex_handle& simplex()     const { return simplex_;     }
  Simplex_handle&       simplex()           { return simplex_;     }

  bool is_positive()                  const { return this < &(*paired_with_);}
  void set_base(Pivot_handle base)          { base_ = base;        }
  void print()                        const { 
    std::cout << this - &(*base_);
  }
};

// Definition of static variable
template< class SimplexHandle, class OutputPolicy, class CoefficientPolicy>
typename Pivot< SimplexHandle, OutputPolicy, CoefficientPolicy>::Pivot_handle
         Pivot< SimplexHandle, OutputPolicy, CoefficientPolicy>::base_;

#endif 
// _PIVOT_H_
