/* BoundaryMap.cc
 * --------------
 * Implements BoundaryMap.h
 *
 * Written by Patrick Perry
 * Original Version on October 15, 2003
 *
 * $Id: BoundaryMap.cc,v 1.2 2005/10/24 16:19:56 patperry Exp $
 * $Log: BoundaryMap.cc,v $
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:11  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.7  2004/03/15 09:32:00  patperry
 * handle relative boundary maps correctly
 *
 * Revision 1.6  2004/03/14 07:57:58  patperry
 * handle relative complexes in bmap
 *
 * Revision 1.5  2004/02/09 06:34:04  patperry
 * Playing around with hashtable.
 *
 * Revision 1.4  2004/01/15 07:10:33  patperry
 * Changed file extensions.
 *
 * Revision 1.3  2003/12/04 14:26:24  patperry
 * fixed compile bugs
 *
 * Revision 1.2  2003/11/13 04:34:47  patperry
 * Boundary map.
 *
 * Revision 1.1  2003/10/16 08:43:00  patperry
 * Starting code for BoundaryMap.
 *
 *
 */

#include <iterator>


template <class Field, class Simplex, class Alloc>
template <class ForwardIterator1, class ForwardIterator2>
BoundaryMap<Field, Simplex, Alloc>::
BoundaryMap (ForwardIterator1 domainBegin, ForwardIterator1 domainEnd,
		   ForwardIterator2 codomainBegin, ForwardIterator2 codomainEnd)
  : CSCSparseMatrix<Field, Alloc>(getNumNondegenerateSimplices(domainBegin, 
												   domainEnd)
						    * (*domainBegin)->getDimension(),
						    getNumNondegenerateSimplices(codomainBegin, 
												   codomainEnd),
						    getNumNondegenerateSimplices(domainBegin, 
												   domainEnd))
{
  Field column[this->getNumRows()];
  Field boundaryCoefficient;
  int faceIndex;
  int domainIndex = 0;

  // add the nondegenerate simplices in the codomain
  for (ForwardIterator2 simplex = codomainBegin; 
	  simplex != codomainEnd; ++simplex) {
    if (!(*simplex)->isDegenerate()) {
	 codomain.push_back(*simplex);
    }
  }

  // for each simplex in the domain
  for (ForwardIterator1 simplex = domainBegin; 
	  simplex != domainEnd; ++simplex) {
   
    // if the simplex is nondegenerate
    if (!(*simplex)->isDegenerate()) {
	 // add the simplex to the simplex->int domain mapping
	 domain[*simplex] = domainIndex;
    
	 // initialize the bounday of the simplex to zero
	 std::uninitialized_fill(column, column + this->getNumRows(), 0);
	 
	 // initialize the first boundary coefficient to 1
	 boundaryCoefficient = 1;
	 
	 // for each face of the simplex
	 for (typename Simplex::ConstFaceIterator face = (*simplex)->facesBegin();
		 face != (*simplex)->facesEnd(); ++face) {
	   
	   // if the face is nondegenerate, set the appropriate coefficent
	   if (!(*face)->isDegenerate()) {
		// find the index in the codomain of the face
		faceIndex = (std::find(codomain.begin(), codomain.end(), *face) 
				   - codomain.begin());
		
		// if the face is in the codomain
		if (faceIndex < this->getNumRows()) {
		  // set the appropriate element in the column
		  column[faceIndex] = boundaryCoefficient;
		}
		
		// alternate the boundary coefficient;
		boundaryCoefficient = -boundaryCoefficient;
	   }
	 }

	 // copy the column data over
	 fillColumn(domainIndex, column);

	 // advance to the next simplex in the domain
	 ++domainIndex;
    }
  }
}


template <class Field, class Simplex, class Alloc>
BoundaryMap<Field, Simplex, Alloc>::
~BoundaryMap ()
{
}


template <class Field, class Simplex, class Alloc>
template <class InputIterator>
int 
BoundaryMap<Field, Simplex, Alloc>::
getNumNondegenerateSimplices (InputIterator begin, InputIterator end)
{
  int result = 0;

  while (begin != end) {
    if (!(*begin++)->isDegenerate()) {
	 ++result;
    }
  }

  return result;
}
					    
