/* BoundaryMap.h
 * -------------
 * Written by Patrick Perry
 * Original Version on 10/13/2003
 *
 * $Id: BoundaryMap.h,v 1.2 2005/10/24 16:19:56 patperry Exp $
 * $Log: BoundaryMap.h,v $
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:11  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.3  2004/03/15 09:32:00  patperry
 * handle relative boundary maps correctly
 *
 * Revision 1.2  2004/02/09 06:34:04  patperry
 * Playing around with hashtable.
 *
 * Revision 1.1  2004/01/15 07:09:28  patperry
 * Changed file extension.
 *
 * Revision 1.3  2003/12/04 14:26:24  patperry
 * fixed compile bugs
 *
 * Revision 1.2  2003/11/13 04:34:47  patperry
 * Boundary map.
 *
 * Revision 1.1  2003/10/16 08:43:00  patperry
 * Starting code for BoundaryMap.
 *
 *
 */

#ifndef _BOUNDARYMAP_H
#define _BOUNDARYMAP_H

// Lots of trouble just to get a hashtable.  Code taken from
// http://gcc.gnu.org/onlinedocs/libstdc++/faq/index.html#5_4
#ifdef __GNUC__
#if __GNUC__ < 3
  #include <hash_map.h>
  namespace Sgi { using ::hash_map }; 
#else
  #include <ext/hash_map>
  #if ((__GNUC__ == 3) && (__GNUC_MINOR__ == 0))
    namespace Sgi = std;
  #else 
    namespace Sgi = ::__gnu_cxx;
  #endif
#endif
#else
  #include <hash_map>
  namespace Sgi = std;
#endif 


#include <cstdlib>
#include <vector>
#include <functional>
#include <memory>
#include "Simplex.h"
#include "CSCSparseMatrix.h"


/**
 * Class for defining the boundary map of a simplicial complex.
 */
template <class Field, class Simplex, class Alloc = std::allocator<Field> >
class BoundaryMap : public CSCSparseMatrix<Field, Alloc>
{
private:

  /**
   * type for hashing a simplex.
   */
  struct HashSimplex
  {
    std::size_t operator () (const Simplex * x) const
    {
	 return reinterpret_cast<std::size_t>(x);
    }
  };
  
  //! a hashtable mapping simplices in the domain to indices
  Sgi::hash_map<const Simplex *, int, HashSimplex,
			 std::equal_to<const Simplex *>, Alloc> domain;
			 
  //! an array mapping the index i to a simplex in the codomain.
  std::vector<const Simplex *, 
		    typename Alloc::template rebind<const Simplex *>::other> codomain;

 public:

  /**
   * Constructs the bounday map going from the given domain to the
   * codomain.  If the bounday of a simplex in the domain has a component
   * not included in the codomain, that simplex is treated as zero.
   *
   * \param domainBegin an iterator to the first simplex in the domain.
   * \param domainEnd an iterator to the end of the domain collection.
   * \param codomainBegin an iterator to the begin of the codomain
   *        simplex collection.
   * \param codomainEnd an iterator to the end of the codomain simplex
   *        collection.
   */
  template <class ForwardIterator1, class ForwardIterator2>
  BoundaryMap (ForwardIterator1 domainBegin, ForwardIterator1 domainEnd,
			ForwardIterator2 codomainBegin, ForwardIterator2 codomainEnd);

  /**
   * Destructor.
   */
  virtual ~BoundaryMap ();

 private:

  /**
   * Find the number of nondegenerate simplices in a simplex iterator range.
   *
   * \param begin a simplex iterator to the begin of the range.
   * \param end a simplex iterator to the end of the range.
   * \returns the number of nondegenerate simplices in [begin, end).
   */
  template <class InputIterator>
  static int getNumNondegenerateSimplices (InputIterator begin, 
								   InputIterator end);
							   
};


// get compiler to see definitions
#include "BoundaryMap.cc"


#endif // _BOUNDARYMAP_H
