/* ComplexMap.h
 * ------------
 * Written by Patrick Perry
 * Original Version on May 26, 2004
 *
 * $Id: ComplexMap.h,v 1.2 2005/10/24 16:19:56 patperry Exp $
 * $Log: ComplexMap.h,v $
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:12  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.1  2004/05/28 05:47:55  patperry
 * InitialVersions of ComplexMap and UnionFilter
 *
 */

#ifndef _COMPLEXMAP_H
#define _COMPLEXMAP_H

#include <functional>
#include <memory>
#include "SimplicialComplex.h"


template <class Alloc = std::allocator<int> >
class ComplexMap 
  : public std::unary_function
  <const typename SimplicialComplex<Alloc>::Simplex *,
   const typename SimplicialComplex<Alloc>::Simplex * >
{
 public:

  //! The simplicial complex type
  typedef SimplicialComplex<Alloc> SimplicialComplex_t;

  //! The simplex type
  typedef typename SimplicialComplex_t::Simplex Simplex_t;

  //! The simplex handle type
  typedef const Simplex_t * SimplexHandle_t;

 private:
  
  //! The simplicial complex to map to
  const SimplicialComplex_t * scomplex;

 public:

  /**
   * Constructor.
   *
   * \param scomplex the complex to create the map to.
   */
  ComplexMap (const SimplicialComplex_t& scomplex);

  /**
   * Destructor.
   */
  virtual ~ComplexMap ();

  /**
   * Function call operator.  Takes a simplex handle to a simplex from
   * any simplicial complex.  If there exists a simplex with the same
   * label in the complex, returns a pointer to that simplex.
   *
   * \param simplex a simplex from another complex.
   * \returns the corresponding simplex in the complex.
   */
  SimplexHandle_t operator() (SimplexHandle_t simplex) const;
};


// get compiler to see function definitions
#include "ComplexMap.cc"
  

#endif // _COMPLEXMAP_H
