/* FilteredBoundaryOperator.h
 * --------------------------
 * Written by Patrick Perry
 * Original Version on February 27, 2004
 *
 * $Id: FilteredBoundaryOperator.h,v 1.2 2005/10/24 16:19:56 patperry Exp $
 * $Log: FilteredBoundaryOperator.h,v $
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:12  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.5  2004/05/05 22:29:15  patperry
 * Fixed bugs in filtration/persistence.
 *
 * Revision 1.4  2004/03/14 07:30:34  patperry
 * Handle relative complexes in persistence
 *
 * Revision 1.3  2004/03/01 07:59:12  patperry
 * Persistence output
 *
 * Revision 1.2  2004/03/01 06:55:49  patperry
 * Persistence fixes
 *
 * Revision 1.1  2004/02/27 10:49:06  patperry
 * More playing around with boundary operators
 *
 */

#ifndef _FILTEREDBOUNDARYOPERATOR_H
#define _FILTEREDBOUNDARYOPERATOR_H

#include "Filtration.h"
#include "SimplexBoundaryOperator.h"

#include <iterator>
#include <memory>
#include <algorithm>
#include <cstdlib>
#include <iostream>
#include <map>


/**
 * Class for representing the boundary operator(s) of a filtered simplicial
 * complex.
 */
template <class SimplexHandle_t, class FiltrationValue_t, class Coeff_t, 
		class Alloc = std::allocator<int> >
class FilteredBoundaryOperator 
{
 public:

  //! the simplex handle type
  typedef SimplexHandle_t Simplex_handle;

  //! the coefficient type
  typedef Coeff_t Coeff;

  //! the type for storing chain components
  typedef std::pair<Simplex_handle, Coeff> value_type;

  //! the tag indicating that we use handles
  typedef Boundary_handle_tag rep_tag;

  
  typedef Filtration<SimplexHandle_t, FiltrationValue_t, Alloc> Filtration_t;

 private:

  //! the filtration
  const Filtration_t& filtration;

 public:
  
  FilteredBoundaryOperator (const Filtration_t& filtration)
    : filtration(filtration)
  {
  }

  template <class OutputIterator>
  OutputIterator operator() (Simplex_handle simplex, OutputIterator out)
  {
    //std::cout << "Boundary of " << *simplex << " is { ";
    if (!simplex->isDegenerate()) {
	 std::map<FiltrationValue_t, value_type,
	   std::less<FiltrationValue_t> > boundarySorter;
	 
	 int dimension = simplex->getDimension();
	 Coeff sign(-1);
	 
	 if (dimension > 0) {
	   for (int i = 0; i <= dimension; ++i) {
		Simplex_handle face = simplex->getFace(i);
		Coeff coeff = sign;
		
		if (face->isDegenerate()) {
		  coeff = 0;
		}
		
		value_type component(face, coeff);
		
		boundarySorter.insert(std::pair<FiltrationValue_t, value_type>
						  (filtration.getFiltrationPosition(face),
						   component));
		sign = -sign;
	   }
	   
	   for (typename std::map<FiltrationValue_t, 
			value_type>::iterator it =
			boundarySorter.begin(); it != boundarySorter.end(); ++it) {
		//std::cout << (it->second).second << " * " << *((it->second).first)
		//		   << " ";
		*out++ = it->second;
	   }
	 }
    } 

    //std::cout << "}\n";

    return out;
  }


};

#endif // _FILTEREDBOUNDARYOPERATOR_H
