/* FilteredCoboundaryOperator.h
 * ----------------------------
 * Written by Patrick Perry
 * Original Version on March 4, 2005 
 *   (modified from FilteredBoundaryOperator.h)
 *
 * $Id: FilteredCoboundaryOperator.h,v 1.2 2005/10/24 16:19:56 patperry Exp $
 * $Log: FilteredCoboundaryOperator.h,v $
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:13  silva
 * Imported Sources
 *
 * Revision 1.1  2005/03/04 23:46:29  patperry
 * Added copersistence.
 *
 *
 */

#ifndef _FILTEREDCOBOUNDARYOPERATOR_H
#define _FILTEREDCOBOUNDARYOPERATOR_H

#include "Filtration.h"
#include "SimplexBoundaryOperator.h"

#include <iterator>
#include <memory>
#include <algorithm>
#include <cstdlib>
#include <iostream>
#include <map>


/**
 * Class for representing the boundary operator(s) of a filtered simplicial
 * complex.
 */
template <class SimplexHandle_t, class FiltrationValue_t, class Coeff_t, 
		class Alloc = std::allocator<int> >
class FilteredCoboundaryOperator 
{
 public:

  //! the simplex handle type
  typedef SimplexHandle_t Simplex_handle;

  //! the simplex type
  typedef typename std::iterator_traits<SimplexHandle_t>::value_type Simplex_t;

  //! the coface iterator type
  typedef typename Simplex_t::ConstCofaceIterator CofaceIterator_t;

  //! the coefficient type
  typedef Coeff_t Coeff;

  //! the type for storing chain components
  typedef std::pair<Simplex_handle, Coeff> value_type;

  //! the tag indicating that we use handles
  typedef Boundary_handle_tag rep_tag;

  
  typedef Filtration<SimplexHandle_t, FiltrationValue_t, Alloc> Filtration_t;

 private:

  //! the filtration
  const Filtration_t& filtration;

 public:
  
  FilteredCoboundaryOperator (const Filtration_t& filtration)
    : filtration(filtration)
  {
  }
  
  template <class OutputIterator>
  OutputIterator operator() (Simplex_handle simplex, OutputIterator out)
  {
    //std::cout << "Boundary of " << *simplex << " is { ";
    if (!simplex->isDegenerate()) {
	 std::map<FiltrationValue_t, value_type,
	   std::greater<FiltrationValue_t> > coboundarySorter;
	 
	 int dimension = simplex->getDimension();
	 CofaceIterator_t it = simplex->cofacesBegin();
	 CofaceIterator_t end = simplex->cofacesEnd();

	 while (it != end) {
	   Simplex_handle coface = *it++;
	   Coeff coeff;
	   
	   if (coface->isDegenerate()) {
		coeff = 0;
	   } else {
		Coeff sign;

		if (dimension % 2 == 0) {
		  sign = Coeff(1);
		} else {
		  sign = Coeff(-1);
		}
		
		for (int i = 0; i <= dimension; ++i) {
		  Simplex_handle face = coface->getFace(i);
		  
		  if (*face == *simplex) {
		    coeff = sign;
		    break;
		  }
		  
		  sign = -sign;
		}
	   }
		
	   value_type component(coface, coeff);
		
	   coboundarySorter.insert(std::pair<FiltrationValue_t, value_type>
						  (filtration.getFiltrationPosition(coface),
						   component));
	 }
	 
	 for (typename std::map<FiltrationValue_t, 
		   value_type>::iterator it =
		   coboundarySorter.begin(); it != coboundarySorter.end(); ++it) {
	   //std::cout << (it->second).second << " * " << *((it->second).first)
	   //		   << " ";
	   *out++ = it->second;
	 }
    }

  //std::cout << "}\n";
  
  return out;
  }

};

#endif // _FILTEREDCOBOUNDARYOPERATOR_H
