/* PackedArrayIterator.cc
 * ----------------------
 * Implements PackedArrayIterator.h
 *
 * Written by Patrick Perry
 * Original Version on July 5, 2004
 *
 * $Id: PackedArrayIterator.cc,v 1.1.1.1 2005/03/18 23:37:16 silva Exp $
 * $Log: PackedArrayIterator.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:37:16  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.1  2004/07/07 23:03:06  patperry
 * Added packed array iterator.
 *
 */


template <class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc>::
PackedArrayIterator (int dimension, Element_t * position)
  : dimension(dimension), position(position)
{
}


template <class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc>::
PackedArrayIterator ()
{
}


template <class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc>::
~PackedArrayIterator ()
{
}


template <class Element_t, class Alloc>
Element_t * 
PackedArrayIterator<Element_t, Alloc>::
operator* ()
{
  return position;
}

template <class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc>&
PackedArrayIterator<Element_t, Alloc>::
operator++ ()
{
  position += dimension;
  return *this;
}


template <class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc>
PackedArrayIterator<Element_t, Alloc>::
operator++ (int post)
{
  PackedArrayIterator result = *this;
  ++(*this);
  return result;
}


template <class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc>&
PackedArrayIterator<Element_t, Alloc>::
operator-- ()
{
  position -= dimension;
  return *this;
}


template <class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc>
PackedArrayIterator<Element_t, Alloc>::
operator-- (int post)
{
  PackedArrayIterator result = *this;
  --(*this);
  return result;
}


template <class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc>&
PackedArrayIterator<Element_t, Alloc>::
operator+= (int n)
{
  position += n * dimension;
}


template <class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc>&
PackedArrayIterator<Element_t, Alloc>::
operator-= (int n)
{
  position -= n * dimension;
}


template <class Element_t, class Alloc>
int
PackedArrayIterator<Element_t, Alloc>::
operator- (const PackedArrayIterator& x) const
{
  return (position - x.position) / dimension;
}


template <class Element_t, class Alloc>
Element_t *
PackedArrayIterator<Element_t, Alloc>::
operator[] (int n) const
{
  return position + n * dimension;
}


template <class Element_t, class Alloc>
bool
PackedArrayIterator<Element_t, Alloc>::
operator== (const PackedArrayIterator& x) const
{
  return (position == x.position);
}


template <class Element_t, class Alloc>
bool
PackedArrayIterator<Element_t, Alloc>::
operator!= (const PackedArrayIterator& x) const
{
  return (position != x.position);
}


template <class Element_t, class Alloc>
bool
PackedArrayIterator<Element_t, Alloc>::
operator< (const PackedArrayIterator& x) const
{
  return (position < x.position);
}


template<class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc> 
operator+ (int n, const PackedArrayIterator<Element_t, Alloc>& i)
{
  PackedArrayIterator<Element_t, Alloc> result = i;
  result += n;
  return result;
}


template<class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc> 
operator+ (const PackedArrayIterator<Element_t, Alloc>& i, int n)
{
  PackedArrayIterator<Element_t, Alloc> result = i;
  result += n;
  return result;
}


template<class Element_t, class Alloc>
PackedArrayIterator<Element_t, Alloc> 
operator- (const PackedArrayIterator<Element_t, Alloc>& i, int n)
{
  PackedArrayIterator<Element_t, Alloc> result = i;
  result -= n;
  return result;
}

