/* PackedMatrixColumnIterator.cc
 * ----------------------
 * Implements PackedMatrixColumnIterator.h
 *
 * Written by Patrick Perry
 * Original Version on July 28, 2004
 *
 * $Id: PackedMatrixColumnIterator.cc,v 1.2 2005/10/24 16:19:56 patperry Exp $
 * $Log: PackedMatrixColumnIterator.cc,v $
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:17  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.1  2004/09/16 09:00:24  patperry
 * Added C++ Witness
 *
 *
 */


template <class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>::
PackedMatrixColumnIterator (size_type numRows, size_type numColumns,
					   size_type row, size_type column,
					   Element_t * position)
  : numRows(numRows), numColumns(numColumns), row(row), column(column),
    position(position)
{
}


template <class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>::
PackedMatrixColumnIterator ()
{
}


template <class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>::
~PackedMatrixColumnIterator ()
{
}


template <class Element_t, class Alloc>
Element_t
PackedMatrixColumnIterator<Element_t, Alloc>::
operator* ()
{
  return *position;
}

template <class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>&
PackedMatrixColumnIterator<Element_t, Alloc>::
operator++ ()
{
  position += numRows;
  column = (column + 1) % numColumns;
  return *this;
}


template <class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>::
operator++ (int post)
{
  PackedMatrixColumnIterator result = *this;
  ++(*this);
  return result;
}


template <class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>&
PackedMatrixColumnIterator<Element_t, Alloc>::
operator-- ()
{
  position -= numRows;
  column = (column - 1) % numColumns;
  return *this;
}


template <class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>::
operator-- (int post)
{
  PackedMatrixColumnIterator result = *this;
  --(*this);
  return result;
}


template <class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>&
PackedMatrixColumnIterator<Element_t, Alloc>::
operator+= (int n)
{
  position += n * numRows;
  column = (column + n) % numColumns;
}


template <class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc>&
PackedMatrixColumnIterator<Element_t, Alloc>::
operator-= (int n)
{
  position -= n * numRows;
  column = (column - n) % numColumns;
}


template <class Element_t, class Alloc>
int
PackedMatrixColumnIterator<Element_t, Alloc>::
operator- (const PackedMatrixColumnIterator& x) const
{
  return (position - x.position) / numRows;
}


template <class Element_t, class Alloc>
Element_t
PackedMatrixColumnIterator<Element_t, Alloc>::
operator[] (int n) const
{
  return position[n * numRows];
}


template <class Element_t, class Alloc>
bool
PackedMatrixColumnIterator<Element_t, Alloc>::
operator== (const PackedMatrixColumnIterator& x) const
{
  return (position == x.position);
}


template <class Element_t, class Alloc>
bool
PackedMatrixColumnIterator<Element_t, Alloc>::
operator!= (const PackedMatrixColumnIterator& x) const
{
  return (position != x.position);
}


template <class Element_t, class Alloc>
bool
PackedMatrixColumnIterator<Element_t, Alloc>::
operator< (const PackedMatrixColumnIterator& x) const
{
  return (position < x.position);
}


template<class Element_t, class Alloc>
typename PackedMatrixColumnIterator<Element_t, Alloc>::size_type 
PackedMatrixColumnIterator<Element_t, Alloc>::
index1 () const
{
  return row;
}


template<class Element_t, class Alloc>
typename PackedMatrixColumnIterator<Element_t, Alloc>::size_type 
PackedMatrixColumnIterator<Element_t, Alloc>::
index2 () const
{
  return column;
}


template<class Element_t, class Alloc>
typename PackedMatrixColumnIterator<Element_t, Alloc>::dual_iterator_type 
PackedMatrixColumnIterator<Element_t, Alloc>::
begin () const
{
  return dual_iterator_type(numRows, numColumns, 0, column, position - row);
}

template<class Element_t, class Alloc>
typename PackedMatrixColumnIterator<Element_t, Alloc>::dual_iterator_type 
PackedMatrixColumnIterator<Element_t, Alloc>::
end () const
{
  return dual_iterator_type(numRows, numColumns, 0, column, 
					   position + numRows - row);
					   
}


template<class Element_t, class Alloc>
typename PackedMatrixColumnIterator<Element_t, Alloc>::
dual_reverse_iterator_type 
PackedMatrixColumnIterator<Element_t, Alloc>::
rbegin () const
{
  return dual_reverse_iterator_type(end());
}


template<class Element_t, class Alloc>
typename PackedMatrixColumnIterator<Element_t, Alloc>::
dual_reverse_iterator_type 
PackedMatrixColumnIterator<Element_t, Alloc>::
rend () const
{
  return dual_reverse_iterator_type(begin());
}


template<class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc> 
operator+ (int n, const PackedMatrixColumnIterator<Element_t, Alloc>& i)
{
  PackedMatrixColumnIterator<Element_t, Alloc> result = i;
  result += n;
  return result;
}


template<class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc> 
operator+ (const PackedMatrixColumnIterator<Element_t, Alloc>& i, int n)
{
  PackedMatrixColumnIterator<Element_t, Alloc> result = i;
  result += n;
  return result;
}


template<class Element_t, class Alloc>
PackedMatrixColumnIterator<Element_t, Alloc> 
operator- (const PackedMatrixColumnIterator<Element_t, Alloc>& i, int n)
{
  PackedMatrixColumnIterator<Element_t, Alloc> result = i;
  result -= n;
  return result;
}

