/* PackedMatrixRowIterator.cc
 * --------------------------
 * Implements PackedMatrixRowIterator.h
 *
 * Written by Patrick Perry
 * Original Version on July 28, 2004
 *
 * $Id: PackedMatrixRowIterator.cc,v 1.1.1.1 2005/03/18 23:37:18 silva Exp $
 * $Log: PackedMatrixRowIterator.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:37:18  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.1  2004/09/16 09:00:24  patperry
 * Added C++ Witness
 *
 *
 */


template <class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc>::
PackedMatrixRowIterator (size_type numRows, size_type numColumns,
					size_type row, size_type column,
					Element_t * position)
  : numRows(numRows), numColumns(numColumns), row(row), column(column),
    position(position)
{
}


template <class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc>::
PackedMatrixRowIterator ()
{
}


template <class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc>::
~PackedMatrixRowIterator ()
{
}


template <class Element_t, class Alloc>
Element_t
PackedMatrixRowIterator<Element_t, Alloc>::
operator* ()
{
  return *position;
}

template <class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc>&
PackedMatrixRowIterator<Element_t, Alloc>::
operator++ ()
{
  position += 1;
  row = (row + 1) % numRows;
  return *this;
}


template <class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc>
PackedMatrixRowIterator<Element_t, Alloc>::
operator++ (int post)
{
  PackedMatrixRowIterator result = *this;
  ++(*this);
  return result;
}


template <class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc>&
PackedMatrixRowIterator<Element_t, Alloc>::
operator-- ()
{
  position -= 1;
  row = (row - 1) % numRows;
  return *this;
}


template <class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc>
PackedMatrixRowIterator<Element_t, Alloc>::
operator-- (int post)
{
  PackedMatrixRowIterator result = *this;
  --(*this);
  return result;
}


template <class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc>&
PackedMatrixRowIterator<Element_t, Alloc>::
operator+= (int n)
{
  position += n;
  row = (row + n) % numRows;
}


template <class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc>&
PackedMatrixRowIterator<Element_t, Alloc>::
operator-= (int n)
{
  position -= n;
  row = (row - n) % numRows;
}


template <class Element_t, class Alloc>
int
PackedMatrixRowIterator<Element_t, Alloc>::
operator- (const PackedMatrixRowIterator& x) const
{
  return (position - x.position);
}


template <class Element_t, class Alloc>
Element_t 
PackedMatrixRowIterator<Element_t, Alloc>::
operator[] (int n) const
{
  return position[n];
}


template <class Element_t, class Alloc>
bool
PackedMatrixRowIterator<Element_t, Alloc>::
operator== (const PackedMatrixRowIterator& x) const
{
  return (position == x.position);
}


template <class Element_t, class Alloc>
bool
PackedMatrixRowIterator<Element_t, Alloc>::
operator!= (const PackedMatrixRowIterator& x) const
{
  return (position != x.position);
}


template <class Element_t, class Alloc>
bool
PackedMatrixRowIterator<Element_t, Alloc>::
operator< (const PackedMatrixRowIterator& x) const
{
  return (position < x.position);
}


template<class Element_t, class Alloc>
typename PackedMatrixRowIterator<Element_t, Alloc>::size_type 
PackedMatrixRowIterator<Element_t, Alloc>::
index1 () const
{
  return row;
}


template<class Element_t, class Alloc>
typename PackedMatrixRowIterator<Element_t, Alloc>::size_type 
PackedMatrixRowIterator<Element_t, Alloc>::
index2 () const
{
  return column;
}


template<class Element_t, class Alloc>
typename PackedMatrixRowIterator<Element_t, Alloc>::dual_iterator_type 
PackedMatrixRowIterator<Element_t, Alloc>::
begin () const
{
  return dual_iterator_type(numRows, numColumns, row, 0, 
					   position - column * numRows);
}

template<class Element_t, class Alloc>
typename PackedMatrixRowIterator<Element_t, Alloc>::dual_iterator_type 
PackedMatrixRowIterator<Element_t, Alloc>::
end () const
{
  return dual_iterator_type(numRows, numColumns, row, 0, 
					   position + (numColumns - column) * numRows);
}


template<class Element_t, class Alloc>
typename PackedMatrixRowIterator<Element_t, Alloc>::
dual_reverse_iterator_type 
PackedMatrixRowIterator<Element_t, Alloc>::
rbegin () const
{
  return dual_reverse_iterator_type(end());
}


template<class Element_t, class Alloc>
typename PackedMatrixRowIterator<Element_t, Alloc>::
dual_reverse_iterator_type 
PackedMatrixRowIterator<Element_t, Alloc>::
rend () const
{
  return dual_reverse_iterator_type(begin());
}


template<class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc> 
operator+ (int n, const PackedMatrixRowIterator<Element_t, Alloc>& i)
{
  PackedMatrixRowIterator<Element_t, Alloc> result = i;
  result += n;
  return result;
}


template<class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc> 
operator+ (const PackedMatrixRowIterator<Element_t, Alloc>& i, int n)
{
  PackedMatrixRowIterator<Element_t, Alloc> result = i;
  result += n;
  return result;
}


template<class Element_t, class Alloc>
PackedMatrixRowIterator<Element_t, Alloc> 
operator- (const PackedMatrixRowIterator<Element_t, Alloc>& i, int n)
{
  PackedMatrixRowIterator<Element_t, Alloc> result = i;
  result -= n;
  return result;
}

