/* PointSet.cc
 * -----------
 * Implements PointSet.h
 *
 * Written by Patrick Perry
 * Original Version on July 5 2004
 *
 * $Id: PointSet.cc,v 1.2 2005/10/24 16:19:56 patperry Exp $
 * $Log: PointSet.cc,v $
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:19  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.1  2004/07/07 23:05:39  patperry
 * Added PointSet
 *
 */



template <class Alloc>
template <class InputIterator>
PointSet<Alloc>::
PointSet (int dimension, InputIterator begin, InputIterator end, 
		bool freePoints)
  : dimension(dimension), 
    points(begin, end), 
    searchTree(const_cast<double **>(&(points[0])), 
			points.size(), dimension, 1,
			ANN_KD_SUGGEST, ANN_BD_SUGGEST),
    freePoints(freePoints)
{
}


template <class Alloc>
PointSet<Alloc>::
~PointSet ()
{
  if (freePoints) {
    typename std::vector<Point, PointAlloc>::iterator it = points.begin();
    typename std::vector<Point, PointAlloc>::iterator end = points.end();

    while (it != end) {
	 delete *it++;
    }
  }
}


template <class Alloc>
int
PointSet<Alloc>::
getDimension () const
{
  return dimension;
}


template <class Alloc>
int
PointSet<Alloc>::
getSize() const
{
  return points.size();
}

template <class Alloc>
typename PointSet<Alloc>::iterator
PointSet<Alloc>::
begin () const
{
  return points.begin();
}


template <class Alloc>
typename PointSet<Alloc>::iterator
PointSet<Alloc>::
end () const
{
  return points.end();
}


template <class Alloc>
template <class OutputIterator>
OutputIterator 
PointSet<Alloc>::
getNearestNeighbors (Point query, int numNeighbors, 
				 double errorBound, OutputIterator neighbors) const
{
  int neighborIndices[numNeighbors];
  double neighborDistances[numNeighbors];

  searchTree.annkSearch(const_cast<double *>(query), numNeighbors, 
				    neighborIndices, neighborDistances, errorBound);

  for (int i = 0; i < numNeighbors; ++i) {
    Point neighbor = points[neighborIndices[i]];
    double distance = neighborDistances[i];
    NeighborQueryResult queryResult(neighbor, distance);

    *neighbors++ = queryResult;
  }

  return neighbors;
}
