/* SimplexBoundaryOperator.h
 * -------------------------
 * Written by Patrick Perry
 * Original Version on February 25, 2004
 *
 * $Id: SimplexBoundaryOperator.h,v 1.1.1.1 2005/03/18 23:37:21 silva Exp $
 * $Log: SimplexBoundaryOperator.h,v $
 * Revision 1.1.1.1  2005/03/18 23:37:21  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.4  2004/02/27 10:49:06  patperry
 * More playing around with boundary operators
 *
 * Revision 1.3  2004/02/26 11:09:54  patperry
 * persistence changes
 *
 * Revision 1.2  2004/02/26 10:17:44  patperry
 * Compile bugs
 *
 * Revision 1.1  2004/02/26 10:12:09  patperry
 * Initial version.
 *
 */

#ifndef _SIMPLEXBOUNDARYOPERATOR_H
#define _SIMPLEXBOUNDARYOPERATOR_H

#include <utility>


/**
 * Defines a generic operator to get the boundary of a simplex by
 * passing in a handle to the simplex.  This class is designed to
 * be used with Afra Zommorodian's persistence code.
 */
template <class SimplexHandle_t, class Coeff_t>
class SimplexBoundaryOperator
{
 public:

  //! the simplex handle type
  typedef SimplexHandle_t Simplex_handle;

  //! the coefficient type
  typedef Coeff_t Coeff;

  //! the type for storing chain components
  typedef std::pair<Simplex_handle, Coeff> value_type;

  //! the tag indicating that we use handles
  typedef Boundary_handle_tag rep_tag;

  
 public:

  /**
   * Function-call operator.  This writes the boundary of a simplex to
   * an output iterator in the form of dimension+1 (handle, coefficient)
   * pairs.  Calling this function on a vertex just returns out.
   *
   * \param simplex the simplex to get the boundary of.
   * \param out the output iterator to write the result to.
   * \returns out + (dimension + 1) (or just out in the case of a vertex).
   */
  template <class OutputIterator>
  OutputIterator operator() (Simplex_handle simplex, OutputIterator out);

};

// get compiler to see function definitions
#include "SimplexBoundaryOperator.cc"


#endif // _SIMPLEXBOUNDARYOPERATOR_H
