/* SimplexIterator.cc
 * ------------------
 * Implements SimplexIterator.h
 *
 * Written by Patrick Perry
 * Original Version on 10/10/2003
 *
 * $Id: SimplexIterator.cc,v 1.1.1.1 2005/03/18 23:37:21 silva Exp $
 * $Log: SimplexIterator.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:37:21  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.6  2004/02/25 09:27:59  patperry
 * Added ConstSimplexIterators
 *
 * Revision 1.5  2004/02/24 23:48:40  patperry
 * Fixed bugs in Simplex destructor
 *
 * Revision 1.4  2004/02/24 13:30:39  patperry
 * Radically restructured Simplex/Simplicial Complex
 *
 * Revision 1.3  2004/01/15 07:10:33  patperry
 * Changed file extensions.
 *
 * Revision 1.2  2003/11/13 06:25:30  patperry
 * Added method to construct scomplex from a graph
 *
 * Revision 1.1  2003/10/10 11:09:03  patperry
 * Added better interface of inserting simplices into a simplicial complex.  Added
 * simplex iterators.
 *
 *
 */

#include <cassert>


template <class SimplexHandle, class Alloc>
SimplexIterator<SimplexHandle, Alloc>::
SimplexIterator (SimplexHandle simplex)
  : simplex(simplex)
{
}


template <class SimplexHandle, class Alloc>
SimplexIterator<SimplexHandle, Alloc>::
SimplexIterator ()
  : simplex(NULL)
{
}


template <class SimplexHandle, class Alloc>
SimplexIterator<SimplexHandle, Alloc>&
SimplexIterator<SimplexHandle, Alloc>::
operator++ ()
{
  assert(simplex != NULL);

  // there is only one nil simplex, so we go straight to the end
  if (simplex->getDimension() == -1) {
    simplex = *(simplex->scomplex->simplicesEnd(-1));
  } else {
    // the parent of a simplex is its last face
    SimplexIterator lowerSimplex(simplex->getFace(simplex->getDimension()));
    SimplexIterator lowerSimplicesEnd(*(simplex->scomplex->
								simplicesEnd(simplex
										   ->getDimension() - 1)));
    typename Simplex::ConstCofaceIterator upperBound;
    
    while (lowerSimplex != lowerSimplicesEnd) {
	 upperBound = std::upper_bound((*lowerSimplex)->cofacesBegin(), 
							 (*lowerSimplex)->cofacesEnd(),
							 simplex, Simplex::simplexPointerLess);
	 if (upperBound != (*lowerSimplex)->cofacesEnd()) {
	   simplex = *upperBound;
	   break;
	 } else {
	   ++lowerSimplex;
	 }
    }
    
    if (lowerSimplex == lowerSimplicesEnd) {
	 SimplexHandle nextBeginSimplex 
	   = *(simplex->scomplex->simplicesBegin(simplex->getDimension() + 1));
		  
	 simplex = nextBeginSimplex;
    }
  }

  return *this;
}


template <class SimplexHandle, class Alloc>
SimplexIterator<SimplexHandle, Alloc>
SimplexIterator<SimplexHandle, Alloc>::
operator++ (int dummy)
{
  SimplexIterator old = *this;
  ++(*this);

  return old;
}


template <class SimplexHandle, class Alloc>
SimplexHandle
SimplexIterator<SimplexHandle, Alloc>::
operator* () const
{
  return simplex;
}


template <class SimplexHandle, class Alloc>
bool 
SimplexIterator<SimplexHandle, Alloc>::
operator== (SimplexIterator x)
{
  return (simplex == x.simplex);
}


template <class SimplexHandle, class Alloc>
bool 
SimplexIterator<SimplexHandle, Alloc>::
operator!= (SimplexIterator x)
{
  return (simplex != x.simplex);
}


