/* SimplexIterator.h
 * -----------------
 * Written by Patrick Perry
 * Original Version on 10/10/2003
 *
 * $Id: SimplexIterator.h,v 1.1.1.1 2005/03/18 23:37:21 silva Exp $
 * $Log: SimplexIterator.h,v $
 * Revision 1.1.1.1  2005/03/18 23:37:21  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.3  2004/02/25 09:27:59  patperry
 * Added ConstSimplexIterators
 *
 * Revision 1.2  2004/02/24 13:30:39  patperry
 * Radically restructured Simplex/Simplicial Complex
 *
 * Revision 1.1  2004/01/15 07:10:33  patperry
 * Changed file extensions.
 *
 * Revision 1.2  2003/11/13 06:25:30  patperry
 * Added method to construct scomplex from a graph
 *
 * Revision 1.1  2003/10/10 11:09:03  patperry
 * Added better interface of inserting simplices into a simplicial complex.  Added
 * simplex iterators.
 *
 *
 */


#ifndef _SIMPLEXITERATOR_H
#define _SIMPLEXITERATOR_H

template <class SimplexHandle, class Alloc>
class SimplexIterator;

#include "Simplex.h"

#include <iterator>

/**
 * Iterator type for a collection of simplices of a given dimension.
 */
template <class SimplexHandle, class Alloc>
class SimplexIterator 
  : public std::iterator<std::input_iterator_tag, SimplexHandle>
{

 public:
  //! The simplex type
  typedef Simplex<Alloc> Simplex;
  
 private:

  //! the simplex pointed to by the iterator
  SimplexHandle simplex;
  
 public:
  
  /**
   * Constructor.  Creates an iterator to the given simplex.
   *
   * \param simplex the simplex to point to.
   */
  SimplexIterator (SimplexHandle simplex);

  /**
   * Default constructor.
   */
  SimplexIterator ();

  /**
   * Preincrement operator.
   */
  SimplexIterator& operator++ ();
  
  /**
   * Postincrement operator.
   */
  SimplexIterator operator++ (int dummy);

  /**
   * Dereference operator.
   */
  SimplexHandle operator* () const;

  /**
   * Equality comparison operator.
   *
   * \param x a SimplexIterator to compare to.
   */
  bool operator== (SimplexIterator x);

  /**
   * Non-equality comparison operator.
   *
   * \param x a SimplexIterator to compare to.
   */
  bool operator!= (SimplexIterator x);

};


// get compiler to see definitions
#include "SimplexIterator.cc"


#endif // _SIMPLEXITERATOR_H
