/* SimplicialComplex.cc
 * --------------------
 * Implements SimplicialComplex.h
 *
 * Written by Patrick Perry
 * Initial version on 10/2/2003
 *
 * $Id: SimplicialComplex.cc,v 1.4 2005/10/24 16:19:56 patperry Exp $
 * $Log: SimplicialComplex.cc,v $
 * Revision 1.4  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.3  2005/06/15 22:56:32  patperry
 * Fixed bug when trying to expand from negative dimension
 *
 * Revision 1.2  2005/05/03 22:34:14  patperry
 * Fixed intersect and union bugs
 *
 * Revision 1.1.1.1  2005/03/18 23:37:23  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.35  2004/09/16 06:16:12  patperry
 * Fixed bug in rippsExpand.
 *
 * Revision 1.34  2004/09/15 18:14:15  patperry
 * Added "fromDimension" functionality for expand.
 *
 * Revision 1.33  2004/08/03 17:17:30  patperry
 * Fixed bug in removeSimplex
 *
 * Revision 1.32  2004/08/02 22:43:34  zakh
 * *** empty log message ***
 *
 * Revision 1.31  2004/06/21 17:16:51  patperry
 *
 * Generalized scomplex construction with graph.
 *
 * Revision 1.30  2004/05/10 22:47:33  patperry
 * Added addFaces.
 *
 * Revision 1.29  2004/04/03 23:05:46  patperry
 * Bugfix and document attach
 *
 * Revision 1.28  2004/04/02 08:25:35  patperry
 * Modified complex from graph routine.
 *
 * Revision 1.27  2004/03/15 08:15:31  patperry
 * fixed some simplex identification stuff
 *
 * Revision 1.26  2004/03/13 07:27:05  patperry
 * Fixed bugs in degenerate simpelx handling.
 *
 * Revision 1.25  2004/03/13 07:21:44  patperry
 * fixed degenerate simplex counting
 *
 * Revision 1.24  2004/03/13 07:08:14  patperry
 * fixed semantic error in relativeTo
 *
 * Revision 1.23  2004/03/13 06:38:19  patperry
 * added initial version of relative complex code
 *
 * Revision 1.22  2004/03/13 00:05:03  patperry
 * fixed tiny bug in restrict
 *
 * Revision 1.21  2004/03/09 07:59:23  patperry
 * Implemented restrict and neighborhood.
 *
 * Revision 1.20  2004/02/26 06:49:24  patperry
 * Converted mexfiles to use new scomplex interface
 *
 * Revision 1.19  2004/02/25 09:27:59  patperry
 * Added ConstSimplexIterators
 *
 * Revision 1.18  2004/02/25 00:45:52  patperry
 * Fixed RippsExpand.
 *
 * Revision 1.17  2004/02/24 23:48:40  patperry
 * Fixed bugs in Simplex destructor
 *
 * Revision 1.16  2004/02/24 13:30:39  patperry
 * Radically restructured Simplex/Simplicial Complex
 *
 * Revision 1.15  2004/02/09 06:34:04  patperry
 * Playing around with hashtable.
 *
 * Revision 1.14  2004/01/30 23:57:29  patperry
 * added neighborhood functionality
 *
 * Revision 1.13  2004/01/15 07:10:33  patperry
 * Changed file extensions.
 *
 * Revision 1.12  2003/11/18 09:27:20  patperry
 * Fixed const bugs.
 *
 * Revision 1.11  2003/11/18 06:46:35  patperry
 * added intersect and union.
 *
 * Revision 1.10  2003/11/18 06:23:33  patperry
 * Added k-skeleton constructor.
 *
 * Revision 1.9  2003/11/18 00:33:02  patperry
 * Added copy constructor and assignment operator.
 *
 * Revision 1.8  2003/11/14 10:18:33  patperry
 * Added getDimension method.
 *
 * Revision 1.7  2003/11/13 09:07:05  patperry
 * Added Ripps expand.
 *
 * Revision 1.6  2003/11/13 06:25:30  patperry
 * Added method to construct scomplex from a graph
 *
 * Revision 1.5  2003/10/16 08:42:15  patperry
 * Added a Chain data structure.
 *
 * Revision 1.4  2003/10/10 22:59:11  patperry
 * Fixed potential memory leak.
 *
 * Revision 1.3  2003/10/10 22:08:24  patperry
 * Fixed problems with addSimplex.
 * Added a removeSimplex function to SimpicialComplex.
 *
 * Revision 1.2  2003/10/10 11:09:03  patperry
 * Added better interface of inserting simplices into a simplicial complex.  Added
 * simplex iterators.
 *
 * Revision 1.1.1.1  2003/10/09 03:24:46  patperry
 * Imported Sources
 *
 */

#include <cassert>
#include <iostream>
#include <iterator>
#include <utility>

// Lots of trouble just to get a SGI extensions.  Code taken from
// http://gcc.gnu.org/onlinedocs/libstdc++/faq/index.html#5_4
#ifdef __GNUC__
#if __GNUC__ < 3
  #include <algo.h>
  namespace Sgi { using ::hash_map }; 
#else
  #include <ext/algorithm>
  #if ((__GNUC__ == 3) && (__GNUC_MINOR__ == 0))
    namespace Sgi = std;
  #else 
    namespace Sgi = ::__gnu_cxx;
  #endif
#endif
#else
  #include <algorithm>
  namespace Sgi = std;
#endif 



// static member instantiation
template <class Alloc>
typename Alloc::template rebind<Simplex<Alloc> >::other 
SimplicialComplex<Alloc>::SimplexAlloc;


template <class Alloc>
SimplicialComplex<Alloc>::
SimplicialComplex ()
  : nilSimplex(*this, -1, static_cast<int *>(NULL), 
			static_cast<Simplex **>(NULL))
{
}


template <class Alloc>
SimplicialComplex<Alloc>::
SimplicialComplex (const SimplicialComplex& scomplex)
  : nilSimplex(*this, -1, static_cast<int *>(NULL), 
			static_cast<Simplex **>(NULL))
{
  for (int i = 0; i <= scomplex.getDimension(); ++i) {
    ConstSimplexIterator it = scomplex.simplicesBegin(i);
    ConstSimplexIterator end = scomplex.simplicesEnd(i);

    while (it != end) {
	 addSimplex(i, (*it++)->getLabel());
    }
  }
}


template <class Alloc>
template <class Element_t, class ColumnIterator_t, class Alloc1,
		class InputIterator>
SimplicialComplex<Alloc>::
SimplicialComplex (const Matrix<Element_t, ColumnIterator_t, Alloc1>& graph,
			    InputIterator vertexLabelsBegin)
  : nilSimplex(*this, -1, static_cast<int *>(NULL), 
			static_cast<Simplex **>(NULL))
{
  assert(graph.getNumColumns() == graph.getNumRows());

  int numVertices = graph.getNumColumns();
  int vertexLabels[numVertices];

  Sgi::copy_n(vertexLabelsBegin, numVertices, vertexLabels);

  // add the vertices and edges
  for (int v1 = 0; v1 < graph.getNumColumns(); ++v1) {
    int edgeLabel[2];

    // add a vertex
    addVertex(vertexLabels[v1]);
    
    // add all edges connecting vertex to already-existing vertices
    edgeLabel[1] = vertexLabels[v1];

    ColumnIterator_t column_it = graph.getColumnBegin(v1);
    for (int v2 = 0; v2 < v1; ++v2) {
	 // for evey nonzero entry above the diagonal in column v1
	 if (*column_it++ != 0) {
	   // add an edge
	   edgeLabel[0] = vertexLabels[v2];
	   addSimplex(1, edgeLabel);
	 }
    }
  }
}


template <class Alloc>
SimplicialComplex<Alloc>::
~SimplicialComplex ()
{
}


template <class Alloc>
SimplicialComplex<Alloc>& 
SimplicialComplex<Alloc>::
operator= (const SimplicialComplex& scomplex)
{
  if (this != &scomplex) {
    this->~SimplicialComplex();
    new(this) SimplicialComplex(scomplex);
  }

  return *this;
}


template <class Alloc>
int
SimplicialComplex<Alloc>::
getDimension () const
{
  return (numSimplices.size() - 1);
}


template <class Alloc>
int 
SimplicialComplex<Alloc>::
getNumSimplices (int dimension) const
{
  assert(dimension >= 0);
  
  int result = 0;

  if (dimension <= getDimension()) {
    result = numSimplices[dimension];
  }

  return result;
}


template <class Alloc>
int 
SimplicialComplex<Alloc>::
getNumSimplices () const
{
  int result = 0;

  for (int i = 0; i <= getDimension(); ++i) {
    result += getNumSimplices(i);
  }

  return result;
}


template <class Alloc>
int 
SimplicialComplex<Alloc>::
getNumDegenerateSimplices (int dimension) const
{
  int result = 0;
  ConstSimplexIterator simplex_it = simplicesBegin(dimension);
  ConstSimplexIterator simplex_end = simplicesEnd(dimension);

  while (simplex_it != simplex_end) {
    if ((*simplex_it++)->isDegenerate()) {
	 ++result;
    }
  }

  return result;
}


template <class Alloc>
int 
SimplicialComplex<Alloc>::
getNumDegenerateSimplices () const
{
  int result = 0;

  for (int i = 0; i <= getDimension(); ++i) {
    result += getNumDegenerateSimplices(i);
  }

  return result;
}


template <class Alloc>
typename SimplicialComplex<Alloc>::SimplexIterator
SimplicialComplex<Alloc>::
simplicesBegin (int dimension) 
{
  const SimplicialComplex * const_this = this;
  ConstSimplexIterator constPos = const_this->simplicesBegin(dimension);
  SimplexIterator result(const_cast<Simplex *>(*constPos));

  return result;
}


template <class Alloc>
typename SimplicialComplex<Alloc>::ConstSimplexIterator
SimplicialComplex<Alloc>::
simplicesBegin (int dimension) const
{
  assert(dimension >= -1);

  // initialize result to be the end of the collection
  ConstSimplexIterator result(NULL);

  if (dimension <= getDimension()) {
    if (dimension == -1) {
	 result = ConstSimplexIterator(&nilSimplex);
    } else if (dimension == 0) {
	 result = ConstSimplexIterator(*(nilSimplex.cofacesBegin()));
    } else {
	 ConstSimplexIterator lower_it = simplicesBegin(dimension - 1);

	 while ((*lower_it)->getNumCofaces() == 0) {
	   ++lower_it;
	 }

	 result = ConstSimplexIterator(*((*lower_it)->cofacesBegin()));
    }
  }

  return result;
}


template <class Alloc>
typename SimplicialComplex<Alloc>::SimplexIterator
SimplicialComplex<Alloc>::
simplicesEnd (int dimension) 
{
  const SimplicialComplex * const_this = this;
  ConstSimplexIterator constPos = const_this->simplicesEnd(dimension);
  SimplexIterator result(const_cast<Simplex *>(*constPos));

  return result;
}


template <class Alloc>
typename SimplicialComplex<Alloc>::ConstSimplexIterator
SimplicialComplex<Alloc>::
simplicesEnd (int dimension) const
{
  assert(dimension >= -1);

  ConstSimplexIterator result = simplicesBegin(dimension + 1);

  return result;
}


template <class Alloc>
typename SimplicialComplex<Alloc>::SimplexIterator
SimplicialComplex<Alloc>::
addVertex (int label)
{
  SimplexIterator result = findSimplex(0, &label);

  // if the vertex doesn't already exist
  if (result == simplicesEnd(0)) {
    Simplex * nilSimplexIter = &nilSimplex;
    Simplex * vertex = SimplexAlloc.allocate(1);
    new(vertex) Simplex(*this, 0, &label, &nilSimplexIter);

    result = SimplexIterator(vertex);
  }

  return result;
}


template <class Alloc>
template <class InputIterator>
typename SimplicialComplex<Alloc>::SimplexIterator
SimplicialComplex<Alloc>::
addSimplex (int dimension, InputIterator label)
{
  assert(dimension >= 0);

  int simplexLabel[dimension + 1];
  Sgi::copy_n(label, dimension + 1, simplexLabel);

  SimplexIterator result;

  //std::cout << "Adding simplex [ ";
  //Sgi::copy_n(label, dimension + 1, 
  //		    std::ostream_iterator<int>(std::cout, " "));
  //std::cout << "].\n";

  if (dimension == 0) {
    result = addVertex(*simplexLabel);

  } else {
    result = findSimplex(dimension, simplexLabel);

    // if the simplex doesn't already exist...
    if (result == simplicesEnd(dimension)) {
	 Simplex * faces[dimension + 1];
	 int faceDimension = dimension - 1;
	 int faceLabel[dimension];
	 
	 // initialize the first face label
	 std::copy(simplexLabel + 1, simplexLabel + dimension + 1, faceLabel);
	   
	 // add all the faces if necessary
	 for (int i = 0; i <= dimension; ++i) {
	   faces[i] = *(addSimplex(faceDimension, faceLabel));
	   
	   // proceed to the next label
	   if (i != dimension) {
		faceLabel[i] = simplexLabel[i];
	   }
	 }
	 
	 // create a new simplex
	 Simplex * simplex = SimplexAlloc.allocate(1);
	 new(simplex) Simplex(*this, dimension, simplexLabel, faces);
	 
	 result = SimplexIterator(simplex);
    }
  }

  return result;
}


template <class Alloc>
template <class InputIterator>
void 
SimplicialComplex<Alloc>::
addFaces (int dimension, InputIterator label, int k)
{
  assert (dimension >= 0);
  assert (k >= 0);

  int simplexLabel[dimension + 1];
  Sgi::copy_n(label, dimension + 1, simplexLabel);

  //std::cout << "Adding " << k << "-faces of [ ";
  //Sgi::copy_n(label, dimension + 1,
  //		    std::ostream_iterator<int>(std::cout, " "));
  //std::cout << "].\n";

  if (k > dimension) {
    k = dimension;
  }

  int faceLabel[k + 1];
  int faceIndices[k + 1];

  // initialize faceIndices to be the first face 
  for (int i = 0; i <= k; ++i) {
    faceIndices[i] = i;
  }

  bool hasNext = true;
  do {
    // determine the label of the current face
    for (int i = 0; i <= k; ++i) {
	 faceLabel[i] = simplexLabel[faceIndices[i]];
    }

    // add the face to the complex
    //std::cout << "Adding face [ ";
    //Sgi::copy_n(faceLabel, k + 1,
    //		 std::ostream_iterator<int>(std::cout, " "));
    //std::cout << "].\n";
    addSimplex(k, faceLabel);

    // determine the indices for the next face
    int pos = k;
    
    while ((pos >= 0) && (faceIndices[pos] == (dimension - k + pos))) {
	 --pos;
    }
    
    if (pos < 0) {
	 hasNext = false;
    } else {
	 faceIndices[pos]++;
	 
	 for (int i = pos + 1; i <= k; ++i) {
	   faceIndices[i] = faceIndices[i - 1] + 1;
	 }
    }
  } while (hasNext);
}

template <class Alloc>
template <class InputIterator>
void 
SimplicialComplex<Alloc>::
removeSimplex (int dimension, InputIterator label)
{
  assert(dimension >= 0);

  // try finding the simplex
  SimplexIterator position = findSimplex(dimension, label);

  // if the simplex is in the set...
  if (position != simplicesEnd(dimension)) {
    Simplex * simplex = *position;

    // delete the simplex
    SimplexAlloc.destroy(simplex);
    SimplexAlloc.deallocate(simplex, 1);
  }
}


template <class Alloc>
typename SimplicialComplex<Alloc>::SimplexIterator 
SimplicialComplex<Alloc>::
removeSimplex (SimplexIterator pos)
{
  Simplex * simplex = *pos++;

  if ((pos != simplicesEnd(getDimension())
	  && (simplex->getDimension() != (*pos)->getDimension()))) {
    while ((pos != simplicesEnd(getDimension()))
		 && (simplex->findCoface((*pos)->getDimension(), (*pos)->getLabel())
			!= simplex->cofacesEnd())) {
	 pos++;
    }
  }

  // delete the simplex
  SimplexAlloc.destroy(simplex);
  SimplexAlloc.deallocate(simplex, 1);
  
  return pos;
}


template <class Alloc>
template <class InputIterator>
typename SimplicialComplex<Alloc>::SimplexIterator
SimplicialComplex<Alloc>::
findSimplex (int dimension, InputIterator label)
{
  const SimplicialComplex * const_this = this;
  ConstSimplexIterator constPos = const_this->findSimplex(dimension, label);
  SimplexIterator result(const_cast<Simplex *>(*constPos));

  return result;
}


template <class Alloc>
template <class InputIterator>
typename SimplicialComplex<Alloc>::ConstSimplexIterator 
SimplicialComplex<Alloc>::
findSimplex (int dimension, InputIterator label) const
{
  assert(dimension >= 0);

  int simplexLabel[dimension + 1];
  const Simplex * currentFace = &nilSimplex;
  ConstSimplexIterator result = simplicesEnd(dimension);

  Sgi::copy_n(label, dimension + 1, simplexLabel);

  for (int faceDimension = 0; faceDimension <= dimension; ++faceDimension) {
    typename Simplex::ConstCofaceIterator cofacePos 
	 = currentFace->findCoface(faceDimension, simplexLabel);

    if (cofacePos != currentFace->cofacesEnd()) {
	 currentFace = *cofacePos;
    } else {
	 break;
    }
  }

  if (currentFace->getDimension() == dimension) {
    result = ConstSimplexIterator(currentFace);
  } 

  return result;
}


template <class Alloc>
void 
SimplicialComplex<Alloc>::
rippsExpand (int fromDimension, int toDimension)
{
  for (int currentDimension = std::max(fromDimension, 0);
	  currentDimension < toDimension; ++currentDimension) {
    SimplexIterator simplex_it = simplicesBegin(currentDimension);

    int newSimplexLabel[currentDimension + 2];

    // for each simplex of the current dimension
    while (simplex_it != simplicesEnd(currentDimension)) {
	 // use the label of the simplex as the first part of the potential 
	 // simplex label
	 Sgi::copy_n((*simplex_it)->getLabel(), currentDimension + 1, 
			   newSimplexLabel);

	 // Letting d = currentDimension, the potential new simplex is 
	 // [0 1 2 3 ... d X] (where [0 1 2 3 ... d] is the current simplex.  
	 // We try a value for X if the simplex [0 1 2 3 ... (d - 1) X] exists 
	 // in the complex and X > d.  If this simplex exists, then it is a 
	 // coface of [0 1 2 3 ... (d-1)].  We call [0 1 2 3 ... (d-1)] "face", 
	 // and iterate through face's cofaces with labels lexicographically 
	 // greater than [0 1 2 3 ... d].
	 Simplex * face = *((*simplex_it)->facesBegin());

	 typename Simplex::CofaceIterator faceCoface 
	   = face->findCoface(currentDimension, 
					  (*simplex_it)->getLabel()) + 1;
	 typename Simplex::CofaceIterator faceCofacesEnd 
	   = face->cofacesEnd();

	 while (faceCoface != faceCofacesEnd) {
	   newSimplexLabel[currentDimension + 1] 
		= *((*faceCoface++)->getLabel() + currentDimension);
	   if ((*simplex_it)->findCoface(currentDimension + 1, newSimplexLabel)
		  == (*simplex_it)->cofacesEnd()) {
		rippsExpandSimplex(currentDimension + 1, newSimplexLabel);
	   }
	 }

	 ++simplex_it;
    }
  }
}


template <class Alloc>
template <class InputIterator>
bool
SimplicialComplex<Alloc>::
rippsExpandSimplex (int dimension, InputIterator label)
{
  assert(dimension > 0);

  bool result = true;
  int simplexLabel[dimension + 1];
  Sgi::copy_n(label, dimension + 1, simplexLabel);

  Simplex * boundary[dimension + 1];
  int faceLabel[dimension];

  // initialize faceLabel to be the label of the first face
  Sgi::copy_n(simplexLabel + 1, dimension, faceLabel);
    
  // for each face
  for (int i = 0; i <= dimension; ++i) {
    SimplexIterator face_pos = findSimplex(dimension - 1, faceLabel);

    // make sure the face exists
    if (face_pos != simplicesEnd(dimension - 1)) {
	 boundary[i] = *face_pos;
    } else {
	 result = false;
	 break;
    }
    
    // proceed to the next face label
    if (i != dimension) {
	 faceLabel[i] = label[i];
    }
  }
    
  // if we found all faces, allocate a new simplex
  if (result) {
    Simplex * simplex = SimplexAlloc.allocate(1);
    new(simplex) Simplex(*this, dimension, simplexLabel, boundary);
  }

  return result;
}


template <class Alloc>
void 
SimplicialComplex<Alloc>::
intersectComplex (const SimplicialComplex& scomplex)
{
  // for each dimension, intersect the simplices at the dimension i
  for (int i = 0; i <= getDimension(); ++i) {
    // for each simplex
    SimplexIterator it = simplicesBegin(i);
    while (it != simplicesEnd(i)) {
     typename Simplex::LabelIterator label = (*it)->getLabel();

	 // if the simplex does not exist in the other scomplex
	 if (scomplex.findSimplex(i, (*it)->getLabel()) 
		== scomplex.simplicesEnd(i)) {
	   // remove the simplex
	   it = removeSimplex(it);
	 } else {
	   ++it;
	 }
    }
  }
}


template <class Alloc>
void 
SimplicialComplex<Alloc>::
unionComplex (const SimplicialComplex& scomplex)
{
  // for each dimension, union the simplices at the dimension i
  for (int i = scomplex.getDimension(); i >= 0; --i) {
    // for each simplex in the other complex
    for (ConstSimplexIterator it = scomplex.simplicesBegin(i);
	    it != scomplex.simplicesEnd(i); ++it) {

	 // add the simplex if it does not already exist
	 addSimplex(i, (*it)->getLabel());
    }
  }
}


template <class Alloc>
SimplicialComplex<Alloc> * 
SimplicialComplex<Alloc>::
getSkeleton (int k) const
{
  assert(k >= 0);

  // allocate the result
  SimplicialComplex * result = new SimplicialComplex();

  for (int i = 0; i <= k; ++i) {
    ConstSimplexIterator it = simplicesBegin(i);
    ConstSimplexIterator end = simplicesEnd(i);

    while (it != end) {
	 result->addSimplex(i, (*it++)->getLabel());
    }
  }

  return result;
}


template <class Alloc>
template <class InputIterator>
SimplicialComplex<Alloc> *
SimplicialComplex<Alloc>::
getNeighborhood (InputIterator verticesBegin, InputIterator verticesEnd) const
{
  // allocate the result
  SimplicialComplex * result = new SimplicialComplex();
  
  // initialize the vertex set
  std::vector<int> starSet(verticesBegin, verticesEnd);
  std::sort(starSet.begin(), starSet.end());
  
  // add all the vertices to the simplicial complex
  for (std::vector<int>::iterator it = starSet.begin(); 
	  it != starSet.end(); ++it) {
    result->addVertex(*it);
  }
  
  // add the rest of the simplices in the star
  for (int dimension = 1; dimension <= getDimension();
       ++dimension) {
    ConstSimplexIterator simplex_it = simplicesBegin(dimension);
    ConstSimplexIterator simplex_end = simplicesEnd(dimension);
      
    while (simplex_it != simplex_end) {
	 typename Simplex::LabelIterator label = (*simplex_it)->getLabel();
	 
      // if any vertex in a simplex is part of the vertex set, it is
      // in the star
      for (int i = 0; i <= dimension; ++i) {
	   if (std::binary_search(starSet.begin(), starSet.end(), label[i])) {
		result->addSimplex(dimension, label);
		break;
	   }
      }
	 
      ++simplex_it;
    }
  }
  
  return result;
}


template <class Alloc>
template <class InputIterator>
SimplicialComplex<Alloc> *
SimplicialComplex<Alloc>::
getRestriction (InputIterator verticesBegin, InputIterator verticesEnd) const
{
  // initialized the result to be an empty simplicial complex
  SimplicialComplex * result = new SimplicialComplex();

  // initialize the vertex set
  std::vector<int> vertexSet(verticesBegin, verticesEnd);
  std::sort(vertexSet.begin(), vertexSet.end());

  // add all the vertices to the simplicial complex
  for (std::vector<int>::iterator it = vertexSet.begin(); 
	  it != vertexSet.end(); ++it) {
    result->addVertex(*it);
  }
  
  // add the rest of the simplices in the restriction
  for (int dimension = 1; dimension <= getDimension(); ++dimension) {
    ConstSimplexIterator simplex_it = simplicesBegin(dimension);
    ConstSimplexIterator simplex_end = simplicesEnd(dimension);
      
    while (simplex_it != simplex_end) {
	 typename Simplex::LabelIterator label = (*simplex_it)->getLabel();
	 bool inRestriction = true;
	 
      // if every vertex of the simplex is part of the vertex set, it is
      // in the restriction
      for (int i = 0; i <= dimension; ++i) {
	   if (!(std::binary_search(vertexSet.begin(), 
						   vertexSet.end(), label[i]))) {
		inRestriction = false;
		break;
	   }
      }
	 
	 if (inRestriction) {
	   result->addSimplex(dimension, label);
	 }

      ++simplex_it;
    }
  }
  
  return result;
}
		

template <class Alloc>
void 
SimplicialComplex<Alloc>::
relativeBy (const SimplicialComplex * subcomplex)
{
  ConstSimplexIterator simplex_it = subcomplex->simplicesBegin(0);
  ConstSimplexIterator simplex_end = subcomplex
    ->simplicesEnd(subcomplex->getDimension());

  while (simplex_it != simplex_end) {
    // look for the subcomplex simplex in the simplicial complex
    const Simplex * subcomplexSimplex = *simplex_it++;
    SimplexIterator pos = findSimplex(subcomplexSimplex->getDimension(),
							   subcomplexSimplex->getLabel());
    
    // if found, mark the simplex as degenerate
    if (pos != simplicesEnd(subcomplexSimplex->getDimension())) {
	 (*pos)->identifyWith(&nilSimplex);
    }
  }
}


template <class Alloc>
template <class InputIterator>
void 
SimplicialComplex<Alloc>::
relativeTo (InputIterator verticesBegin, InputIterator verticesEnd)
{
  // sort the vertex set
  std::vector<int> vertexSet(verticesBegin, verticesEnd);
  std::sort(vertexSet.begin(), vertexSet.end());
  
  // make all simplices with vertices not in the vertex set degengerate
  for (int dimension = 0; dimension <= getDimension(); ++dimension) {
    SimplexIterator simplex_it = simplicesBegin(dimension);
    SimplexIterator simplex_end = simplicesEnd(dimension);
      
    while (simplex_it != simplex_end) {
	 typename Simplex::LabelIterator label = (*simplex_it)->getLabel();
	 bool degenerate = true;

      // if a single vertex is in the vertex set, the simplex is not degenerate
      for (int i = 0; i <= dimension; ++i) {
	   if (std::binary_search(vertexSet.begin(), 
						 vertexSet.end(), label[i])) {
		degenerate = false;
		break;
	   }
      }
	 
	 if (degenerate) {
	   (*simplex_it)->identifyWith(&nilSimplex);
	 }

      ++simplex_it;
    }
  }
}
					    

template <class Alloc>
std::ostream&
SimplicialComplex<Alloc>::
put (std::ostream& s) const
{
  // for each set of simplices
  for (int simplexDimension = getDimension();
	  simplexDimension >= 0; --simplexDimension) {
    s << simplexDimension << "-simplices:\n";

    // print out all the simplices
    for (ConstSimplexIterator simplex = simplicesBegin(simplexDimension);
	    simplex != simplicesEnd(simplexDimension); ++simplex) {
	 s << *(*simplex) << std::endl;
    }
  }

  return s;
}


template <class Alloc>
void 
SimplicialComplex<Alloc>::
incrementSimplexCount (int dimension, int num)
{
  assert(dimension >= 0);
  assert(num > 0);

  numSimplices.resize(std::max(dimension, getDimension()) + 1, 0);
  numSimplices[dimension] += num;
}


template <class Alloc>
void 
SimplicialComplex<Alloc>::
decrementSimplexCount (int dimension, int num)
{
  assert (dimension >= 0);
  assert (dimension <= getDimension());
  assert (numSimplices[dimension] - num >= 0);

  numSimplices[dimension] -= num;
  if (numSimplices[dimension] == 0) {
    numSimplices.pop_back();
  }
}


template <class Alloc>
std::ostream& 
operator<< (std::ostream& s, const SimplicialComplex<Alloc>& complex)
{
  return complex.put(s);
}


