/* UnionFilter.cc
 * --------------
 * Implements UnionFilter.h
 *
 * Written by Patrick Perry
 * Original Version on May 23, 2004
 *
 * $Id: UnionFilter.cc,v 1.2 2005/10/24 16:19:56 patperry Exp $
 * $Log: UnionFilter.cc,v $
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:25  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.1  2004/05/28 05:47:55  patperry
 * InitialVersions of ComplexMap and UnionFilter
 *
 */


#include <algorithm>


template <class SimplicialComplex_t, class FiltrationValue_t, 
		class UnaryFunction, class Alloc>
template <class InputIterator1, class InputIterator2>
UnionFilter<SimplicialComplex_t, FiltrationValue_t, UnaryFunction, Alloc>::
UnionFilter (InputIterator1 filtersBegin, InputIterator1 filtersEnd,
		   InputIterator2 complexesBegin, InputIterator2 complexesEnd)
  : filters(filtersBegin, filtersEnd), 
    complexes(complexesBegin, complexesEnd)
{
}


template <class SimplicialComplex_t, class FiltrationValue_t, 
		class UnaryFunction, class Alloc>
UnionFilter<SimplicialComplex_t, FiltrationValue_t, UnaryFunction, Alloc>::
~UnionFilter()
{
}


template <class SimplicialComplex_t, class FiltrationValue_t, 
		class UnaryFunction, class Alloc>
template <class SimplexHandle_t>
FiltrationValue_t
UnionFilter<SimplicialComplex_t, FiltrationValue_t, UnaryFunction, Alloc>::
operator() (SimplexHandle_t simplex) 
{
  typename FilterVector::iterator filter_it = filters.begin();
  typename FilterVector::iterator filter_end = filters.end();
  typename ScomplexVector::iterator complex_it = complexes.begin();

  UnaryFunction * filter;
  const SimplicialComplex_t * complex;
  SimplexHandle_t localSimplex;
  FiltrationValue_t result;

  do {
    filter = &(*filter_it++);
    complex = *complex_it++;
    localSimplex = (ComplexMap<Alloc>(*complex))(simplex);
  } while ((filter_it != filter_end) && (localSimplex == NULL));

  if (localSimplex) {
    result = (*filter)(localSimplex);

    while (filter_it != filter_end) {
	 filter = &(*filter_it++);
	 complex = *complex_it++;
	 localSimplex = (ComplexMap<Alloc>(*complex))(simplex);
	 
	 if (localSimplex) {
	   FiltrationValue_t newValue = (*filter)(localSimplex);
	   result = std::min(result, newValue);
	 }
    }
  }

  return result;
}
