/* UnionFilter.h
 * -------------
 * Written by Patrick Perry
 * Original Version on May 23, 2004
 *
 * $Id: UnionFilter.h,v 1.2 2005/10/24 16:19:56 patperry Exp $
 * $Log: UnionFilter.h,v $
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:25  silva
 * Imported Sources
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.2  2004/05/28 05:54:28  patperry
 * Comment bug
 *
 * Revision 1.1  2004/05/28 05:47:55  patperry
 * InitialVersions of ComplexMap and UnionFilter
 *
 */

#ifndef _UNIONFILTER_H
#define _UNIONFILTER_H

#include <functional>
#include <memory>
#include <vector>
#include "SimplicialComplex.h"


template <class SimplicialComplex_t, class FiltrationValue_t, 
		class UnaryFunction, class Alloc = std::allocator<int> >
class UnionFilter
{
 private:

  typedef std::vector<UnaryFunction, 
				  typename Alloc::template rebind<UnaryFunction>::other> 
    FilterVector;

  //! the collection of filters to union
  FilterVector filters;

  typedef std::vector<const SimplicialComplex_t *, 
				  typename Alloc::template rebind<SimplicialComplex_t *>
    ::other> ScomplexVector;

  //! the collection of simplicial complexes
  ScomplexVector complexes;

 public:

  /**
   * Constructor.  Takes a collectiono of filters and forms the union,
   * defined by the minimum of the filter values.
   *
   * \param filtersBegin the begin of the filters collection.
   * \param filtersEnd the end of the filters collection.
   * \param complexesBegin the begin of the complexes collection.
   * \param complexesEnd the end of the complexes collection.
   */
  template <class InputIterator1, class InputIterator2>
  UnionFilter (InputIterator1 filtersBegin, InputIterator1 filtersEnd,
			InputIterator2 complexesBegin, InputIterator2 complexesEnd);

  /**
   * Destructor.
   */
  virtual ~UnionFilter();

  /**
   * The union filter operator.  Given a simplex, returns the value.
   *
   * \param simplex the simplex to get the filter value of.
   * \returns the value.
   */
  template <class SimplexHandle_t>
  FiltrationValue_t operator() (SimplexHandle_t simplex);

};

// get compiler to see function definitions.
#include "UnionFilter.cc"


#endif // _UNIONFILTER_H
