/* WitnessComplex.cc
 * -----------------
 * Implements WitnessComplex.h
 *
 * Written by Patrick Perry
 * Original Version on July 28, 2004
 *
 * $Id: WitnessComplex.cc,v 1.1.1.1 2005/03/18 23:37:26 silva Exp $
 * $Log: WitnessComplex.cc,v $
 * Revision 1.1.1.1  2005/03/18 23:37:26  silva
 * Imported Sources
 *
 * Revision 1.2  2005/02/11 22:59:31  patperry
 * Fixed witness vertex labeling
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.1  2004/09/16 09:00:24  patperry
 * Added C++ Witness
 *
 */

#include <algorithm>
#include <vector>



template <class Alloc>
template <class InputColumnIterator>
WitnessComplex<Alloc>::
WitnessComplex (InputColumnIterator distancesBegin,
			 InputColumnIterator distancesEnd, int nu, 
			 typename std::iterator_traits<InputColumnIterator>
			 ::value_type R, int maxDim, int firstVertex)
{
  typedef typename std::iterator_traits<InputColumnIterator>::value_type 
    Element_t;
  
  while (distancesBegin != distancesEnd) {
    std::vector<Element_t> column_buffer(distancesBegin.begin(), 
								 distancesBegin.end());
    Element_t m = 0;
    
    if (nu > 0) {
	 typename std::vector<Element_t>::iterator nu_th 
	   = column_buffer.begin() + (nu - 1);
	 std::nth_element(column_buffer.begin(), nu_th, column_buffer.end());
	 m = *nu_th;
    }
    
    std::vector<int> simplexLabel;
    
    typename InputColumnIterator::dual_iterator_type column_begin 
	 = distancesBegin.begin();
    typename InputColumnIterator::dual_iterator_type column_end 
	 = distancesBegin.end();
    
    while (column_begin != column_end) {
	 if (*column_begin <= R + m) {
	   simplexLabel.push_back(column_begin.index1() + firstVertex);
	 }
	 ++column_begin;
    }
    
    if (!simplexLabel.empty()) {
	 addFaces(simplexLabel.size() - 1, simplexLabel.begin(), maxDim);
    }

    ++distancesBegin;
  }
}
