/* WitnessComplex.h
 * ----------------
 * Written by Patrick Perry
 * Original Version on July 27, 2004
 *
 * $Id: WitnessComplex.h,v 1.2 2005/10/24 16:19:56 patperry Exp $
 * $Log: WitnessComplex.h,v $
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:26  silva
 * Imported Sources
 *
 * Revision 1.2  2005/02/11 22:59:31  patperry
 * Fixed witness vertex labeling
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.2  2004/09/16 09:08:19  patperry
 * compile warning
 *
 * Revision 1.1  2004/09/16 09:00:24  patperry
 * Added C++ Witness
 *
 */

#ifndef _WITNESSCOMPLEX_H
#define _WITNESSCOMPLEX_H

#include <iterator>
#include "SimplicialComplex.h"


template <class Alloc = std::allocator<int> >
class WitnessComplex : public SimplicialComplex<Alloc>
{

 public:

  /**
   * Constructor.  Takes a point-to-landmark distance matrix, nu
   * and R parameters, and constructs a witness complex.
   *
   * \param distancesBegin an iterator for the first column of the
   *        distance matrix.
   * \param distancesEnd the end of the columns of the distance matrix.
   * \param nu the nu parameter.
   * \param R the maximum radius of simplex to allow.
   * \param maxDim the maximum dimension of simplex to allow.
   * \param firstVertex the label for the first vertex (default is 0)
   */
  template <class InputColumnIterator>
  WitnessComplex (InputColumnIterator distancesBegin,
			   InputColumnIterator distancesEnd, int nu, 
			   typename std::iterator_traits<InputColumnIterator>
			   ::value_type R, int maxDim, int firstVertex = 0);

};

// get compiler to see function defintions
#include "WitnessComplex.cc"


#endif // _WITNESSCOMPLEX_H
