/* WitnessFilter.h
 * ---------------
 * Written by Patrick Perry
 * Original Version on May 22, 2004
 *
 * $Id: WitnessFilter.h,v 1.3 2005/11/02 01:59:52 patperry Exp $
 * $Log: WitnessFilter.h,v $
 * Revision 1.3  2005/11/02 01:59:52  patperry
 * The last (?) gcc4.0 fixes\!\!\!
 *
 * Revision 1.2  2005/10/24 16:19:56  patperry
 * Hells (literally) of compile fixes for gcc4.0
 *
 * Revision 1.1.1.1  2005/03/18 23:37:26  silva
 * Imported Sources
 *
 * Revision 1.3  2005/03/04 21:38:37  patperry
 * Fixed bug in WitnessFilter
 *
 * Revision 1.2  2005/02/11 23:55:04  patperry
 * Fixed vertex labling in wfilt
 *
 * Revision 1.1.1.1  2004/09/25 22:04:08  patperry
 * Imported sources
 *
 * Revision 1.1  2004/05/28 05:59:14  patperry
 * initial version of WitnessFilter
 *
 */

#ifndef _WITNESSFILTER_H
#define _WITNESSFILTER_H

#include <functional>
#include <memory>
#include <vector>

// Lots of trouble just to get a hashtable.  Code taken from
// http://gcc.gnu.org/onlinedocs/libstdc++/faq/index.html#5_4
#ifdef __GNUC__
#if __GNUC__ < 3
  #include <hash_map.h>
  namespace Sgi { using ::hash_map }; 
#else
  #include <ext/hash_map>
  #if ((__GNUC__ == 3) && (__GNUC_MINOR__ == 0))
    namespace Sgi = std;
  #else 
    namespace Sgi = ::__gnu_cxx;
  #endif
#endif
#else
  #include <hash_map>
  namespace Sgi = std;
#endif 


template <class SimplexHandle_t, class FiltrationValue_t, 
		class Alloc = std::allocator<int> > 
class WitnessFilter
{
  
  //! a mapping from vertex label to landmark index
  Sgi::hash_map<int, int, Sgi::hash<int>, std::equal_to<int>, Alloc> 
  vertexToIndex;

  //! the number of landmarks
  int numLandmarks;

  //! the number of points
  int numPoints;
  
  typedef std::vector<FiltrationValue_t, 
	typename Alloc::template rebind<FiltrationValue_t>::other> 
    FiltrationValueVector_t;

  //! the distances from landmarks to points
  FiltrationValueVector_t distances;

  //! the index of the first row in the matrix
  const int firstRow;

 public:

  /**
   * Constructor.  Takes a set of vertices an a column-major distance
   * matrix and constructs a witness filter function.
   *
   * \param verticesBegin the begin of the vertex set.
   * \param verticesEnd the end of the vertex set.
   * \param distancesBegin the begin of the column-major landmark-to-point
   *        distance matrix.  Each column must have (verticesEnd - verticesEnd)
   *        rows.
   * \param distancesEnd the end of the distance matrix.
   * \param numLandmarks the number of landmarks in the distance matrix.
   * \param nu the nu parameter of the filtration
   * \param firstRow the index of the first row in the matrix.
   */
  template <class InputIterator1, class InputIterator2>
  WitnessFilter (InputIterator1 verticesBegin, InputIterator1 verticesEnd,
			  InputIterator2 distancesBegin, InputIterator2 distancesEnd,
			  int numLandmarks, int nu = 0, int firstRow = 0);

  /**
   * Destructor.
   */
  virtual ~WitnessFilter();

  /**
   * Function operator.  Gets the filtration value associated with a given
   * simplex.
   *
   * \param simplex a handle to the simplex to get the value of.
   * \returns the filtration value in the witness complex
   */
  FiltrationValue_t operator() (SimplexHandle_t simplex) const;

 private:

  /**
   * Map between vertices and rows of the distance matrix.
   * 
   * \param a vertex's label 
   * \returns the corresponding row index
   */
  int getVertexIndex (int vertexLabel) const;

};

// get compiler to see function definitions
#include "WitnessFilter.cc"

#endif // _WITNESSFILTER_H
