// Mod2.h
// ------
// Class for representing an integer mod 2.
//
// Author: Patrick Perry
// Date:   September 2, 2003
//

#ifndef _MOD2_H
#define _MOD2_H

#include <iostream>


class Mod2 
{
  bool value;
 
public:
  class DivideByZero { };

  // Constructors
  Mod2 ();
  Mod2 (bool value);
  Mod2 (int value);
  Mod2 (double value);

  // operations that manipulate the value
  Mod2& operator+= (Mod2 a);
  Mod2& operator-= (Mod2 a);
  Mod2& operator*= (Mod2 a);
  Mod2& operator/= (Mod2 a) throw(DivideByZero);

  // converstion to natural types
  operator bool () const;
  operator int () const;
  operator double () const;

  // comparators
  friend bool operator== (Mod2 a, Mod2 b);
  friend bool operator!= (Mod2 a, Mod2 b);
  friend bool operator< (Mod2 a, Mod2 b);
  friend bool operator<= (Mod2 a, Mod2 b);
  friend bool operator> (Mod2 a, Mod2 b);  
  friend bool operator>= (Mod2 a, Mod2 b);  

  // mixed-mode comparators
  friend bool operator== (int a, Mod2 b);
  friend bool operator== (Mod2 a, int b);
  friend bool operator!= (int a, Mod2 b);
  friend bool operator!= (Mod2 a, int b);
  friend bool operator< (int a, Mod2 b);
  friend bool operator< (Mod2 a, int b);
  friend bool operator<= (int a, Mod2 b);
  friend bool operator<= (Mod2 a, int b);
  friend bool operator> (int a, Mod2 b);  
  friend bool operator> (Mod2 a, int b);  
  friend bool operator>= (int a, Mod2 b);
  friend bool operator>= (Mod2 a, int b);

  // stream operators
  friend std::ostream& operator<< (std::ostream& s, Mod2 a);
  friend std::istream& operator>> (std::istream& s, Mod2& a);
};


// unary arithmatic operations
Mod2 operator+ (Mod2 a);
Mod2 operator- (Mod2 a);

// binary arithmatic operations
Mod2 operator+ (Mod2 a, Mod2 b);
Mod2 operator- (Mod2 a, Mod2 b);
Mod2 operator* (Mod2 a, Mod2 b);
Mod2 operator/ (Mod2 a, Mod2 b) throw(Mod2::DivideByZero);

// mixed-mode arithmetic operations
Mod2 operator+ (int a, Mod2 b);
Mod2 operator+ (Mod2 a, int b);
Mod2 operator- (int a, Mod2 b);
Mod2 operator- (Mod2 a, int b);
Mod2 operator* (int a, Mod2 b);
Mod2 operator* (Mod2 a, int b);
Mod2 operator/ (int a, Mod2 b);
Mod2 operator/ (Mod2 a, int b);


namespace std { 
  int abs(Mod2 x);
}

#endif // _MOD2_H
