function sgnDeclicked = plexTestSpeech(sgn)
% -------------------------------------------------------
% Simple Plex Test (persistent homology) for a frequency 
% representation of a speech signal
%
% --------------------------------------------------------
% Author: Mijail Guillemard - 2010
% Copyright 2010 Mijail Guillemard
% This program is distributed under the terms of the GNU General Public License.
% --------------------------------------------------------

clear all; close all;
fname = 'separator'; 
addpath('isomap'); addpath('cliffordProduct');
global parms; setGlobalParms;

%% =====================================================================
%% Loading Audio Signal

fnam = 'femaleGermanMonoA11Khz'; % fnam = 'beat1'; fnam = 'BassDrumS';
[sg1 Fs] = wavread(['audio/' fnam '.wav']);
lsg1 = length(sg1); 
lsg1 = 2700; % for 11Khz
tag = 'chirpA2'; tag = 'speechB4';
filename = ['results/' fnam]; tag = [filename tag]; parms.tag = tag;

%% loading the castanets h2 file and adding to the speech signal 
casta = 'beat111Khz';
[sg2 Fs] = wavread(['audio/' casta]);
sg2 = click(lsg1,100);
sg2 = sg2(1:lsg1); sg1 = sg1(1:lsg1);
sgn = sg1 + sg2/3; 
wavwrite(sgn,Fs,[tag 'sgnSpeechC.wav']);

%% =====================================================================
%% Constructing High-Dimensional Datasets

pt=1; fftSize = 128; winSize = 128; hopSize = 4; fftSize2 = fftSize/2;
pfft.fftSize = fftSize; pfft.winSize = winSize; pfft.hopSize = hopSize; 
[wxn wsg] = stft(sgn',fftSize,winSize,hopSize);
awxn = abs(wxn);
dawxn = diff(awxn); lawxn = log10(awxn); dlawxn = diff(lawxn);
plotSpectro(sgn,[tag 'spectOrg']);

[wx2 csw] = stft(sg2',fftSize,winSize,hopSize);
awx2 = abs(wx2);
nawx2 = sum(awx2.*awx2); clcs = find(nawx2 > 1); awx2 = awx2(:,clcs);
dawx2 = diff(awx2); lawx2 = log10(awx2); dlawx2 = diff(lawx2);

[wx1 se1] = stft(sg1',fftSize,winSize,hopSize);
awx1 = abs(wx1);
dawx1 = diff(awx1); lawx1 = log10(awx1); dlawx1 = diff(lawx1);
plotSpectro(sg1,[tag 'spectSgn1']);

pcar2 = pcaAnalysis3(awxn',awx1',awx2');       title('awx PCA');
pcar4 = pcaAnalysis3(lawxn',lawx1',lawx2'); title('lawx PCA'); 
screen2jpeg([tag 'PCD1']);

%% =====================================================================
%% Transforming and Filtering Datasets

sek = lawxn; sek1 = lawx1; sek2 = lawx2;
sed = pcar4.tr2c; sep = pcar4.tr;
sed1 = sep(:,1:size(sek1,2)); sed2 = sep(:,size(sek1,2)+1:end);

disp('now entering the plex routines'); 
plexTest2(sed);

