function sgnDeclicked = separator(rmv)
% -------------------------------------------------------
% Main Function for Clifford Separation Routine  
%
% --------------------------------------------------------
% Author: Mijail Guillemard - 2010
% Copyright 2010 Mijail Guillemard
% This program is distributed under the terms of the GNU General Public License.
% --------------------------------------------------------

% clear all; close all; 
close all; 
fname = 'separator'; 
addpath('isomap'); addpath('cliffordProduct');
global parms; setGlobalParms;
if nargin < 1; rmv = 0; end;
if rmv ~= 0 & rmv ~= 1; disp('not supported'); return; end;

%% =====================================================================
%% Loading Audio Signals

fnam = 'femaleGermanMonoA11Khz'; % fnam = 'beat1'; fnam = 'BassDrumS';
% fnam = 'FemaleSpeechEnglish11Khz';
% fnam = 'AllanBeatM'; % fnam = 'h2c';
% fnam = 'beat111Khz'; fnam = 'h2oo11Khz'; % fnam = 'femaleGermanMonoA';
[sg1 Fs] = wavread(['audio/' fnam '.wav']);
lsg1 = length(sg1); 
lsg1 = 40000; % for 44Khz
lsg1 = 10000; % for 11Khz
lsg1 = 7500; % for 11Khz
% lsg1 = 2700; % for 11Khz
tag = 'chirpA2'; tag = 'speechB4';
filename = ['results/' fnam]; tag = [filename tag]; parms.tag = tag;
% sg1 = sin(2*pi*9000*[1:lsg1]/lsg1)'/10;
%-= xx = [1:lsg1]/lsg1;
%-= sg1 = sin(2*pi*(2000+2*sin(xx*120)).*[1:lsg1]/lsg1)'/10;
%-= sg1 = click(lsg1,10);

%% loading the castanets h2 file and adding to the speech signal 
casta = 'h2a.wav'; casta = 'h2o.wav'; % casta = 'h2b.wav'; % casta = 'beat1';
casta = 'h2oo11Khz.wav'; % casta = 'FemaleSpeechFrench'; 
casta = 'h2ac11Khz.wav'; % casta = 'FemaleSpeechEnglish'; % casta = 'h2oo.wav';
casta = 'beat111Khz';
% casta = 'noise2.wav'; 
[sg2 Fs] = wavread(['audio/' casta]);
sg2 = click(lsg1,100);
sg2 = sg2(1:lsg1); sg1 = sg1(1:lsg1);
sgn = sg1 + sg2/3; 
wavwrite(sgn,Fs,[tag 'sgnSpeechC.wav']);

%% =====================================================================
%% Constructing High-Dimensional Datasets

pt=1; fftSize = 512; winSize = 512; hopSize = 32; fftSize2 = fftSize/2;
pt=1; fftSize = 128; winSize = 128; hopSize = 8; fftSize2 = fftSize/2;
pt=1; fftSize = 256; winSize = 256; hopSize = 16; fftSize2 = fftSize/2;
pt=1; fftSize = 128; winSize = 128; hopSize = 4; fftSize2 = fftSize/2;
pfft.fftSize = fftSize; pfft.winSize = winSize; pfft.hopSize = hopSize; 
[wxn wsg] = stft(sgn',fftSize,winSize,hopSize);
awxn = abs(wxn);
% nawxn = sum(awxn.*awxn); clcs = find(nawxn > 1); awxn = awxn(:,clcs);
dawxn = diff(awxn); lawxn = log10(awxn); dlawxn = diff(lawxn);
plotSpectro(sgn,[tag 'spectOrg']);

[wx2 csw] = stft(sg2',fftSize,winSize,hopSize);
awx2 = abs(wx2);
nawx2 = sum(awx2.*awx2); clcs = find(nawx2 > 1); awx2 = awx2(:,clcs);
dawx2 = diff(awx2); lawx2 = log10(awx2); dlawx2 = diff(lawx2);

[wx1 se1] = stft(sg1',fftSize,winSize,hopSize);
awx1 = abs(wx1);
% nawx1 = sum(awx1.*awx1); clcs = find(nawx1 > 1); awx1 = awx1(:,clcs);
dawx1 = diff(awx1); lawx1 = log10(awx1); dlawx1 = diff(lawx1);
plotSpectro(sg1,[tag 'spectSgn1']);

%% =====================================================================
%% Constructing Low-Dimensional Datasets

%% % taking block of time-frequency data
%% skq1 = lawx1(:,1:800); fck = 4;
%% pcaAnalysis2(skq1'); title('lawx1 PCA');
%% [nla mla] = size(skq1);
%% la2r1 = reshape(skq1,nla*fck,mla/fck);
%% pcaAnalysis2(skq1'); 
%% 
%% skq2 = lawx2(:,1:800);
%% pcaAnalysis2(skq2'); title('lawx2 PCA');
%% [nla mla] = size(skq2);
%% la2r2 = reshape(skq2,nla*fck,mla/fck);
%% pcaAnalysis2(skq2'); 
%% 
%% skqn = lawxn(:,1:800);
%% pcaAnalysis2(skqn'); title('lawxn PCA');
%% [nla mla] = size(skqn);
%% la2rn = reshape(skqn,nla*fck,mla/fck);
%% pcaAnalysis2(skqn'); 
%% 
%% pcar4 = pcaAnalysis3(lawxn',lawx1',lawx2'); title('lawx PCA'); 
%% pcar4 = pcaAnalysis3(la2rn',la2r2',la2r1'); title('la2r PCA'); 
%% disp('asf3e'); keyboard; 

%pcar1 = pcaAnalysis3(dawxn',dawx1',dawx2');    title('dawx PCA');
pcar2 = pcaAnalysis3(awxn',awx1',awx2');       title('awx PCA');
%pcar3 = pcaAnalysis3(dlawxn',dlawx1',dlawx2'); title('dlawx PCA');
pcar4 = pcaAnalysis3(lawxn',lawx1',lawx2'); title('lawx PCA'); 
% saveas(gcf,[tag 'PCD1'],'png'); saveas(gcf,[tag 'PCD1'],'epsc');
screen2jpeg([tag 'PCD1']);

%% =====================================================================
%% Transforming and Filtering Datasets

sek = lawxn; sek1 = lawx1; sek2 = lawx2;
sed = pcar4.tr2c; sep = pcar4.tr;
sed1 = sep(:,1:size(sek1,2)); sed2 = sep(:,size(sek1,2)+1:end);

z1 = centerCluster(sed2);
z1 = centerCluster(sed2);
e1 = centerCluster(sed1);

% PCD centering and Moebius Transform design
ze12 = (e1+z1)/2; zz1 = z1 - ze12; ee1 = e1 - ze12;
sedc  = sed  - repmat(ze12,1,size(sed,2));
sed1c = sed1 - repmat(ze12,1,size(sed1,2));
sed2c = sed2 - repmat(ze12,1,size(sed2,2));

[mbt imbt] = moebiusTransform2(zz1,-1,0.4);

% select the PCD subsample (enough for STFT reconstruction) 
hps = fftSize/4; sedsample = sedc(:,1:(hps/hopSize):end);
tic; sedm = mtransformPCD(sedsample,mbt); toc;
sedf = filterPCDProcrust(sedm,zz1,rmv);
sedic = mtransformPCD(sedf,imbt);

% sedm = sedsample;
% sedf = filterPCDProcrust(sedm,zz1);
% sedic = sedf;

sedi = sedic + repmat(ze12,1,size(sedic,2));

%% =====================================================================
%% Reconstructing High-Dimensional Datasets and Audio Signals

disp('starting RBF interpolation'); 
WwCc1 = rbfWeights(sek1,sed1); 
sevr1 = rbfApproximation(sedi,WwCc1);
WwCcn = rbfWeights(sek,sed); 
sevrn = rbfApproximation(sedi,WwCcn);
WwCc2 = rbfWeights(sek2,sed2); 
sevr2 = rbfApproximation(sedi,WwCc2);

% if parms.usepcd1 == 1; sevr = sevr1; else sevr = sevrn; end;
sevr = sevr1; 
sevr = sevrn;
% sevr = sevr2; 

% reconstruct signal
disp('starting reconstruction of signal'); 
% sevr = sevr*pcar4.mnorm; sevr = sevr + repmat(pcar4.msed',1,size(sevr,2));
wxnrs = power(10,sevr);
% wxnrs = wxnrs(:,1:(hps/hopSize):end);
wxnso = wxn(:,1:(hps/hopSize):end);
wxnsa = wxnrs.*exp(i*angle(wxnso));
sgnFilt = istft(wxnsa*2,fftSize,winSize,hps);
wavwrite(2*sgnFilt,Fs,[tag '-processedAA2.wav']);
plotSpectro(sgnFilt',[tag 'spectFilt']);

% disp('function completed'); keyboard; 
