function [sed sed2] = torus (r, n, a)
% TORUS Generate a torus.
% torus (r, n, a) generates a plot of a
% torus with central radius a and
% lateral radius r.
% n controls the number of facets
% on the surface.
% These input variables are optional
% with defaults r = 0.5, n = 30, a = 1.
%
% [x, y, z] = torus(r, n, a) generates
% three (n + 1)-by-(n + 1) matrices so
% that surf (x, y, z) will produce the
% torus.
%
% See also SPHERE, CYLINDER
%
% MATLAB Primer, 6th Edition
% Kermit Sigmon and Timothy A. Davis
% Section 11.5, page 65.

% clear all; close all;

if nargin < 3, a = 1 ;   end
if nargin < 2, n = 90 ;  end
if nargin < 1, r = 0.4 ; end

% a = 1; n = 110; r = 0.4;
% a = 1; n = 190; r = 0.4;
% a = 1; n = 80;  r = 0.4;
% a = 1; n = 50;  r = 0.4;

% theta = pi * (0:2:2*n)/n;
theta = 2*pi* (0:2:n)/n ;
phi = 2*pi* (0:2:n)'/n ;
xx = (a + r*cos(phi)) * cos(theta) ;
yy = (a + r*cos(phi)) * sin(theta) ;
zz = r * sin(phi) * ones(size(theta));
% zz = ones(size(zz));

xx2 = (r*cos(phi)) * cos(theta);
yy2 = 2*(r*cos(phi)) * sin(theta);
zz2 = r * sin(phi) * ones(size(theta)) ;
% zz2 = ones(size(zz2));

%% if nargout == 0
%%     surf (xx, yy, zz) ;
%%     ar = (a + r)/sqrt(2) ;
%%     axis([-ar, ar, -ar, ar, -ar, ar]) ;
%% else
%%     x = xx ;
%%     y = yy ;
%%     z = zz ;
%% end

xx0 = xx; yy0 = yy; zz0 = zz;
xx(:,2:2:end) = flipud(xx(:,2:2:end));
yy(:,2:2:end) = flipud(yy(:,2:2:end));
zz(:,2:2:end) = flipud(zz(:,2:2:end));

sed(:,2)  = xx(:);  sed(:,1)  = yy(:);  sed(:,3)  = zz(:);
sed2(:,2) = xx2(:); sed2(:,1) = yy2(:); sed2(:,3) = zz2(:);

% disp('turus.m'); keyboard;

sed = sed +  repmat(abs(min(sed)),size(sed,1),1);
sed = sed ./ repmat(max(sed), size(sed,1),1); 

sed2 = sed2 +  repmat(abs(min(sed2)),size(sed2,1),1);
sed2 = sed2 ./ repmat(max(sed2), size(sed2,1),1); 

%% [s3 i3] = sort(sed(:,3));
%% sed = sed(i3,:);
%% 
%% [s3 i3] = sort(sed2(:,3));
%% sed2 = sed2(i3,:);

sed = sed'; sed2 = sed2';

%sed2 = sort(sed2,3); 

%%== ncolors = 64; 
%%== lse1 = size(sed,1); ncolorsArray = floor(([1:lse1-1]/lse1)*ncolors+1);
%%== ncolorsArray(length(ncolorsArray)+1) = ncolorsArray(length(ncolorsArray));
%%== figure; trsed  = pcaAnalysis2(sed,ncolorsArray,1); rotate3d on;
%%== figure; trsed2  = pcaAnalysis2(sed2,ncolorsArray,1); rotate3d on;
%%== 
%%== disp('sad33'); keyboard; 

